<?php

/**
 * ReduxFramework Config
 * */
if ( !class_exists( 'economistcommercegurus_Redux_Framework_config' ) ) {

	class economistcommercegurus_Redux_Framework_config {

		public $args	 = array();
		public $sections = array();
		public $theme;
		public $ReduxFramework;

		public function __construct() {

			if ( !class_exists( 'ReduxFramework' ) ) {
				return;
			}

			// This is needed. Bah WordPress bugs.  ;)
			if ( true == Redux_Helpers::isTheme( __FILE__ ) ) {
				$this->initSettings();
			} else {
				add_action( 'plugins_loaded', array( $this, 'initSettings' ), 10 );
			}
		}

		public function initSettings() {

			// Just for demo purposes. Not needed per say.
			$this->theme = wp_get_theme();

			// Set the default arguments
			$this->setArguments();

			// Set a few help tabs so you can see how it's done
			$this->setHelpTabs();

			// Create the sections and fields
			$this->setSections();

			if ( !isset( $this->args['opt_name'] ) ) { // No errors please
				return;
			}

			// If Redux is running as a plugin, this will remove the demo notice and links
			add_action( 'redux/loaded', array( $this, 'remove_demo' ) );

			$this->ReduxFramework = new ReduxFramework( $this->sections, $this->args );
		}

		/**
		 * This is a test function that will let you see when the compiler hook occurs.
		 * It only runs if a field   set with compiler=>true is changed.
		 * */
		function compiler_action( $options, $css ) {
			
		}

		/**
		 * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
		 * Simply include this function in the child themes functions.php file.
		 * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
		 * so you must use get_template_directory_uri() if you want to use any of the built in icons
		 * */
		function dynamic_section( $sections ) {
			//$sections = array();
			$sections[] = array(
				'title'	 => esc_html__( 'Section via hook', 'economist' ),
				'desc'	 => esc_html__( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'economist' ),
				'icon'	 => 'el-icon-paper-clip',
				// Leave this as a blank section, no options just some intro text set above.
				'fields' => array()
			);

			return $sections;
		}

		/**
		 * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
		 * */
		function change_arguments( $args ) {
			//$args['dev_mode'] = true;

			return $args;
		}

		/**
		 * Filter hook for filtering the default value of any given field. Very useful in development mode.
		 * */
		function change_defaults( $defaults ) {
			$defaults['str_replace'] = 'Testing filter hook!';

			return $defaults;
		}

		// Remove the demo link and the notice of integrated demo from the redux-framework plugin
		function remove_demo() {

			// Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
			if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
				remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::instance(), 'plugin_metalinks' ), null, 2 );

				// Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
				remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
			}
		}

		public function setSections() {

			/**
			 * Theme Options sections
			 * */
			$this->sections[] = array(
				'title'	 => esc_html__( 'Global Settings', 'economist' ),
				'desc'	 => esc_html__( 'Changes to major global elements.', 'economist' ),
				'icon'	 => 'el-icon-home',
				'fields' => array(
					array(
						'desc'		 => esc_html__( 'Select a container layout style', 'economist' ),
						'id'		 => 'container_style',
						'type'		 => 'select',
						'options'	 => array(
							'full-width' => esc_html__( 'Full Width Layout', 'economist' ),
							'boxed'		 => esc_html__( 'Boxed Layout', 'economist' ),
						),
						'title'		 => esc_html__( 'Container layout style', 'economist' ),
						'default'	 => 'full-width',
					),
					array(
						'desc'		 => esc_html__( 'Enable or disable responsiveness on smartphones', 'economist' ),
						'id'		 => 'economistcommercegurus_responsive',
						'type'		 => 'select',
						'options'	 => array(
							'enabled'	 => esc_html__( 'Enabled', 'economist' ),
							'disabled'	 => esc_html__( 'Disabled', 'economist' ),
						),
						'title'		 => esc_html__( 'Responsive', 'economist' ),
						'default'	 => 'enabled',
					),
					array(
						'desc'		 => esc_html__( 'Enable or disable the Page preloader', 'economist' ),
						'id'		 => 'economistcommercegurus_preloader',
						'type'		 => 'select',
						'options'	 => array(
							'enabled'	 => esc_html__( 'Enabled', 'economist' ),
							'disabled'	 => esc_html__( 'Disabled', 'economist' ),
						),
						'title'		 => esc_html__( 'Page Preloader', 'economist' ),
						'default'	 => 'disabled',
					),
					array(
						'id'					 => 'economistcommercegurus_background',
						'type'					 => 'background',
						'title'					 => esc_html__( 'Body Background - Color and image', 'economist' ),
						'subtitle'				 => esc_html__( 'Configure your theme background.', 'economist' ),
						'background-position'	 => false,
						'background-size'		 => false,
						'background-attachment'	 => false,
						'default'				 => array(
							'background-color' => '#f8f8f8',
						),
					),
					array(
						'id'					 => 'economistcommercegurus_pattern_background',
						'type'					 => 'background',
						'title'					 => esc_html__( 'Body Background - Pattern', 'economist' ),
						'subtitle'				 => esc_html__( 'Use this option if you want to use a repeating pattern for your background. Note: Do not try to use both a pattern background and a full size image background! ', 'economist' ),
						'background-position'	 => false,
						'background-size'		 => false,
						'background-attachment'	 => false,
						'default'				 => array(
							'background-color' => '#efefef',
						),
					),
					array(
						'id'		 => 'economistcommercegurus_page_wrapper_color',
						'type'		 => 'color',
						'title'		 => esc_html__( 'Main body wrapper color', 'economist' ),
						'subtitle'	 => esc_html__( 'Configure your theme wrapper.', 'economist' ),
						'default'	 => '#ffffff',
					),
				),
			);

			$this->sections[] = array(
				'title'	 => esc_html__( 'Colors', 'economist' ),
				'desc'	 => esc_html__( 'Customize your theme color palette.', 'economist' ),
				'icon'	 => 'el-icon-tint',
				'fields' => array(
					array(
						'desc'		 => esc_html__( 'Select from one of the predefined color skins, or have your own colors by selecting "No Skin" and choosing colors below.', 'economist' ),
						'id'		 => 'economistcommercegurus_skin_color',
						'type'		 => 'select',
						'options'	 => array(
							'none'	 => esc_html__( 'No skin - use custom', 'economist' ),
							'red'	 => esc_html__( 'Red', 'economist' ),
							'green'	 => esc_html__( 'Green', 'economist' ),
							'blue'	 => esc_html__( 'Blue', 'economist' ),
						),
						'title'		 => esc_html__( 'Color Skin', 'economist' ),
						'default'	 => 'none',
					),
					array(
						'id'		 => 'economistcommercegurus_primary_color',
						'type'		 => 'color',
						'title'		 => esc_html__( 'Primary theme color', 'economist' ),
						'subtitle'	 => esc_html__( 'This should be something unique.', 'economist' ),
						'default'	 => '#104b85',
					),
					array(
						'id'		 => 'economistcommercegurus_secondary_color',
						'type'		 => 'color_rgba',
						'title'		 => esc_html__( 'Secondary swatch color', 'economist' ),
						'indent'	 => true,
						'subtitle'	 => esc_html__( 'This should be something unique.', 'economist' ),
						'default'	 => array(
							'color'	 => '#ffea00',
							'alpha'	 => 0.8
						),
						'output'	 => array( 'background-color' => '.entry-content a.more-link:after,
.error404 .page-content p a:after, .cg-primary-menu .menu > li a span:after, #secondary .advanced-sidebar-menu ul li a:before, .content-area .vc_row ul li:before, .bypostauthor .comment-author .says:after' )
					),
					array(
						'id'		 => 'link-colors-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Link Colors', 'economist' ),
						'subtitle'	 => esc_html__( 'Define your link colors.', 'economist' ),
						'indent'	 => true
					),
					array(
						'id'		 => 'economistcommercegurus_active_link_color',
						'type'		 => 'color',
						'title'		 => esc_html__( 'Active link color', 'economist' ),
						'subtitle'	 => esc_html__( 'The color of active links.', 'economist' ),
						'default'	 => '#104b85',
					),
					array(
						'id'		 => 'economistcommercegurus_link_hover_color',
						'type'		 => 'color',
						'title'		 => esc_html__( 'Link hover color', 'economist' ),
						'subtitle'	 => esc_html__( 'The color of your links in the hover state.', 'economist' ),
						'default'	 => '#000000',
					),
					array(
						'id'	 => 'link-colors-end',
						'type'	 => 'section',
						'indent' => false,
					),
					array(
						'id'		 => 'navigation-colors-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Navigation Colors', 'economist' ),
						'subtitle'	 => esc_html__( 'Define your navigation colors. Note: not all color options apply to all navigation styles.', 'economist' ),
						'indent'	 => true
					),
					array(
						'id'		 => 'economistcommercegurus_navigation_bg_color',
						'type'		 => 'color',
						'title'		 => esc_html__( 'Navigation Background Color', 'economist' ),
						'indent'	 => true,
						'subtitle'	 => esc_html__( 'The Color of Navigation Background.', 'economist' ),
						'default'	 => '#ffffff',
						'output'	 => array( 'background-color' => '.cg-minimal .cg-menu-below, body.fixed .cg-menu-below' )
					),
					array(
						'id'		 => 'economistcommercegurus_navigation_text_color',
						'type'		 => 'color',
						'title'		 => esc_html__( 'Navigation Text Color', 'economist' ),
						'subtitle'	 => esc_html__( 'The color of the Navigation', 'economist' ),
						'default'	 => '#111111',
					),
					array(
						'id'	 => 'navigation-colors-end',
						'type'	 => 'section',
						'indent' => false,
					),
					array(
						'id'		 => 'headermobile-colors-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Mobile Colors', 'economist' ),
						'subtitle'	 => esc_html__( 'Define your mobile colors.', 'economist' ),
						'indent'	 => true
					),
					array(
						'id'		 => 'economistcommercegurus_mobile_header_bg_color',
						'type'		 => 'color',
						'title'		 => esc_html__( 'Mobile header background', 'economist' ),
						'subtitle'	 => esc_html__( 'The color of the Mobile header background.', 'economist' ),
						'default'	 => '#ffffff',
					),
					array(
						'id'		 => 'economistcommercegurus_mobile_header_elements_color',
						'type'		 => 'color',
						'title'		 => esc_html__( 'Mobile header elements', 'economist' ),
						'indent'	 => true,
						'subtitle'	 => esc_html__( 'The color of the Mobile search and hamburger menu.', 'economist' ),
						'default'	 => '#000',
						'output'	 => array( 'background-color' => '.mean-container a.meanmenu-reveal span', 'color' => '.mobile-search i' )
					),
					array(
						'id'	 => 'headermobile-colors-end',
						'type'	 => 'section',
						'indent' => false,
					),
					array(
						'id'		 => 'footer-colors-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Footer Colors', 'economist' ),
						'subtitle'	 => esc_html__( 'Define your footer colors.', 'economist' ),
						'indent'	 => true
					),
					array(
						'id'		 => 'economistcommercegurus_first_footer_bg',
						'type'		 => 'color',
						'title'		 => esc_html__( 'First footer background color', 'economist' ),
						'subtitle'	 => esc_html__( 'The background color of the first (top) footer.', 'economist' ),
						'default'	 => '#232323',
					),
					array(
						'id'		 => 'economistcommercegurus_first_footer_text',
						'type'		 => 'color',
						'title'		 => esc_html__( 'First footer text color', 'economist' ),
						'subtitle'	 => esc_html__( 'The text color of the first (top) footer.', 'economist' ),
						'default'	 => '#ffffff',
					),
					array(
						'id'		 => 'economistcommercegurus_first_footer_link',
						'type'		 => 'color',
						'title'		 => esc_html__( 'First footer link color', 'economist' ),
						'subtitle'	 => esc_html__( 'The link color of the first (top) footer.', 'economist' ),
						'default'	 => '#cccccc',
					),
					array(
						'id'		 => 'economistcommercegurus_second_footer_bg',
						'type'		 => 'color',
						'title'		 => esc_html__( 'Second footer background color', 'economist' ),
						'subtitle'	 => esc_html__( 'The background color of the second (bottom) footer.', 'economist' ),
						'default'	 => '#1e1e1e',
					),
					array(
						'id'		 => 'economistcommercegurus_second_footer_text',
						'type'		 => 'color',
						'title'		 => esc_html__( 'Second footer text color', 'economist' ),
						'subtitle'	 => esc_html__( 'The text color of the second (bottom) footer.', 'economist' ),
						'default'	 => '#999999',
					),
					array(
						'id'	 => 'footer-colors-end',
						'type'	 => 'section',
						'indent' => false,
					),
				),
			);

			$this->sections[] = array(
				'title'	 => esc_html__( 'Logos', 'economist' ),
				'desc'	 => esc_html__( 'Update your Logos.', 'economist' ),
				'icon'	 => 'el-icon-photo',
				'fields' => array(
					array(
						'id'		 => 'standard-logo-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Logos', 'economist' ),
						'subtitle'	 => esc_html__( 'Set your Logo', 'economist' ),
						'indent'	 => true
					),
					array(
						'desc'		 => esc_html__( 'Upload a Transparent Logo.', 'economist' ),
						'id'		 => 'site_logo',
						'type'		 => 'media',
						'title'		 => esc_html__( 'Transparent Logo', 'economist' ),
						'url'		 => true,
						'default'	 => array(
							'url' => get_template_directory_uri() . '/images/logo-transparent.png'
						),
					),
					array(
						'title'			 => esc_html__( 'Logo Height', 'economist' ),
						'subtitle'		 => esc_html__( 'Set your Logo Height in pixels', 'economist' ),
						'id'			 => 'economistcommercegurus_logo_height',
						'type'			 => 'slider',
						"default"		 => 31,
						"min"			 => 0,
						"step"			 => 1,
						"max"			 => 200,
						'display_value'	 => 'text',
					),
					array(
						'title'			 => esc_html__( 'Padding around Logo', 'economist' ),
						'subtitle'		 => esc_html__( 'Set some padding around your logo', 'economist' ),
						'id'			 => 'economistcommercegurus_padding_below_logo',
						'type'			 => 'slider',
						"default"		 => 58,
						"min"			 => 0,
						"step"			 => 1,
						"max"			 => 200,
						'display_value'	 => 'text',
					),
					array(
						'id'	 => 'standard-logo-end',
						'type'	 => 'section',
						'indent' => false,
					),
					array(
						'id'		 => 'sticky-logo-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Sticky Logo', 'economist' ),
						'subtitle'	 => esc_html__( 'Set your Sticky Logo', 'economist' ),
						'indent'	 => true
					),
					array(
						'desc'		 => esc_html__( 'Upload a Logo which appears within a Sticky Header.', 'economist' ),
						'id'		 => 'economistcommercegurus_alt_site_logo',
						'type'		 => 'media',
						'title'		 => esc_html__( 'Sticky Logo (optional)', 'economist' ),
						'url'		 => true,
						'default'	 => array(
							'url' => get_template_directory_uri() . '/images/example-logo.png'
						),
					),
					array(
						'id'	 => 'sticky-logo-end',
						'type'	 => 'section',
						'indent' => false,
					),
					array(
						'id'		 => 'dynamic-width-logo-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Logo Container Width', 'economist' ),
						'subtitle'	 => esc_html__( 'Set the Container width of the Logo - the default is 20%. Unless you have a very wide logo you should not need to adjust this.', 'economist' ),
						'indent'	 => true
					),
					array(
						'title'			 => esc_html__( 'Logo Container Width', 'economist' ),
						'subtitle'		 => esc_html__( 'Set in %', 'economist' ),
						'desc'			 => esc_html__( 'You may need to remove or adjust your Menu labels if you increase this.', 'economist' ),
						'id'			 => 'economistcommercegurus_dynamic_logo_width',
						'type'			 => 'slider',
						"default"		 => 20,
						"min"			 => 10,
						"step"			 => 1,
						"max"			 => 50,
						'display_value'	 => 'text',
					),
					array(
						'id'	 => 'dynamic-width-logo-end',
						'type'	 => 'section',
						'indent' => false,
					),
					array(
						'id'		 => 'mobile-header-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Mobile Header Height', 'economist' ),
						'subtitle'	 => esc_html__( 'Set the mobile header height', 'economist' ),
						'indent'	 => true
					),
					array(
						'title'			 => esc_html__( 'Mobile Header Height', 'economist' ),
						'subtitle'		 => esc_html__( 'Set in px', 'economist' ),
						'desc'			 => esc_html__( 'Increase the Mobile Header Height if you wish (Default is 75px)', 'economist' ),
						'id'			 => 'economistcommercegurus_mobile_header_height',
						'type'			 => 'slider',
						"default"		 => 75,
						"min"			 => 60,
						"step"			 => 1,
						"max"			 => 150,
						'display_value'	 => 'text',
					),
					array(
						'title'			 => esc_html__( 'Mobile Logo Height', 'economist' ),
						'subtitle'		 => esc_html__( 'Set in px', 'economist' ),
						'desc'			 => esc_html__( 'Set your Mobile Logo Size (Default is 27px)', 'economist' ),
						'id'			 => 'economistcommercegurus_mobile_logo_height',
						'type'			 => 'slider',
						"default"		 => 27,
						"min"			 => 25,
						"step"			 => 1,
						"max"			 => 150,
						'display_value'	 => 'text',
					),
					array(
						'id'	 => 'mobile-header-end',
						'type'	 => 'section',
						'indent' => false,
					),
				),
			);

			$this->sections[] = array(
				'title'	 => esc_html__( 'Header Settings', 'economist' ),
				'desc'	 => esc_html__( 'Manage your header.', 'economist' ),
				'icon'	 => 'el-icon-hand-up',
				'fields' => array(
					array(
						'id'		 => 'economistcommercegurus_logo_position',
						'type'		 => 'image_select',
						'compiler'	 => true,
						'title'		 => esc_html__( 'Header Layout', 'economist' ),
						'subtitle'	 => esc_html__( 'Select the Header Layout.', 'economist' ),
						'options'	 => array(
							'left' => array(
								'alt'	 => 'Layout 4',
								'img'	 => get_template_directory_uri() . '/images/theme_options/header_2.png'
							),
						),
						'default'	 => 'left'
					),
					array(
						'id'		 => 'economistcommercegurus_header_style',
						'type'		 => 'select',
						'title'		 => esc_html__( 'Header Style', 'economist' ),
						'options'	 => array(
							'transparent'	 => esc_html__( 'Transparent (default)', 'economist' ),
							'solid'			 => esc_html__( 'Solid', 'economist' ),
						),
						'default'	 => 'transparent',
					),
					array(
						'id'		 => 'economistcommercegurus_mobile_header_style',
						'type'		 => 'select',
						'title'		 => esc_html__( 'Mobile Menu Style', 'economist' ),
						'options'	 => array(
							'sticky'	 => esc_html__( 'Sticky (default)', 'economist' ),
							'regular'	 => esc_html__( 'Regular', 'economist' ),
						),
						'default'	 => 'sticky',
					),
					array(
						'id'		 => 'economistcommercegurus_show_search',
						'type'		 => 'switch',
						'title'		 => esc_html__( 'Search', 'economist' ),
						'subtitle'	 => esc_html__( 'Enable the Search?', 'economist' ),
						'on'		 => esc_html__( 'Enable', 'economist' ),
						'off'		 => esc_html__( 'Disable', 'economist' ),
						'default'	 => 1,
					),
				),
			);

			$this->sections[] = array(
				'title'	 => esc_html__( 'Main Menu Settings', 'economist' ),
				'desc'	 => esc_html__( 'Manage your main menu.', 'economist' ),
				'icon'	 => 'el-icon-cog-alt',
				'fields' => array(
					array(
						'id'			 => 'economistcommercegurus_level1_font',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'Level 1 Typeface', 'economist' ),
						'text-transform' => true,
						'google'		 => true,
						'font-backup'	 => true,
						'line-height'	 => false,
						'letter-spacing' => true,
						'all_styles'	 => true,
						'text-align'	 => false,
						'output'		 => array( '.cg-primary-menu .menu > li > a' ),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Typography option where each property can be called individually.', 'economist' ),
						'default'		 => array(
							'font-weight'	 => '400',
							'font-family'	 => 'Rubik',
							'google'		 => true,
							'font-size'		 => '16px',
							'text-transform' => 'uppercase',
							'letter-spacing' => '-0.1px',
						),
					),
					array(
						'id'			 => 'economistcommercegurus_level2_heading_font',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'Level 2 Heading Typeface', 'economist' ),
						'text-transform' => true,
						'google'		 => true,
						'font-backup'	 => true,
						'line-height'	 => false,
						'letter-spacing' => true,
						'all_styles'	 => true,
						'text-align'	 => false,
						'output'		 => array( '.cg-header-fixed .menu > li.menu-full-width .cg-submenu-ddown .container > ul > li > a, .cg-primary-menu .menu > li.menu-full-width .cg-submenu-ddown .container > ul > li > a, .menu-full-width .cg-menu-title, .cg-header-fixed .menu > li.menu-full-width .cg-submenu-ddown .container > ul .menu-item-has-children > a, .cg-primary-menu .menu > li .cg-submenu-ddown ul li.image-item-title a, .cg-primary-menu .menu > li .cg-submenu-ddown ul li.image-item-title ul a,
.cg-primary-menu .menu > li.menu-full-width .cg-submenu-ddown .container > ul .menu-item-has-children > a, .cg-header-fixed .menu > li.menu-full-width .cg-submenu-ddown .container > ul > li .cg-submenu ul li.title a, .cg-primary-menu .menu > li.menu-full-width .cg-submenu-ddown .container > ul > li .cg-submenu ul li.title a, .cg-primary-menu .menu > li.menu-full-width .cg-submenu-ddown .container > ul > li > a:hover, .menu > li.menu-full-width .cg-submenu-ddown h4' ),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Typography option where each property can be called individually.', 'economist' ),
						'default'		 => array(
							'font-weight'	 => '400',
							'font-family'	 => 'Rubik',
							'google'		 => true,
							'font-size'		 => '14px',
							'letter-spacing' => '-0.1px',
							'text-transform' => 'uppercase',
							'color'			 => '#ffffff',
						),
					),
					array(
						'id'			 => 'economistcommercegurus_level2_font',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'Level 2 Typeface', 'economist' ),
						'text-transform' => true,
						'google'		 => true,
						'font-backup'	 => true,
						'line-height'	 => false,
						'letter-spacing' => true,
						'all_styles'	 => true,
						'text-align'	 => false,
						'output'		 => array( '.cg-primary-menu .menu > li .cg-submenu-ddown .container > ul > li > a, .cg-submenu-ddown .container > ul > li > a, .cg-header-fixed .menu > li.menu-full-width .cg-submenu-ddown .container > ul > li .cg-submenu ul li ul li > a, .cg-primary-menu .menu > li.menu-full-width .cg-submenu-ddown .container > ul > li .cg-submenu ul li ul li > a, .menu > li.menu-full-width .cg-submenu-ddown li p, .menu > li.menu-full-width .cg-submenu-ddown li .cg-submenu ul li a, .cg-primary-menu .menu > li .cg-submenu-ddown .container > ul .menu-item-has-children .cg-submenu li a, .mean-container .mean-nav ul li.fa, .cg-primary-menu .menu > li.menu-item-language ul.sub-menu li a' ),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Typography option where each property can be called individually.', 'economist' ),
						'default'		 => array(
							'color'			 => '#999999',
							'font-weight'	 => '300',
							'font-family'	 => 'Rubik',
							'google'		 => true,
							'font-size'		 => '14px',
						),
					),
					array(
						'id'		 => 'mega-heading-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Menu Dropdown', 'economist' ),
						'subtitle'	 => esc_html__( 'Tweak the colors of the dropdown menu', 'economist' ),
						'indent'	 => false,
					),
					array(
						'id'		 => 'economistcommercegurus_mega_menu_bg_color',
						'type'		 => 'color',
						'title'		 => esc_html__( 'Dropdown Menu Background Color', 'economist' ),
						'indent'	 => false,
						'default'	 => '#111111',
					),
					array(
						'id'		 => 'economistcommercegurus_mega_menu_color',
						'type'		 => 'color',
						'indent'	 => false,
						'title'		 => esc_html__( 'Dropdown Menu Text Color', 'economist' ),
						'default'	 => '#999999',
					),
					array(
						'id'		 => 'economistcommercegurus_main_menu_dropdown_hover',
						'type'		 => 'color',
						'title'		 => esc_html__( 'Dropdown Menu Hover Text Color', 'economist' ),
						'default'	 => '#ffffff',
					),
					array(
						'id'	 => 'mega-heading-end',
						'type'	 => 'section',
						'indent' => false,
					),
				),
			);


			// Page Settings
			$this->sections[] = array(
				'title'	 => esc_html__( 'Page Options', 'economist' ),
				'desc'	 => esc_html__( 'Extra Page Options', 'economist' ),
				'icon'	 => 'el-icon-list-alt',
				'fields' => array(
					array(
						'id'		 => 'page-heading-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Page Heading', 'economist' ),
						'subtitle'	 => esc_html__( '', 'economist' ),
						'indent'	 => true
					),
					array(
						'subtitle'	 => esc_html__( 'Should be at least 1200px wide', 'economist' ),
						'id'		 => 'economistcommercegurus_page_header_bg',
						'type'		 => 'media',
						'title'		 => esc_html__( 'Default Background Image', 'economist' ),
						'url'		 => true,
						'default'	 => array(
							'url' => get_template_directory_uri() . '/images/default-heading-bg.jpg'
						),
					),
					array(
						'title'			 => esc_html__( 'Background Image Height', 'economist' ),
						'subtitle'		 => esc_html__( 'Set in px', 'economist' ),
						'desc'			 => esc_html__( 'Increase or decrease the height of the image. Default is 538px.', 'economist' ),
						'id'			 => 'economistcommercegurus_page_header_bg_height',
						'type'			 => 'slider',
						'default'		 => 538,
						'min'			 => 200,
						'step'			 => 1,
						'max'			 => 1000,
						'display_value'	 => 'text',
					),
					array(
						'title'			 => esc_html__( 'Background Opacity', 'economist' ),
						'subtitle'		 => esc_html__( 'Set in %', 'economist' ),
						'desc'			 => esc_html__( 'Increase this to make the overlay across the background image darker.', 'economist' ),
						'id'			 => 'economistcommercegurus_page_header_opacity_bg',
						'type'			 => 'slider',
						'default'		 => 10,
						'min'			 => 0,
						'step'			 => 1,
						'max'			 => 99,
						'display_value'	 => 'text',
					),
					array(
						'id'	 => 'page-heading-end',
						'type'	 => 'section',
						'indent' => false,
					),
					array(
						'id'		 => 'page-title-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Page Title', 'economist' ),
						'subtitle'	 => esc_html__( '', 'economist' ),
						'indent'	 => true
					),
					array(
						'id'		 => 'economistcommercegurus_page_title_bg_color',
						'type'		 => 'color_rgba',
						'title'		 => esc_html__( 'Page Title background color', 'economist' ),
						'indent'	 => true,
						'subtitle'	 => esc_html__( 'Background color of the page title.', 'economist' ),
						'default'	 => array(
							'color'	 => '#ffea00',
							'alpha'	 => 0.8
						),
						'output'	 => array( 'background-color' => '.header-wrapper .entry-header' )
					),
					array(
						'id'		 => 'economistcommercegurus_page_title_color',
						'type'		 => 'color',
						'title'		 => esc_html__( 'Page Title text color', 'economist' ),
						'indent'	 => true,
						'subtitle'	 => esc_html__( 'Text color of the page title.', 'economist' ),
						'default'	 => '#000000',
						'output'	 => array( 'color' => '.header-wrapper h1.cg-page-title, .header-wrapper p.sub-title, .header-wrapper p.sub-title a' )
					),
					array(
						'id'	 => 'page-title-end',
						'type'	 => 'section',
						'indent' => false,
					),
					array(
						'id'		 => 'share-heading-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Share', 'economist' ),
						'subtitle'	 => esc_html__( '', 'economist' ),
						'indent'	 => true
					),
					array(
						'desc'		 => esc_html__( 'Display share buttons below page heading?', 'economist' ),
						'id'		 => 'economistcommercegurus_share_options',
						'type'		 => 'select',
						'title'		 => esc_html__( 'Show Share Buttons', 'economist' ),
						'options'	 => array(
							'yes'	 => esc_html__( 'Yes', 'economist' ),
							'no'	 => esc_html__( 'No', 'economist' ),
						),
						'default'	 => 'yes',
					),
					array(
						'id'	 => 'share-heading-end',
						'type'	 => 'section',
						'indent' => false,
					),
					array(
						'id'		 => 'pagesidebar-heading-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Page Sidebar Position', 'economist' ),
						'subtitle'	 => esc_html__( '', 'economist' ),
						'indent'	 => true
					),
					array(
						'id'		 => 'economistcommercegurus_page_sidebar',
						'type'		 => 'select',
						'options'	 => array(
							'default'	 => esc_html__( 'Right sidebar', 'economist' ),
							'left'		 => esc_html__( 'Left sidebar', 'economist' ),
						),
						'title'		 => esc_html__( 'Position of the page sidebar', 'economist' ),
						'default'	 => 'default',
					),
					array(
						'id'	 => 'pagesidebar-heading-end',
						'type'	 => 'section',
						'indent' => false,
					),
					array(
						'id'		 => 'woocommerce-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'WooCommerce Options', 'economist' ),
						'subtitle'	 => esc_html__( 'These only apply if you have the WooCommerce plugin installed.', 'economist' ),
						'indent'	 => true
					),
					array(
						'subtitle'	 => esc_html__( 'Should be at least 1200px wide', 'economist' ),
						'id'		 => 'economistcommercegurus_woo_header_bg',
						'type'		 => 'media',
						'title'		 => esc_html__( 'Default WooCommerce Image', 'economist' ),
						'url'		 => true,
						'default'	 => array(
							'url' => get_template_directory_uri() . '/images/default-heading-bg.jpg'
						),
					),
					array(
						'title'			 => esc_html__( 'WooCommerce Background Image Height', 'economist' ),
						'subtitle'		 => esc_html__( 'Set in px', 'economist' ),
						'desc'			 => esc_html__( 'Increase or decrease the height of the image in WooCommerce. Default is 420px.', 'economist' ),
						'id'			 => 'economistcommercegurus_woo_header_bg_height',
						'type'			 => 'slider',
						'default'		 => 420,
						'min'			 => 200,
						'step'			 => 1,
						'max'			 => 1000,
						'display_value'	 => 'text',
					),
					array(
						'id'	 => 'woocommerce-end',
						'type'	 => 'section',
						'indent' => false,
					),
				),
			);


			// End Main/Primary menu image uploads
			$this->sections[] = array(
				'title'	 => esc_html__( 'Footer Settings', 'economist' ),
				'desc'	 => esc_html__( 'Manage your footer.', 'economist' ),
				'icon'	 => 'el-icon-hand-down',
				'fields' => array(
					array(
						'desc'		 => esc_html__( 'Show Below Content Features?', 'economist' ),
						'id'		 => 'economistcommercegurus_below_content_features_active',
						'type'		 => 'select',
						'title'		 => esc_html__( 'Show below content features', 'economist' ),
						'options'	 => array(
							'yes'	 => esc_html__( 'Yes', 'economist' ),
							'no'	 => esc_html__( 'No', 'economist' ),
						),
						'default'	 => 'yes',
					),
					array(
						'desc'		 => esc_html__( 'Number of Below Content Features', 'economist' ),
						'id'		 => 'economistcommercegurus_below_content_features_cols',
						'type'		 => 'select',
						'title'		 => esc_html__( 'Number of content features', 'economist' ),
						'options'	 => array(
							'one'	 => esc_html__( 'One', 'economist' ),
							'two'	 => esc_html__( 'Two', 'economist' ),
							'three'	 => esc_html__( 'Three', 'economist' ),
							'four'	 => esc_html__( 'Four', 'economist' ),
						),
						'default'	 => 'three',
					),
					array(
						'desc'		 => esc_html__( 'Show Top Footer?', 'economist' ),
						'id'		 => 'economistcommercegurus_footer_top_active',
						'type'		 => 'select',
						'title'		 => esc_html__( 'Show top footer', 'economist' ),
						'options'	 => array(
							'yes'	 => esc_html__( 'Yes', 'economist' ),
							'no'	 => esc_html__( 'No', 'economist' ),
						),
						'default'	 => 'yes',
					),
					array(
						'desc'		 => esc_html__( 'Top Footer Columns', 'economist' ),
						'id'		 => 'economistcommercegurus_first_footer_cols',
						'type'		 => 'select',
						'title'		 => esc_html__( 'Number of footer columns', 'economist' ),
						'options'	 => array(
							'one'	 => esc_html__( 'One', 'economist' ),
							'two'	 => esc_html__( 'Two', 'economist' ),
							'three'	 => esc_html__( 'Three', 'economist' ),
							'four'	 => esc_html__( 'Four', 'economist' ),
						),
						'default'	 => 'three',
					),
					array(
						'desc'		 => esc_html__( 'Show Bottom Footer?', 'economist' ),
						'id'		 => 'economistcommercegurus_footer_bottom_active',
						'type'		 => 'select',
						'title'		 => esc_html__( 'Show bottom footer', 'economist' ),
						'options'	 => array(
							'yes'	 => esc_html__( 'Yes', 'economist' ),
							'no'	 => esc_html__( 'No', 'economist' ),
						),
						'default'	 => 'yes',
					),
					array(
						'desc'		 => esc_html__( 'Show Back to Top?', 'economist' ),
						'id'		 => 'economistcommercegurus_back_to_top',
						'type'		 => 'select',
						'title'		 => esc_html__( 'Show back to top?', 'economist' ),
						'options'	 => array(
							'yes'	 => esc_html__( 'Yes', 'economist' ),
							'no'	 => esc_html__( 'No', 'economist' ),
						),
						'default'	 => 'yes',
					),
				),
			);

			$this->sections[] = array(
				'title'	 => esc_html__( 'Typography', 'economist' ),
				'desc'	 => esc_html__( 'Manage your fonts and typefaces.', 'economist' ),
				'icon'	 => 'el-icon-fontsize',
				'fields' => array(
					array(
						'id'			 => 'opt-typography-body',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'Body/Main text font', 'economist' ),
						'google'		 => true,
						'font-backup'	 => true,
						'letter-spacing' => true,
						'all_styles'	 => true,
						'text-transform' => false,
						'text-align'	 => false,
						'output'		 => array( 'body', 'select', 'input', 'textarea', 'button', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', ),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Each property can be called individually.', 'economist' ),
						'default'		 => array(
							'color'			 => '#333333',
							'font-weight'	 => '300',
							'font-family'	 => 'Rubik',
							'google'		 => true,
							'font-size'		 => '14px',
							'line-height'	 => '24.4px'
						),
					),
					array(
						'id'			 => 'opt-typography-secondary',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'Secondary font', 'economist' ),
						'google'		 => true,
						'font-backup'	 => true,
						'letter-spacing' => true,
						'text-transform' => true,
						'all_styles'	 => true,
						'output'		 => array(
							'.content-area blockquote',
						),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Each property can be called individually.', 'economist' ),
						'default'		 => array(
							'font-weight'	 => '400',
							'font-family'	 => 'Playfair Display',
							'google'		 => true,
						),
					),
					array(
						'id'			 => 'opt-typography-p',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'Paragraph Style', 'economist' ),
						'google'		 => true,
						'font-backup'	 => true,
						'text-transform' => true,
						'letter-spacing' => true,
						'all_styles'	 => true,
						'text-transform' => false,
						'text-align'	 => false,
						'output'		 => array( '.content-area .entry-content p', '.product p', '.content-area ul', '.content-area ol', ),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Typography option with each property can be called individually.', 'economist' ),
						'default'		 => array(
							'color'			 => '#222222',
							'font-weight'	 => '300',
							'font-family'	 => 'Rubik',
							'google'		 => true,
							'font-size'		 => '16px',
							'line-height'	 => '24.4px',
						),
					),
					array(
						'id'			 => 'opt-typography-h1',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'Heading 1 Style', 'economist' ),
						'google'		 => true,
						'font-backup'	 => true,
						'text-transform' => true,
						'letter-spacing' => true,
						'all_styles'	 => true,
						'text-align'	 => false,
						'output'		 => array( 'h1', '.content-area h1', 'h1.cg-page-title', '.summary h1', '.content-area .summary h1', ),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Typography option with each property can be called individually.', 'economist' ),
						'default'		 => array(
							'color'			 => '#000',
							'font-weight'	 => '500',
							'font-family'	 => 'Rubik',
							'google'		 => true,
							'font-size'		 => '56px',
							'line-height'	 => '60px',
							'text-transform' => 'uppercase',
							'letter-spacing' => '-2px',
						),
					),
					array(
						'id'			 => 'opt-typography-h2',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'Heading 2 Style', 'economist' ),
						'google'		 => true,
						'font-backup'	 => true,
						'text-transform' => true,
						'letter-spacing' => true,
						'all_styles'	 => true,
						'text-transform' => false,
						'text-align'	 => false,
						'output'		 => array( 'h2', '.content-area h2' ),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Each property can be called individually.', 'economist' ),
						'default'		 => array(
							'color'			 => '#222',
							'font-weight'	 => '300',
							'font-family'	 => 'Rubik',
							'google'		 => true,
							'font-size'		 => '32px',
							'line-height'	 => '40px',
							'letter-spacing' => '-0.5px',
						),
					),
					array(
						'id'			 => 'opt-typography-h3',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'Heading 3 Style', 'economist' ),
						'google'		 => true,
						'font-backup'	 => true,
						'text-transform' => true,
						'letter-spacing' => true,
						'all_styles'	 => true,
						'text-transform' => false,
						'text-align'	 => false,
						'output'		 => array( 'h3', '.content-area h3' ),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Each property can be called individually.', 'economist' ),
						'default'		 => array(
							'color'			 => '#222',
							'font-weight'	 => '300',
							'font-family'	 => 'Rubik',
							'google'		 => true,
							'font-size'		 => '28px',
							'line-height'	 => '38px',
							'letter-spacing' => '-0.5px',
						),
					),
					array(
						'id'			 => 'opt-typography-h4',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'Heading 4 Style', 'economist' ),
						'google'		 => true,
						'font-backup'	 => true,
						'text-transform' => true,
						'letter-spacing' => true,
						'all_styles'	 => true,
						'text-transform' => false,
						'text-align'	 => false,
						'output'		 => array( 'h4', '.content-area h4', 'body .vc_separator h4' ),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Each property can be called individually.', 'economist' ),
						'default'		 => array(
							'color'			 => '#222',
							'font-weight'	 => '300',
							'font-family'	 => 'Rubik',
							'google'		 => true,
							'font-size'		 => '24px',
							'line-height'	 => '34px',
							'letter-spacing' => '-0.4px',
						),
					),
					array(
						'id'			 => 'opt-typography-h5',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'Heading 5 Style', 'economist' ),
						'google'		 => true,
						'font-backup'	 => true,
						'text-transform' => false,
						'text-align'	 => false,
						'letter-spacing' => true,
						'all_styles'	 => true,
						'output'		 => array( 'h5', '.content-area h5' ),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Each property can be called individually.', 'economist' ),
						'default'		 => array(
							'color'			 => '#104b85',
							'font-weight'	 => '300',
							'font-family'	 => 'Rubik',
							'google'		 => true,
							'font-size'		 => '22px',
							'line-height'	 => '33px',
							'letter-spacing' => '-0.3px',
						),
					),
					array(
						'id'			 => 'opt-typography-h6',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'Heading 6 Style', 'economist' ),
						'google'		 => true,
						'font-backup'	 => true,
						'text-transform' => true,
						'letter-spacing' => true,
						'all_styles'	 => true,
						'text-transform' => false,
						'text-align'	 => false,
						'output'		 => array( 'h6', '.content-area h6' ),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Each property can be called individually.', 'economist' ),
						'default'		 => array(
							'color'			 => '#343e47',
							'font-weight'	 => '300',
							'font-family'	 => 'Rubik',
							'google'		 => true,
							'font-size'		 => '18px',
							'line-height'	 => '26px',
						),
					),
					array(
						'id'			 => 'cg-type-widget-title',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'Widget Title Typeface', 'economist' ),
						'google'		 => true,
						'font-backup'	 => true,
						'text-transform' => true,
						'letter-spacing' => true,
						'all_styles'	 => true,
						'text-align'	 => false,
						'output'		 => array( 'h4.widget-title', '.first-footer h4', '#secondary h4.widget-title a', '.subfooter h4', ),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Each property can be called individually.', 'economist' ),
						'default'		 => array(
							'color'			 => '#222222',
							'font-weight'	 => '400',
							'font-family'	 => 'Rubik',
							'text-transform' => 'uppercase',
							'google'		 => true,
							'font-size'		 => '16px',
							'line-height'	 => '22px',
							'letter-spacing' => '0.03px',
						),
					),
				),
			);

			$this->sections[] = array(
				'title'	 => esc_html__( 'News Settings', 'economist' ),
				'desc'	 => esc_html__( 'Manage your news settings.', 'economist' ),
				'icon'	 => 'el-icon-file-edit',
				'fields' => array(
					array(
						'id'		 => 'economistcommercegurus_blog_page_title',
						'type'		 => 'text',
						'title'		 => esc_html__( 'News Page Title', 'economist' ),
						'default'	 => esc_html__( 'News', 'economist' ),
					),
					array(
						'desc'		 => esc_html__( 'Upload an optional background image for your news archives page title. The image should be at least 1200px wide.', 'economist' ),
						'id'		 => 'economistcommercegurus_blog_archive_title_bg_img',
						'type'		 => 'media',
						'title'		 => esc_html__( 'News Archive Background', 'economist' ),
						'url'		 => true,
						'default'	 => array(
							'url' => get_template_directory_uri() . '/images/default-heading-bg.jpg'
						),
					),
					array(
						'id'			 => 'economistcommercegurus_news_title_font',
						'type'			 => 'typography',
						'title'			 => esc_html__( 'News Item Single Post Title Font', 'economist' ),
						'text-transform' => true,
						'google'		 => true,
						'font-backup'	 => true,
						'line-height'	 => true,
						'letter-spacing' => true,
						'all_styles'	 => true,
						'text-align'	 => false,
						'output'		 => array( 'body.single-post h1.cg-page-title' ),
						'units'			 => 'px',
						'subtitle'		 => esc_html__( 'Typography option where each property can be called individually.', 'economist' ),
						'default'		 => array(
							'color'			 => '#000000',
							'font-weight'	 => '500',
							'font-family'	 => 'Rubik',
							'google'		 => true,
							'font-size'		 => '46px',
							'line-height'	 => '52px',
							'text-transform' => 'uppercase',
							'letter-spacing' => '-2px',
						),
					),
					array(
						'id'		 => 'blog-layout-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Layout', 'economist' ),
						'subtitle'	 => esc_html__( '', 'economist' ),
						'indent'	 => true
					),
					array(
						'id'		 => 'economistcommercegurus_news_layout',
						'type'		 => 'select',
						'options'	 => array(
							'default-news'	 => 'Default',
							'grid-news'		 => 'Grid (3 columns)',
							'grid-news-two'	 => 'Grid (2 columns)',
						),
						'title'		 => esc_html__( 'Blog Layout', 'economist' ),
						'default'	 => 'default-news',
					),
					array(
						'id'		 => 'economistcommercegurus_blog_sidebar',
						'type'		 => 'select',
						'options'	 => array(
							'default'	 => esc_html__( 'Left sidebar', 'economist' ),
							'right'		 => esc_html__( 'Right sidebar', 'economist' ),
							'none'		 => esc_html__( 'No sidebar', 'economist' ),
						),
						'title'		 => esc_html__( 'Choose a sidebar position for the news archive page', 'economist' ),
						'default'	 => 'right',
					),
					array(
						'id'		 => 'economistcommercegurus_post_sidebar',
						'type'		 => 'select',
						'options'	 => array(
							'default'	 => esc_html__( 'Left sidebar', 'economist' ),
							'right'		 => esc_html__( 'Right sidebar', 'economist' ),
							'none'		 => esc_html__( 'No sidebar', 'economist' ),
						),
						'title'		 => esc_html__( 'Choose a sidebar position for an individual post', 'economist' ),
						'default'	 => 'right',
					),
					array(
						'id'	 => 'blog-layout-end',
						'type'	 => 'section',
						'indent' => false,
					),
					array(
						'id'		 => 'blogsharing-heading-start',
						'type'		 => 'section',
						'title'		 => esc_html__( 'Share Icons', 'economist' ),
						'subtitle'	 => esc_html__( '', 'economist' ),
						'indent'	 => true
					),
					array(
						'desc'		 => esc_html__( 'Display share icons on hover?', 'economist' ),
						'id'		 => 'economistcommercegurus_blog_share_options',
						'type'		 => 'select',
						'title'		 => esc_html__( 'Show Share Icons', 'economist' ),
						'options'	 => array(
							'yes'	 => esc_html__( 'Yes', 'economist' ),
							'no'	 => esc_html__( 'No', 'economist' ),
						),
						'default'	 => 'yes',
					),
					array(
						'id'	 => 'blogsharing-heading-end',
						'type'	 => 'section',
						'indent' => false,
					),
				),
			);


			$this->sections[] = array(
				'title'	 => esc_html__( 'Custom Code', 'economist' ),
				'desc'	 => esc_html__( 'Add some custom code.', 'economist' ),
				'fields' => array(
					array(
						'title'	 => esc_html__( 'Custom CSS', 'economist' ),
						'desc'	 => esc_html__( 'Add some custom css to your site?', 'economist' ),
						'id'	 => 'economistcommercegurus_custom_css',
						'type'	 => 'ace_editor',
						'mode'	 => 'css',
						'theme'	 => 'monokai'
					),
				),
			);
		}

		public function setHelpTabs() {

			// Custom page help tabs, displayed using the help API. Tabs are shown in order of definition.
			$this->args['help_tabs'][] = array(
				'id'		 => 'redux-help-tab-1',
				'title'		 => esc_html__( 'Theme Information 1', 'economist' ),
				'content'	 => esc_html__( '<p>This is the tab content, HTML is allowed.</p>', 'economist' )
			);

			$this->args['help_tabs'][] = array(
				'id'		 => 'redux-help-tab-2',
				'title'		 => esc_html__( 'Theme Information 2', 'economist' ),
				'content'	 => esc_html__( '<p>This is the tab content, HTML is allowed.</p>', 'economist' )
			);

			// Set the help sidebar
			$this->args['help_sidebar'] = esc_html__( '<p>This is the sidebar content, HTML is allowed.</p>', 'economist' );
		}

		/**
		 * Redux config
		 * */
		public function setArguments() {

			$theme = wp_get_theme(); // For use with some settings. Not necessary.

			$this->args = array(
				// TYPICAL -> Change these values as you need/desire

				'opt_name'				 => 'economistcommercegurus_reduxopt', // This is where your data is stored in the database and also becomes your global variable name.
				'display_name'			 => $theme->get( 'Name' ), // Name that appears at the top of your panel
				'display_version'		 => $theme->get( 'Version' ), // Version that appears at the top of your panel
				'menu_type'				 => 'menu', //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
				'allow_sub_menu'		 => true, // Show the sections below the admin menu item or not
				'menu_title'			 => esc_html__( 'Theme Options', 'economist' ),
				'page_title'			 => esc_html__( 'Theme Options', 'economist' ),
				// You will need to generate a Google API key to use this feature.
				// Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
				'google_api_key'		 => 'AIzaSyB9TDy0IOriQpR8gt2TmoaZ070oWgIhvcs', // Must be defined to add google fonts to the typography module
				'google_update_weekly'	 => true,
				'async_typography'		 => false, // Use a asynchronous font on the front end or font string
				'admin_bar'				 => true, // Show the panel pages on the admin bar
				'global_variable'		 => 'economistcommercegurus_options', // Set a different name for your global variable other than the opt_name
				'dev_mode'				 => false, // Show the time the page took to load, etc
				'customizer'			 => true, // Enable basic customizer support
				//'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
				//'disable_save_warn' => true,                    // Disable the save warning when a user changes a field
				// OPTIONAL -> Give you extra features
				'page_priority'			 => null, // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
				'page_parent'			 => 'themes.php', // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
				'page_permissions'		 => 'manage_options', // Permissions needed to access the options panel.
				'menu_icon'				 => '', // Specify a custom URL to an icon
				'last_tab'				 => '', // Force your panel to always open to a specific tab (by id)
				'page_icon'				 => 'icon-themes', // Icon displayed in the admin panel next to your menu_title
				'page_slug'				 => 'economistcommercegurus_reduxopt', // Page slug used to denote the panel
				'save_defaults'			 => true, // On load save the defaults to DB before user clicks save or not
				'default_show'			 => false, // If true, shows the default value next to each field that is not the default value.
				'default_mark'			 => '*', // What to print by the field's title if the value shown is default. Suggested: *
				'show_import_export'	 => true, // Shows the Import/Export panel when not used as a field.
				// CAREFUL -> These options are for advanced use only
				'transient_time'		 => 60 * MINUTE_IN_SECONDS,
				'output'				 => true, // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
				'output_tag'			 => true, // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
				'footer_credit'			 => false, // Disable the footer credit of Redux. Please leave if you can help it.
				// FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
				'database'				 => '', // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
				'system_info'			 => false, // REMOVE
				// HINTS
				'hints'					 => array(
					'icon'			 => 'icon-question-sign',
					'icon_position'	 => 'right',
					'icon_color'	 => 'lightgray',
					'icon_size'		 => 'normal',
					'tip_style'		 => array(
						'color'		 => 'light',
						'shadow'	 => true,
						'rounded'	 => false,
						'style'		 => '',
					),
					'tip_position'	 => array(
						'my' => 'top left',
						'at' => 'bottom right',
					),
					'tip_effect'	 => array(
						'show'	 => array(
							'effect'	 => 'slide',
							'duration'	 => '500',
							'event'		 => 'mouseover',
						),
						'hide'	 => array(
							'effect'	 => 'slide',
							'duration'	 => '500',
							'event'		 => 'click mouseleave',
						),
					),
				)
			);

			// SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
			$this->args['share_icons'][]	 = array(
				'url'	 => 'https://www.facebook.com/CommerceGurus-1687149888185740',
				'title'	 => 'Like us on Facebook',
				'icon'	 => 'el-icon-facebook'
			);
			$this->args['share_icons'][]	 = array(
				'url'	 => esc_html__( 'http://twitter.com/commercegurus', 'economist' ),
				'title'	 => esc_html__( 'Follow us on Twitter', 'economist' ),
				'icon'	 => 'el-icon-twitter'
			);
			// Panel Intro text -> before the form
			if ( !isset( $this->args['global_variable'] ) || $this->args['global_variable'] !== false ) {
				if ( !empty( $this->args['global_variable'] ) ) {
					$v = $this->args['global_variable'];
				} else {
					$v = str_replace( '-', '_', $this->args['opt_name'] );
				}
			} else {
				
			}
		}

	}

	global $reduxConfig;
	$reduxConfig = new economistcommercegurus_Redux_Framework_config();
}

/**
 * Custom function for the callback referenced above
 */
if ( !function_exists( 'redux_theme_my_custom_field' ) ):

	function redux_theme_my_custom_field( $field, $value ) {
		print_r( $field );
		echo '<br/>';
		print_r( $value );
	}

endif;

/**
 * Custom function for the callback validation referenced above
 * */
if ( !function_exists( 'redux_theme_validate_callback_function' ) ):

	function redux_theme_validate_callback_function( $field, $value, $existing_value ) {
		$error	 = false;
		$value	 = 'just testing';

		$return['value'] = $value;
		if ( $error == true ) {
			$return['error'] = $field;
		}
		return $return;
	}



endif;