<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package commercegurus
 */
$allowed_args = array(
	//formatting
	'span' => array(
		'class' => array()
	),
);

if ( !function_exists( 'economistcommercegurus_posted_on' ) ) :

	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function economistcommercegurus_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		$time_string = sprintf( $time_string, esc_attr( get_the_date( 'c' ) ), esc_html( get_the_date() ), esc_attr( get_the_modified_date( 'c' ) ), esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
		esc_html_x( '%s', 'post date', 'economist' ), '' . $time_string . ''
		);

		$byline = sprintf(
		esc_html_x( 'by %s', 'post author', 'economist' ), '<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="posted-on">' . $posted_on . '</span><span class="author-meta">' . $byline . '</span>'; // WPCS: XSS OK.
	}

endif;

if ( !function_exists( 'economistcommercegurus_content_nav' ) ) :

	/**
	 * Display navigation to next/previous pages when applicable
	 */
	function economistcommercegurus_content_nav( $nav_id ) {
		global $wp_query, $post;

		// Don't print empty markup on single pages if there's nowhere to navigate.
		if ( is_single() ) {
			$previous	 = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
			$next		 = get_adjacent_post( false, '', false );

			if ( !$next && !$previous )
				return;
		}

		// Don't print empty markup in archives if there's only one page.
		if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) )
			return;

		$nav_class = ( is_single() ) ? 'post-navigation' : 'paging-navigation';
		?>
		<nav role="navigation" id="<?php echo esc_attr( $nav_id ); ?>" class="<?php echo esc_attr( $nav_class ); ?>">
			<h1 class="screen-reader-text"><?php esc_html_e( 'Post navigation', 'economist' ); ?></h1>

			<?php if ( is_single() ) : // navigation links for single posts   ?>

				<?php previous_post_link( '<div class="nav-previous">%link</div>', '<span class="meta-nav">' . _x( '&larr;', 'Previous post link', 'economist' ) . '</span> %title' ); ?>
				<?php next_post_link( '<div class="nav-next">%link</div>', '%title <span class="meta-nav">' . _x( '&rarr;', 'Next post link', 'economist' ) . '</span>' ); ?>

			<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : // navigation links for home, archive, and search pages   ?>

				<?php if ( get_next_posts_link() ) : ?>
					<div class="nav-previous"><?php next_posts_link( wp_kses( __( '<span class="meta-nav">&larr;</span> Older posts', 'economist' ), $allowed_args ) ); ?></div>
				<?php endif; ?>

				<?php if ( get_previous_posts_link() ) : ?>
					<div class="nav-next"><?php previous_posts_link( wp_kses( __( 'Newer posts <span class="meta-nav">&larr;</span>', 'economist' ), $allowed_args ) ); ?></div>
				<?php endif; ?>

			<?php endif; ?>

		</nav>
		<?php
	}

endif; // economistcommercegurus_content_nav

if ( !function_exists( 'economistcommercegurus_comment' ) ) :

	/**
	 * Template for comments and pingbacks.
	 *
	 * Used as a callback by wp_list_comments() for displaying the comments.
	 */
	function economistcommercegurus_comment( $comment, $args, $depth ) {
		$allowed_args		 = array(
			//formatting
			'span' => array(
				'class' => array()
			),
		);
		$GLOBALS['comment']	 = $comment;

		if ( 'pingback' == $comment->comment_type || 'trackback' == $comment->comment_type ) :
			?>

			<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
				<div class="comment-body">
					<?php esc_html_e( 'Pingback:', 'economist' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( esc_html__( 'Edit', 'economist' ), '<span class="edit-link">', '</span>' ); ?>
				</div>

			<?php else : ?>

			<li id="comment-<?php comment_ID(); ?>" <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent'  ); ?>>
				<article id="div-comment-<?php comment_ID(); ?>" class="comment-body">
					<footer class="comment-meta">
						<div class="comment-author vcard">
							<?php if ( 0 != $args['avatar_size'] ) echo get_avatar( $comment, $args['avatar_size'] ); ?>
							<?php printf( wp_kses( '%s <span class="says">says:</span>', $allowed_args ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>

						</div><!-- .comment-author -->

						<div class="comment-metadata">
							<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
								<time datetime="<?php comment_time( 'c' ); ?>">
									<?php printf( _x( '%1$s at %2$s', '1: date, 2: time', 'economist' ), get_comment_date(), get_comment_time() ); ?>
								</time>
							</a>
							<?php edit_comment_link( esc_html__( 'Edit', 'economist' ), '<span class="edit-link">', '</span>' ); ?>
						</div><!-- .comment-metadata -->

						<?php if ( '0' == $comment->comment_approved ) : ?>
							<p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'economist' ); ?></p>
						<?php endif; ?>
					</footer><!-- .comment-meta -->

					<div class="comment-content">
						<?php comment_text(); ?>
					</div><!-- .comment-content -->

					<?php
					comment_reply_link( array_merge( $args, array(
						'add_below'	 => 'div-comment',
						'depth'		 => $depth,
						'max_depth'	 => $args['max_depth'],
						'before'	 => '<div class="reply">',
						'after'		 => '</div>',
					) ) );
					?>
				</article><!-- .comment-body -->

			<?php
			endif;
		}

	endif; // ends check for cg_comment()

	if ( !function_exists( 'economistcommercegurus_the_attached_image' ) ) :

		/**
		 * Prints the attached image with a link to the next attached image.
		 */
		function economistcommercegurus_the_attached_image() {
			$post				 = get_post();
			$attachment_size	 = apply_filters( 'economistcommercegurus_attachment_size', array( 1200, 1200 ) );
			$next_attachment_url = wp_get_attachment_url();

			/**
			 * Grab the IDs of all the image attachments in a gallery so we can get the
			 * URL of the next adjacent image in a gallery, or the first image (if
			 * we're looking at the last image in a gallery), or, in a gallery of one,
			 * just the link to that image file.
			 */
			$attachment_ids = get_posts( array(
				'post_parent'	 => $post->post_parent,
				'fields'		 => 'ids',
				'numberposts'	 => -1,
				'post_status'	 => 'inherit',
				'post_type'		 => 'attachment',
				'post_mime_type' => 'image',
				'order'			 => 'ASC',
				'orderby'		 => 'menu_order ID'
			) );

			// If there is more than 1 attachment in a gallery...
			if ( count( $attachment_ids ) > 1 ) {
				foreach ( $attachment_ids as $attachment_id ) {
					if ( $attachment_id == $post->ID ) {
						$next_id = current( $attachment_ids );
						break;
					}
				}

				// get the URL of the next image attachment...
				if ( $next_id )
					$next_attachment_url = get_attachment_link( $next_id );

				// or get the URL of the first image attachment.
				else
					$next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
			}

			printf( '<a href="%1$s" rel="attachment">%2$s</a>', esc_url( $next_attachment_url ), wp_get_attachment_image( $post->ID, $attachment_size )
			);
		}

	endif;

	/**
	 * Returns true if a blog has more than 1 category
	 */
	function economistcommercegurus_categorized_blog() {
		if ( false === ( $all_the_cool_cats = get_transient( 'all_the_cool_cats' ) ) ) {
			// Create an array of all the categories that are attached to posts
			$all_the_cool_cats = get_categories( array(
				'hide_empty' => 1,
			) );

			// Count the number of categories that are attached to the posts
			$all_the_cool_cats = count( $all_the_cool_cats );

			set_transient( 'all_the_cool_cats', $all_the_cool_cats );
		}

		if ( '1' != $all_the_cool_cats ) {
			// This blog has more than 1 category so economistcommercegurus_categorized_blog should return true
			return true;
		} else {
			// This blog has only 1 category so economistcommercegurus_categorized_blog should return false
			return false;
		}
	}

	/**
	 * Flush out the transients used in economistcommercegurus_categorized_blog
	 */
	function economistcommercegurus_category_transient_flusher() {
		// Like, beat it. Dig?
		delete_transient( 'all_the_cool_cats' );
	}

	add_action( 'edit_category', 'economistcommercegurus_category_transient_flusher' );
	add_action( 'save_post', 'economistcommercegurus_category_transient_flusher' );

	/* Responsive Images */

	add_filter( 'post_thumbnail_html', 'economistcommercegurus_remove_thumbnail_dimensions', 10 );
	add_filter( 'image_send_to_editor', 'economistcommercegurus_remove_thumbnail_dimensions', 10 );

	function economistcommercegurus_remove_thumbnail_dimensions( $html ) {
		$html = preg_replace( '/(width|height)=\"\d*\"\s/', "", $html );
		return $html;
	}

// Wraps a span around category widget count
	add_filter( 'wp_list_categories', 'economistcommercegurus_add_span_cat_count' );

	function economistcommercegurus_add_span_cat_count( $links ) {
		$links	 = str_replace( '</a> (', '</a> <span class="count">(', $links );
		$links	 = str_replace( ')', ')</span>', $links );
		return $links;
	}

// Wraps a span around archive widget count
	add_filter( 'get_archives_link', 'economistcommercegurus_archive_count_no_brackets' );

	function economistcommercegurus_archive_count_no_brackets( $links ) {
		$links	 = str_replace( '</a>&nbsp;', '</a><span class="count">', $links );
		$links	 = str_replace( '', '</span>', $links );
		return $links;
	}

	/* pagination */

	function economistcommercegurus_numeric_posts_nav() {

		if ( is_singular() ) {
			return;
		}

		global $wp_query;

		/** Stop execution if there's only 1 page */
		if ( $wp_query->max_num_pages <= 1 ) {
			return;
		}

		$paged	 = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
		$max	 = intval( $wp_query->max_num_pages );

		/** 	Add current page to the array */
		if ( $paged >= 1 )
			$links[] = $paged;

		/** 	Add the pages around the current page to the array */
		if ( $paged >= 3 ) {
			$links[] = $paged - 1;
			$links[] = $paged - 2;
		}

		if ( ( $paged + 2 ) <= $max ) {
			$links[] = $paged + 2;
			$links[] = $paged + 1;
		}

		echo '<div class="blog-pagination"><ul>' . "\n";

		/** 	Previous Post Link */
		if ( get_previous_posts_link() )
			printf( '<li class="prev">%s</li>' . "\n", get_previous_posts_link() );

		/** 	Link to first page, plus ellipses if necessary */
		if ( !in_array( 1, $links ) ) {
			$class = 1 == $paged ? ' class="active"' : '';

			printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( 1 ) ), '1' );

			if ( !in_array( 2, $links ) )
				echo '<li>…</li>';
		}

		/** 	Link to current page, plus 2 pages in either direction if necessary */
		sort( $links );
		foreach ( (array) $links as $link ) {
			$class = $paged == $link ? ' class="active"' : '';
			printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $link ) ), $link );
		}

		/** 	Link to last page, plus ellipses if necessary */
		if ( !in_array( $max, $links ) ) {
			if ( !in_array( $max - 1, $links ) )
				echo '<li>…</li>' . "\n";

			$class = $paged == $max ? ' class="active"' : '';
			printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $max ) ), $max );
		}

		/** 	Next Post Link */
		if ( get_next_posts_link() )
			printf( '<li class="next">%s</li>' . "\n", get_next_posts_link() );

		echo '</ul></div>' . "\n";
	}

// Display Header Cart
	if ( !function_exists( 'economistcommercegurus_header_cart' ) ) {

		function economistcommercegurus_header_cart() {
			if ( is_wc_active() ) {
				if ( is_cart() ) {
					$class = 'current-menu-item';
				} else {
					$class = '';
				}
				?>
				<ul class="cg-site-header-cart menu">
					<li class="<?php echo esc_attr( $class ); ?>">
						<?php economistcommercegurus_cart_link(); ?>
					</li>
					<?php the_widget( 'WC_Widget_Cart', 'title=' ); ?>
				</ul>
				<?php
			}
		}

	}


// Cart Link
	if ( !function_exists( 'economistcommercegurus_cart_link' ) ) {

		function economistcommercegurus_cart_link() {
			?>
			<a class="cart-contents" href="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" title="<?php esc_html_e( 'View your shopping cart', 'economist' ); ?>">
				<?php echo wp_kses_data( WC()->cart->get_cart_subtotal() ); ?> <span class="count"><?php echo wp_kses_data( sprintf( _n( '%d item', '%d items', WC()->cart->get_cart_contents_count(), 'economist' ), WC()->cart->get_cart_contents_count() ) ); ?></span>
			</a>
			<?php
		}

	}

// Cart Link
	if ( !function_exists( 'economistcommercegurus_cart_link_fragment' ) ) {

		function economistcommercegurus_cart_link_fragment( $fragments ) {
			global $woocommerce;

			ob_start();

			economistcommercegurus_cart_link();

			$fragments['a.cart-contents'] = ob_get_clean();

			return $fragments;
		}

	}

// Display product search
	if ( !function_exists( 'economistcommercegurus_product_search' ) ) {

		function economistcommercegurus_product_search() {
			if ( is_wc_active() ) {
				?>
				<div class="site-search">
					<?php the_widget( 'WC_Widget_Product_Search', 'title=' ); ?>
				</div>
				<?php
			}
		}

	}

// Display regular search
	if ( !function_exists( 'economistcommercegurus_search' ) ) {

		function economistcommercegurus_search() {
			?>
			<div class="site-search">
				<?php the_widget( 'WP_Widget_Search', 'title=' ); ?>
			</div>
			<?php
		}

	}


// Get Post Author
	if ( !function_exists( 'economistcommercegurus_get_author_name' ) ) {

		function economistcommercegurus_get_author_name( $format = 'span' ) {
			$economistcommercegurus_author_name = get_the_author();
			if ( $economistcommercegurus_author_name ) {
				if ( $format == 'plain' ) {
					echo wp_kses_post( $economistcommercegurus_author_name );
				} else {
					echo '<span class="cg-blog-author author vcard"> ' . wp_kses_post( $economistcommercegurus_author_name ) . ' </span>';
				}
			}
		}

	}


// Header hooks
// Header init
	add_action( 'economistcommercegurus_header_init', 'economistcommercegurus_header_init_callback' );
	if ( !function_exists( 'economistcommercegurus_header_init_callback' ) ) {

		function economistcommercegurus_header_init_callback() {
			$economistcommercegurus_protocol			 = ( is_ssl() ) ? "https:" : "http:";
			$economistcommercegurus_logo				 = '';
			$economistcommercegurus_preloader_status	 = '';
			$economistcommercegurus_topbar_display		 = '';
			$economistcommercegurus_topbar_display		 = economistcommercegurus_getoption( 'economistcommercegurus_topbar_display' );
			$economistcommercegurus_primary_menu_layout	 = '';
			$economistcommercegurus_primary_menu_layout	 = economistcommercegurus_getoption( 'economistcommercegurus_primary_menu_layout' );
			$economistcommercegurus_sticky_menu			 = '';
			$economistcommercegurus_sticky_menu			 = economistcommercegurus_getoption( 'economistcommercegurus_sticky_menu' );
			if ( !empty( $_SESSION['economistcommercegurus_header_top'] ) ) {
				$economistcommercegurus_topbar_display = $_SESSION['economistcommercegurus_header_top'];
			}
		}

	}


// Maybe responsive
	add_action( 'economistcommercegurus_maybe_responsive', 'economistcommercegurus_maybe_responsive_callback' );
	if ( !function_exists( 'economistcommercegurus_maybe_responsive_callback' ) ) {

		function economistcommercegurus_maybe_responsive_callback() {
			$economistcommercegurus_responsive_status	 = '';
			$economistcommercegurus_responsive_status	 = economistcommercegurus_getoption( 'economistcommercegurus_responsive' );
			if ( $economistcommercegurus_responsive_status == 'enabled' ) {
				echo '<meta name="viewport" content="width=device-width, initial-scale=1.0">';
			}
		}

	}


// Maybe preloader
	add_action( 'economistcommercegurus_maybe_preloader', 'economistcommercegurus_maybe_preloader_callback' );
	if ( !function_exists( 'economistcommercegurus_maybe_preloader_callback' ) ) {

		function economistcommercegurus_maybe_preloader_callback() {
			$economistcommercegurus_preloader	 = '';
			$economistcommercegurus_preloader	 = economistcommercegurus_getoption( 'economistcommercegurus_preloader' );
			if ( $economistcommercegurus_preloader !== 'disabled' ) {
				echo '<div class="cg-loader">
				<section class="mod model-1">
					<div class="spinner"></div></section>
			</div>';
			}
		}

	}


// Header layout
	add_action( 'economistcommercegurus_header_layout', 'economistcommercegurus_header_layout_callback' );
	if ( !function_exists( 'economistcommercegurus_header_layout_callback' ) ) {

		function economistcommercegurus_header_layout_callback() {
			$economistcommercegurus_logo_position	 = '';
			$economistcommercegurus_logo_position	 = economistcommercegurus_getoption( 'economistcommercegurus_logo_position' );
			if ( isset( $_GET['logo_position'] ) ) {
				$economistcommercegurus_logo_position = $_GET['logo_position'];
			}
			if ( $economistcommercegurus_logo_position == 'left' ) {
				get_template_part( 'partials/header', 'left' );
			} else {
				get_template_part( 'partials/header', 'left' );
			}
		}

	}


// Maybe mobile menu
	add_action( 'economistcommercegurus_maybe_mobile_menu', 'economistcommercegurus_maybe_mobile_menu_callback' );
	if ( !function_exists( 'economistcommercegurus_maybe_mobile_menu_callback' ) ) {

		function economistcommercegurus_maybe_mobile_menu_callback() {
			$economistcommercegurus_responsive_status	 = '';
			$economistcommercegurus_responsive_status	 = economistcommercegurus_getoption( 'economistcommercegurus_responsive' );
			if ( $economistcommercegurus_responsive_status !== 'disabled' ) {
				?>
				<div id="mobile-menu">
					<a id="skip" href="#cg-page-wrap" class="hidden" title="<?php esc_attr_e( 'Skip to content', 'economist' ); ?>"><?php esc_html_e( 'Skip to content', 'economist' ); ?></a> 
					<?php
					if ( function_exists( 'has_nav_menu' ) && has_nav_menu( 'mobile' ) ) {
						wp_nav_menu( array( 'theme_location' => 'mobile', 'container' => 'ul', 'menu_id' => 'mobile-cg-mobile-menu', 'menu_class' => 'mobile-menu-wrap', 'walker' => new economistcommercegurus_mobile_menu() ) );
					} elseif ( function_exists( 'has_nav_menu' ) && has_nav_menu( 'primary' ) ) {
						wp_nav_menu( array( 'theme_location' => 'primary', 'container' => 'ul', 'menu_id' => 'mobile-cg-primary-menu', 'menu_class' => 'mobile-menu-wrap', 'walker' => new economistcommercegurus_primary_menu() ) );
					}
					?>
				</div><!--/mobile-menu -->
				<?php
			}
		}

	}


// Footer actions
	add_action( 'economistcommercegurus_footer', 'economistcommercegurus_below_content_features', 10 );
	add_action( 'economistcommercegurus_footer', 'economistcommercegurus_first_footer', 20 );
	add_action( 'economistcommercegurus_footer', 'economistcommercegurus_second_footer', 30 );


// Below Content Features
	if ( !function_exists( 'economistcommercegurus_below_content_features' ) ) {

		function economistcommercegurus_below_content_features() {
			$economistcommercegurus_below_content_features_active	 = '';
			$economistcommercegurus_below_content_features_active	 = economistcommercegurus_getoption( 'economistcommercegurus_below_content_features_active' );

			$economistcommercegurus_show_below_content_features = '';
			if ( function_exists( 'get_field' ) ) {
				$economistcommercegurus_show_below_content_features = get_field( 'show_below_content_features' );
			}

			$economistcommercegurus_below_content_features_cols	 = '';
			$economistcommercegurus_below_content_features_cols	 = economistcommercegurus_getoption( 'economistcommercegurus_below_content_features_cols' );

			if ( $economistcommercegurus_below_content_features_active == 'yes' ) {
				if ( is_active_sidebar( 'below-content-features' ) ) {
					?>

					<?php if ( $economistcommercegurus_show_below_content_features !== 'Hide' ) { ?>

						<?php if ( $economistcommercegurus_below_content_features_cols == 'one' ) { ?>
							<div class="page-footer one-col">
							<?php } if ( $economistcommercegurus_below_content_features_cols == 'two' ) { ?>
								<div class="page-footer two-col">
								<?php } if ( $economistcommercegurus_below_content_features_cols == 'three' ) { ?>
									<div class="page-footer three-col">
									<?php } if ( $economistcommercegurus_below_content_features_cols == 'four' ) { ?>
										<div class="page-footer four-col">
										<?php } ?>
										<?php dynamic_sidebar( 'below-content-features' ); ?>   
									</div>

									<?php
								}
							}
							?>
							<?php
						}
					}

				}

// First footer
				if ( !function_exists( 'economistcommercegurus_first_footer' ) ) {

					function economistcommercegurus_first_footer() {
						$economistcommercegurus_footer_top_active	 = '';
						$economistcommercegurus_footer_top_active	 = economistcommercegurus_getoption( 'economistcommercegurus_footer_top_active' );

						$economistcommercegurus_first_footer_cols	 = '';
						$economistcommercegurus_first_footer_cols	 = economistcommercegurus_getoption( 'economistcommercegurus_first_footer_cols' );

						if ( $economistcommercegurus_footer_top_active == 'yes' ) {
							if ( is_active_sidebar( 'first-footer' ) ) {
								?>
								<?php if ( $economistcommercegurus_first_footer_cols == 'one' ) { ?>
									<div class="first-footer one-col">
									<?php } if ( $economistcommercegurus_first_footer_cols == 'two' ) { ?>
										<div class="first-footer two-col">
										<?php } if ( $economistcommercegurus_first_footer_cols == 'three' ) { ?>
											<div class="first-footer three-col">
											<?php } if ( $economistcommercegurus_first_footer_cols == 'four' ) { ?>
												<div class="first-footer four-col">
												<?php } ?>
												<div class="container">
													<div class="row">
														<?php dynamic_sidebar( 'first-footer' ); ?>   
													</div>
												</div>
											</div>
										<?php } ?>
										<?php
									}
								}

							}


// Second Footer
							if ( !function_exists( 'economistcommercegurus_second_footer' ) ) {

								function economistcommercegurus_second_footer() {
									$economistcommercegurus_footer_bottom_active = '';
									$economistcommercegurus_footer_bottom_active = economistcommercegurus_getoption( 'economistcommercegurus_footer_bottom_active' );

									if ( $economistcommercegurus_footer_bottom_active == 'yes' ) {
										if ( is_active_sidebar( 'second-footer' ) ) {
											?>
											<div class="second-footer">
												<div class="container">
													<div class="row">
														<?php dynamic_sidebar( 'second-footer' ); ?>   
													</div>
												</div>
											</div>
										<?php } ?>
										<?php
									}
								}

							}

// Footer util actions
							add_action( 'economistcommercegurus_footerutils', 'economistcommercegurus_back_to_top', 20 );
							add_action( 'economistcommercegurus_footerutils', 'economistcommercegurus_maybe_demo', 30 );


// Back to top
							if ( !function_exists( 'economistcommercegurus_back_to_top' ) ) {

								function economistcommercegurus_back_to_top() {
									$economistcommercegurus_back_to_top	 = '';
									$economistcommercegurus_back_to_top	 = economistcommercegurus_getoption( 'economistcommercegurus_back_to_top' );
									if ( $economistcommercegurus_back_to_top == 'yes' ) {
										?>
										<div class="container back-to-top">
											<div class="row">
												<a href="#0" class="cd-top">Top</a>
											</div>
										</div>
										<?php
									}
								}

							}

// Demo
							if ( !function_exists( 'economistcommercegurus_maybe_demo' ) ) {

								function economistcommercegurus_maybe_demo() {
									if ( economistcommercegurus_is_live_demo() ) {
										include_once( get_template_directory() . '/live-preview.php' );
									}
								}

							}

