<?php

/**
 * CommerceGurus functions and definitions
 * Maybe your best course would be to tread lightly.
 *
 * @package commercegurus
 */
function economistcommercegurus_getoption( $option, $fallback = false ) {
	global $economistcommercegurus_options;
	if ( $fallback == false ) {
		$fallback = '';
	}

	$output = ( isset( $economistcommercegurus_options[$option] ) && $economistcommercegurus_options[$option] !== '' ) ? $economistcommercegurus_options[$option] : $fallback;
	return $output;
}

/**
 * Global Paths
 */
define( 'economistcommercegurus_FILEPATH', get_template_directory() );
define( 'economistcommercegurus_THEMEURI', get_template_directory_uri() );
define( 'economistcommercegurus_BOOTSTRAP_JS', get_template_directory_uri() . '/inc/core/bootstrap/dist/js' );
define( 'economistcommercegurus_JS', get_template_directory_uri() . '/js' );
define( 'economistcommercegurus_CORE', get_template_directory() . '/inc/core' );


/**
 * Constants for Plugins
 */
define( 'ULTIMATE_USE_BUILTIN', true );


/**
 * Load Globals
 */
require_once( economistcommercegurus_CORE . '/functions/javascript.php' );
require_once( economistcommercegurus_CORE . '/functions/get-the-image.php' );
require_once( economistcommercegurus_CORE . '/menus/wp_bootstrap_navwalker.php' );
require_once( economistcommercegurus_CORE . '/menus/megadropdown.php' );


/**
 * TGM Plugin Activation
 */
require_once ( economistcommercegurus_CORE . '/functions/class-tgm-plugin-activation.php' );
add_action( 'tgmpa_register', 'economistcommercegurus_register_required_plugins' );

function economistcommercegurus_register_required_plugins() {

	/**
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(
		array(
			'name'		 => esc_html__( 'One Click Demo Import', 'economist' ), // The plugin name
			'slug'		 => 'one-click-demo-import', // The plugin slug (typically the folder name)
			'required'	 => false, // If false, the plugin is only 'recommended' instead of required
		),
		array(
			'name'		 => esc_html__( 'Advanced Custom Fields', 'economist' ), // The plugin name
			'slug'		 => 'advanced-custom-fields', // The plugin slug (typically the folder name)
			'required'	 => true, // If false, the plugin is only 'recommended' instead of required
		),
		array(
			'name'		 => esc_html__( 'Advanced Sidebar Menu', 'economist' ), // The plugin name
			'slug'		 => 'advanced-sidebar-menu', // The plugin slug (typically the folder name)
			'required'	 => false, // If false, the plugin is only 'recommended' instead of required
		),
		array(
			'name'		 => esc_html__( 'Redux Framework', 'economist' ), // The plugin name
			'slug'		 => 'redux-framework', // The plugin slug (typically the folder name)
			'required'	 => true, // If false, the plugin is only 'recommended' instead of required
		),
		array(
			'name'				 => esc_html__( 'Layer Slider', 'economist' ), // The plugin name
			'slug'				 => 'LayerSlider', // The plugin slug (typically the folder name)
			'source'			 => 'http://files.commercegurus.com/layersliderwp-6.1.0.installable.zip', // The plugin source
			'required'			 => false, // If false, the plugin is only 'recommended' instead of required
			'version'			 => '6.1.0', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
			'force_activation'	 => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
			'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
			'external_url'		 => '', // If set, overrides default API URL and points to an external URL
		),
		array(
			'name'				 => esc_html__( 'WPBakery Visual Composer', 'economist' ), // The plugin name
			'slug'				 => 'js_composer', // The plugin slug (typically the folder name)
			'source'			 => 'http://files.commercegurus.com/js_composer_5.0.1/js_composer.zip', // The plugin source
  			'required'			 => false, // If false, the plugin is only 'recommended' instead of required
			'version'			 => '5.0.1', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
			'force_activation'	 => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
			'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
			'external_url'		 => '', // If set, overrides default API URL and points to an external URL
		),
		array(
			'name'				 => esc_html__( 'CommerceGurus Toolkit', 'economist' ), // The plugin namename
			'slug'				 => 'commercegurus-toolkit', // The plugin slug (typically the folder name)
			'source'			 => get_template_directory_uri() . '/inc/plugins/commercegurus-toolkit.zip', // The plugin source
			'required'			 => true, // If false, the plugin is only 'recommended' instead of required
			'version'			 => '1.5', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
			'force_activation'	 => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
			'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
			'external_url'		 => '', // If set, overrides default API URL and points to an external URL
		),
		array(
			'name'		 => esc_html__( 'Contact Form 7', 'economist' ), // The plugin name
			'slug'		 => 'contact-form-7', // The plugin slug (typically the folder name)
			'required'	 => false, // If false, the plugin is only 'recommended' instead of required
		),
		array(
			'name'		 => esc_html__( 'MailChimp for WordPress', 'economist' ), // The plugin name
			'slug'		 => 'mailchimp-for-wp', // The plugin slug (typically the folder name)
			'required'	 => false, // If false, the plugin is only 'recommended' instead of required
		),
		array(
			'name'		 => esc_html__( 'Yoast SEO', 'economist' ), // The plugin name
			'slug'		 => 'wordpress-seo', // The plugin slug (typically the folder name)
			'required'	 => false, // If false, the plugin is only 'recommended' instead of required
		),
		array(
			'name'		 => esc_html__( 'Widget CSS Classes', 'economist' ), // The plugin name
			'slug'		 => 'widget-css-classes', // The plugin slug (typically the folder name)
			'required'	 => false, // If false, the plugin is only 'recommended' instead of required
		),
	);

	/**
	 * Array of configuration settings. Amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * leave the strings uncommented.
	 * Some of the strings are added into a sprintf, so see the comments at the
	 * end of each line for what each argument will be.
	 */
	$config = array(
		'domain'		 => 'economist', // Text domain - likely want to be the same as your theme.
		'default_path'	 => '', // Default absolute path to pre-packaged plugins
		'parent_slug'	 => 'themes.php', // Default parent menu slug
		'menu'			 => 'tgmpa-install-plugins', // Menu slug
		'has_notices'	 => true, // Show admin notices or not
		'is_automatic'	 => false, // Automatically activate plugins after installation or not
		'message'		 => '', // Message to output right before the plugins table
		'strings'		 => array(
			'page_title'						 => esc_html__( 'Install Required Plugins', 'economist' ),
			'menu_title'						 => esc_html__( 'Install Plugins', 'economist' ),
			'installing'						 => esc_html__( 'Installing Plugin: %s', 'economist' ), // %1$s = plugin name
			'oops'								 => esc_html__( 'Something went wrong with the plugin API.', 'economist' ),
			'notice_can_install_required'		 => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'economist' ), // %1$s = plugin name(s)
			'notice_can_install_recommended'	 => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'economist' ), // %1$s = plugin name(s)
			'notice_cannot_install'				 => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'economist' ), // %1$s = plugin name(s)
			'notice_can_activate_required'		 => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'economist' ), // %1$s = plugin name(s)
			'notice_can_activate_recommended'	 => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'economist' ), // %1$s = plugin name(s)
			'notice_cannot_activate'			 => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'economist' ), // %1$s = plugin name(s)
			'notice_ask_to_update'				 => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'economist' ), // %1$s = plugin name(s)
			'notice_cannot_update'				 => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'economist' ), // %1$s = plugin name(s)
			'install_link'						 => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'economist' ),
			'activate_link'						 => _n_noop( 'Activate installed plugin', 'Activate installed plugins', 'economist' ),
			'return'							 => esc_html__( 'Return to Required Plugins Installer', 'economist' ),
			'plugin_activated'					 => esc_html__( 'Plugin activated successfully.', 'economist' ),
			'complete'							 => esc_html__( 'All plugins installed and activated successfully. %s', 'economist' ), // %1$s = dashboard link
			'nag_type'							 => 'updated' // Determines admin notice type - can only be 'updated' or 'error'
		)
	);

	tgmpa( $plugins, $config );
}

/**
 * Live Preview
 */
if ( !defined( 'economistcommercegurus_LIVEDEMO' ) ) {
	define( 'economistcommercegurus_LIVEDEMO', false );
}

function economistcommercegurus_is_live_demo() {
	if ( economistcommercegurus_LIVEDEMO ) {
		return true;
	} else {
		return false;
	}
}

if ( economistcommercegurus_is_live_demo() ) {

	add_action( 'after_setup_theme', 'economistcommercegurus_start_live_session', 1 );
	add_action( 'wp_logout', 'economistcommercegurus_end_live_session' );
	add_action( 'wp_login', 'economistcommercegurus_end_live_session' );

	//start live session
	if ( !function_exists( 'economistcommercegurus_start_live_session' ) ) {

		function economistcommercegurus_start_live_session() {
			if ( !session_id() ) {
				session_start();
			}
		}

	}

	//end live session 
	if ( !function_exists( 'economistcommercegurus_end_live_session' ) ) {

		function economistcommercegurus_end_live_session() {
			session_destroy();
		}

	}
}

/**
 * Load CSS
 */
function economistcommercegurus_load_styles() {

	$economistcommercegurus_responsive_status	 = '';
	$economistcommercegurus_responsive_status	 = economistcommercegurus_getoption( 'economistcommercegurus_responsive' );

	wp_register_style( 'bootstrap', get_template_directory_uri() . '/inc/core/bootstrap/dist/css/bootstrap.min.css' );
	wp_register_style( 'economistcommercegurus-commercegurus', get_template_directory_uri() . '/css/commercegurus.css' );

	if ( $economistcommercegurus_responsive_status !== 'disabled' ) {
		wp_register_style( 'economistcommercegurus-responsive', get_template_directory_uri() . '/css/responsive.css' );
	}

	if ( $economistcommercegurus_responsive_status == 'disabled' ) {
		wp_register_style( 'economistcommercegurus-non-responsive', get_template_directory_uri() . '/css/non-responsive.css' );
	}

	wp_enqueue_style( 'economistcommercegurus-style', get_stylesheet_uri() );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome/font-awesome.min.css' );
	wp_enqueue_style( 'ionicons', get_template_directory_uri() . '/css/ionicons.css' );
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/css/animate.css' );
	wp_enqueue_style( 'bootstrap' );
	wp_enqueue_style( 'economistcommercegurus-commercegurus' );

	if ( $economistcommercegurus_responsive_status !== 'disabled' ) {
		wp_enqueue_style( 'economistcommercegurus-responsive' );
	}

	if ( $economistcommercegurus_responsive_status == 'disabled' ) {
		wp_enqueue_style( 'economistcommercegurus-non-responsive' );
	}

	if ( economistcommercegurus_is_live_demo() ) {
		wp_enqueue_style( 'economistcommercegurus-livepreviewcss', get_template_directory_uri() . '/css/livepreview.css' );
	}

	// skins
	$cg_skin_color	 = '';
	$cg_skin_color	 = economistcommercegurus_getoption( 'economistcommercegurus_skin_color' );

	if ( !empty( $_SESSION['economistcommercegurus_skin_color'] ) ) {
		$cg_skin_color = $_SESSION['economistcommercegurus_skin_color'];
	}

	if ( !empty( $cg_skin_color ) ) {
		if ( $cg_skin_color !== 'none' ) {
			wp_enqueue_style( 'economistcommercegurus-cssskin', get_template_directory_uri() . '/css/skins/' . $cg_skin_color . '.css' );
		}
	}
}

add_action( 'wp_enqueue_scripts', 'economistcommercegurus_load_styles' );

// Load css from theme options.
require_once( economistcommercegurus_CORE . '/css/custom-css.php' );

/**
 * Maybe load js
 */
function economistcommercegurus_maybe_load_scripts() {

	$economistcommercegurus_sticky_menu		 = '';
	$economistcommercegurus_display_search	 = '';
	$economistcommercegurus_sticky_menu		 = economistcommercegurus_getoption( 'economistcommercegurus_sticky_menu' );

	if ( $economistcommercegurus_sticky_menu == '1' ) {
		wp_enqueue_script( 'economistcommercegurus_scrollfix', economistcommercegurus_JS . '/src/cond/scrollfix.js', array( 'jquery' ), '', false );
	}

	$economistcommercegurus_display_search = economistcommercegurus_getoption( 'economistcommercegurus_show_search' );
}

add_action( 'wp_enqueue_scripts', 'economistcommercegurus_maybe_load_scripts' );


/**
 * Force Visual Composer to initialize as "built into the theme". This will hide certain tabs under the Settings->Visual Composer page
 */
if ( function_exists( 'vc_set_as_theme' ) ) {
	vc_set_as_theme( $disable_updater = true );

	// Disable frontend editor by default - to re-enable just comment out the next line
	vc_disable_frontend();
}

// Initialising Shortcodes
if ( class_exists( 'WPBakeryVisualComposerAbstract' ) ) {

	function economistcommercegurus_requireVcExtend() {
		require_once locate_template( '/customvc/vc_extend.php' );
	}

	add_action( 'init', 'economistcommercegurus_requireVcExtend', 2 );

	// Set VC tpl override directory
	$vcdir = get_stylesheet_directory() . '/customvc/vc_templates/';
	vc_set_shortcodes_templates_dir( $vcdir );


	// Remove VC nag looking for key - CommerceGurus has an extended lic.

	if ( is_admin() ) {

		function economistcommercegurus_remove_vc_nag() {
			setcookie( 'vchideactivationmsg_vc11', ( defined( 'WPB_VC_VERSION' ) ? WPB_VC_VERSION : '1' ), strtotime( '+3 years' ), '/' );
		}

		add_action( 'init', 'economistcommercegurus_remove_vc_nag' );
	}
}


/**
 * Sets up theme defaults and registers support for various WordPress features.
 */
if ( !function_exists( 'economistcommercegurus_setup' ) ) :

	function economistcommercegurus_setup() {

		/**
		 * Translations can be filed in the /languages/ directory
		 * If you're building a theme based on a commercegurus theme, use a find and replace
		 * to change 'economist' to the name of your theme in all the template files
		 */
		load_theme_textdomain( 'economist', get_template_directory() . '/languages' );

		/**
		 * Add default posts and comments RSS feed links to head
		 */
		add_theme_support( 'automatic-feed-links' );

		/**
		 * This theme uses wp_nav_menu() in one location.
		 */
		register_nav_menus( array(
			'primary' => esc_html__( 'Main Menu', 'economist' ),
		) );

		/**
		 * Infinite Scroll Support via Jetpack
		 */
		function economistcommercegurus_infinite_scroll_supported() {
			return current_theme_supports( 'infinite-scroll' ) && ( is_home() || is_archive() || is_search() ) && !( is_post_type_archive( 'product' ) || is_tax( 'product_cat' ) || is_tax( 'product_tag' ) );
		}

		add_filter( 'infinite_scroll_archive_supported', 'economistcommercegurus_infinite_scroll_supported' );

		add_theme_support( 'infinite-scroll', array(
			'container'	 => 'primary',
			'type'		 => 'click',
			'footer'	 => 'page',
		) );

		/**
		 * Custom Thumbnails
		 */
		if ( function_exists( 'add_theme_support' ) ) {
			add_theme_support( 'post-thumbnails' );
			add_image_size( 'economistcommercegurus-hp-latest-posts', 380, 250, true );
		}

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/**
		 * Enable support for Post Formats
		 */
		add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'audio', 'quote', 'link' ) );
	}

endif; // cg_setup
add_action( 'after_setup_theme', 'economistcommercegurus_setup' );


/**
 * Add Redux Framework
 */
require_once get_template_directory() . '/admin/options-init.php';


/**
 * Prevent HTML from being stripped within the WordPress Menu Description Field
 * @param string $menu the current menu HTML
 * @return string the modified menu HTML
 */
remove_filter( 'nav_menu_description', 'strip_tags' );

/**
 * Set WooCommerce image dimensions upon activation
 */
global $pagenow;
if ( is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' )
	add_action( 'init', 'economistcommercegurus_woocommerce_image_dimensions', 1 );

/**
 * Define image sizes
 */
function economistcommercegurus_woocommerce_image_dimensions() {
	$catalog = array(
		'width'	 => '300', // px
		'height' => '390', // px
		'crop'	 => 1  // true
	);

	$single = array(
		'width'	 => '500', // px
		'height' => '650', // px
		'crop'	 => 1  // true
	);

	$thumbnail = array(
		'width'	 => '120', // px
		'height' => '155', // px
		'crop'	 => 1  // false
	);

	// Image sizes
	update_option( 'shop_catalog_image_size', $catalog ); // Product category thumbs
	update_option( 'shop_single_image_size', $single );   // Single product image
	update_option( 'shop_thumbnail_image_size', $thumbnail );   // Image gallery thumbs
}

/**
 * Register widgetized area and update sidebar with default widgets
 */
function economistcommercegurus_widgets_init() {

	register_sidebar( array(
		'name'			 => esc_html__( 'Sidebar', 'economist' ),
		'id'			 => 'sidebar-1',
		'description'	 => esc_html__( 'The main sidebar used in most places by default', 'economist' ),
		'before_widget'	 => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	 => '</aside>',
		'before_title'	 => '<h4 class="widget-title"><span>',
		'after_title'	 => '</span></h4>',
	) );

	register_sidebar( array(
		'name'			 => esc_html__( 'Pages Sidebar', 'economist' ),
		'id'			 => 'sidebar-pages',
		'description'	 => esc_html__( 'Sidebar for pages', 'economist' ),
		'before_widget'	 => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	 => '</aside>',
		'before_title'	 => '<h4 class="widget-title"><span>',
		'after_title'	 => '</span></h4>',
	) );

	register_sidebar( array(
		'name'			 => esc_html__( 'Shop Sidebar', 'economist' ),
		'id'			 => 'shop-sidebar',
		'description'	 => esc_html__( 'Sidebar for shop pages', 'economist' ),
		'before_widget'	 => '<div id="%1$s" class="widget %2$s">',
		'after_widget'	 => '</div>',
		'before_title'	 => '<h4 class="widget-title"><span>',
		'after_title'	 => '</span></h4>',
	) );

	register_sidebar( array(
		'name'			 => esc_html__( 'Mobile Search', 'economist' ),
		'id'			 => 'mobile-search',
		'description'	 => esc_html__( 'Mobile/smartphone search widget area', 'economist' ),
		'before_widget'	 => '<div id="%1$s" class="%2$s">',
		'after_widget'	 => '</div>',
		'before_title'	 => '<h4 class="widget-title"><span>',
		'after_title'	 => '</span></h4>',
	) );

	register_sidebar( array(
		'name'			 => esc_html__( 'Below Content Features', 'economist' ),
		'id'			 => 'below-content-features',
		'description'	 => esc_html__( 'Features that appear below the content', 'economist' ),
		'before_widget'	 => '<div class="footer-nav below-content-column">',
		'after_widget'	 => '</div>',
		'before_title'	 => '<h4><span>',
		'after_title'	 => '</span></h4>',
	) );

	register_sidebar( array(
		'name'			 => esc_html__( 'First Footer', 'economist' ),
		'id'			 => 'first-footer',
		'description'	 => esc_html__( 'First row of footer widgets', 'economist' ),
		'before_widget'	 => '<div class="%2$s footer-column">',
		'after_widget'	 => '</div>',
		'before_title'	 => '<h4><span>',
		'after_title'	 => '</span></h4>',
	) );

	register_sidebar( array(
		'name'			 => esc_html__( 'Second Footer', 'economist' ),
		'id'			 => 'second-footer',
		'description'	 => esc_html__( 'Second row of footer widgets', 'economist' ),
		'before_widget'	 => '<div class="%2$s footer-column">',
		'after_widget'	 => '</div>',
		'before_title'	 => '<h4 class="widget-title"><span>',
		'after_title'	 => '</span></h4>',
	) );
}

add_action( 'widgets_init', 'economistcommercegurus_widgets_init' );


// Remove certain custom post types from the CG Toolkit
if ( !function_exists( 'economistcommercegurus_unregister_announcements' ) ) :

	function economistcommercegurus_unregister_announcements() {
		global $wp_post_types;
		if ( isset( $wp_post_types['shopannouncements'] ) ) {
			unset( $wp_post_types['shopannouncements'] );
			return true;
		}
		return false;
	}

endif;

if ( !function_exists( 'economistcommercegurus_unregister_testimonials' ) ) :

	function economistcommercegurus_unregister_testimonials() {
		global $wp_post_types;
		if ( isset( $wp_post_types['testimonials'] ) ) {
			unset( $wp_post_types['testimonials'] );
			return true;
		}
		return false;
	}

endif;

if ( !function_exists( 'economistcommercegurus_unregister_topreviews' ) ) :

	function economistcommercegurus_unregister_topreviews() {
		global $wp_post_types;
		if ( isset( $wp_post_types['topreviews'] ) ) {
			unset( $wp_post_types['topreviews'] );
			return true;
		}
		return false;
	}

endif;

if ( !function_exists( 'economistcommercegurus_unregister_showcases' ) ) :

	function economistcommercegurus_unregister_showcases() {
		global $wp_post_types;
		if ( isset( $wp_post_types['showcases'] ) ) {
			unset( $wp_post_types['showcases'] );
			return true;
		}
		return false;
	}

endif;

if ( !function_exists( 'economistcommercegurus_unregister_projects' ) ) :

	function economistcommercegurus_unregister_projects() {
		global $wp_post_types;
		if ( isset( $wp_post_types['project'] ) ) {
			unset( $wp_post_types['project'] );
			return true;
		}
		return false;
	}

endif;

add_action( 'init', 'economistcommercegurus_unregister_announcements', 100 );
add_action( 'init', 'economistcommercegurus_unregister_testimonials', 100 );
add_action( 'init', 'economistcommercegurus_unregister_topreviews', 100 );
add_action( 'init', 'economistcommercegurus_unregister_showcases', 100 );
add_action( 'init', 'economistcommercegurus_unregister_projects', 100 );

add_filter( 'wpseo_breadcrumb_output', 'mc_microdata_breadcrumb' );

function mc_microdata_breadcrumb( $link_output ) {
	$link_output = preg_replace( array( '#<span xmlns:v="http://rdf.data-vocabulary.org/\#">#', '#<span typeof="v:Breadcrumb"><a href="(.*?)" .*?' . '>(.*?)</a></span>#', '#<span typeof="v:Breadcrumb">(.*?)</span>#', '# property=".*?"#', '#</span>$#' ), array( '', '<span itemscope itemtype="http://data-vocabulary.org/Breadcrumb"><a href="$1" itemprop="url"><span itemprop="title">$2</span></a></span>', '<span itemscope itemtype="http://data-vocabulary.org/Breadcrumb"><span itemprop="title">$1</span></span>', '', '' ), $link_output );
	return $link_output;
}

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';


/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';


/**
 * Demo Data Initialize.
 */
add_filter( 'pt-ocdi/import_files', 'economistcommercegurus_demo_import' );
add_action( 'pt-ocdi/after_import', 'economistcommercegurus_after_demo_import_setup' );

/**
 * Define demo import files for One Click Demo Import plugin.
 */
function economistcommercegurus_demo_import() {
	return array(
		array(
			'import_file_name'		 => 'Main Economist Import',
			'import_file_url'		 => 'http://themedemo.commercegurus.com/economist/wp-content/uploads/sites/2/2016/11/content.xml',
			'import_widget_file_url' => 'http://themedemo.commercegurus.com/economist/wp-content/uploads/sites/2/2016/11/widgets.wie'
		),
	);
}

function economistcommercegurus_after_demo_import_setup() {

	// Menus to Import and assign.
	$main_menu = get_term_by( 'name', 'Main Menu', 'nav_menu' );
	set_theme_mod( 'nav_menu_locations', array(
		'primary' => $main_menu->term_id,
	)
	);

	// Set options for front page and blog page.
	$front_page_id	 = get_page_by_title( 'Home' );
	$blog_page_id	 = get_page_by_title( 'News' );

	update_option( 'show_on_front', 'page' );
	update_option( 'page_on_front', $front_page_id->ID );
	update_option( 'page_for_posts', $blog_page_id->ID );

	esc_html_e( 'After import setup ended!', 'economist' );
}

/**
 * Adds a body class if a featured image is present
 */
function economistcommercegurus_featured_image_body_class( $classes ) {
	global $post;

	if ( isset( $post->ID ) && get_the_post_thumbnail( $post->ID ) ) {
		$classes[] = 'has-featured-image';
	}

	return $classes;
}

add_filter( 'body_class', 'economistcommercegurus_featured_image_body_class' );


/* WooCommerce */

/* ----------------------------------------------------------------------------------- */
/* Start WooThemes Functions - Please refrain from editing this section */
/* ----------------------------------------------------------------------------------- */

// Custom function to check if WooCommerce is active - support for WPMU

if ( !function_exists( 'is_wc_active' ) ) {

	function is_wc_active() {
		if ( class_exists( 'woocommerce' ) ) {
			return true;
		} else {
			return false;
		}
	}

}

/**
 * Load WooCommerce Config.
 */
if ( is_wc_active() ) {
	require get_template_directory() . '/inc/woocommerce/hooks.php';
	require get_template_directory() . '/inc/woocommerce/functions.php';
}

// Custom function to check if WooCommerce is active and is the shop page

if ( !function_exists( 'is_wc_shop' ) ) {

	function is_wc_shop() {
		if ( class_exists( 'woocommerce' ) ) {
			if ( is_shop() ) {
				return true;
			} else {
				return false;
			}
		} else {
			return false;
		}
	}

}


// Register Support
add_theme_support( 'woocommerce' );

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( !isset( $content_width ) )
	$content_width = 640; /* pixels */

// End of core functions.