<?php

/**
 * importer field extension class.
 *
 * @version     1.0.0
 */
/* exit if accessed directly. */
if (!defined('ABSPATH'))
    exit;

/* don't duplicate me! */
if (!class_exists('ReduxFramework_extension_importer')) {


    /**
     *  ReduxFramework_extension_importer class.
     *
     * @since       1.0.0
     */
    class ReduxFramework_extension_importer extends ReduxFramework
    {

        /**
         * @access      protected
         * @since       1.0.0
         * @var         array $parent ReduxFramework object
         */
        protected $parent;

        /**
         * @access      public
         * @static
         * @since       1.0.0
         * @var         object $instance singleton instance
         */
        public static $instance;

        /**
         * class Constructor - defines the args for the extions class.
         *
         * @access      public
         * @since       1.0.0
         * @param       array $sections panel sections
         * @param       array $args panel arguments
         * @param       array $extra_tabs extra panel tabs
         * @return      void
         */
        public $h;

        public function __construct($parent)
        {
            $h = new provide_Helper;
            $this->parent = $parent;
            $this->field_name = 'importer';

            if (!isset(self::$instance)) {
                self::$instance = $this;
            }

            /* implement custom field. */
            add_filter('redux/' . $this->parent->args['opt_name'] . '/field/class/' . $this->field_name, array($this, 'overload_field_path'));
            $this->redux_importer_section();
            add_action('wp_ajax_nopriv_provide_demoImporter', array($this, 'provide_demoImporter'));
            add_action('wp_ajax_provide_demoImporter', array($this, 'provide_demoImporter'));
        }

        /* __construct() */

        /**
         * get singleton instance.
         *
         * @access      public
         * @static
         * @since       1.0.0
         * @return      object      $instance       singleton instance
         */
        public static function getInstance()
        {

            if (!isset(self::$instance)) {

                /* instance class. */
                self::$instance = new self;
            }

            return self::$instance;
        }

        /* get_instance() */

        /**
         * implement custom field.
         *
         * @access      public
         * @static
         * @since       1.0.0
         * @return      object      $instance       singleton instance
         */
        public function overload_field_path($field)
        {
            return Plugin_ROOT . 'panel/redux-extensions/extensions/' . $this->field_name . '/' . $this->field_name . '.php';
        }

        /* overload_field_path() */

        public function redux_importer_section()
        {
            for ($n = 0; $n <= count($this->parent->sections); $n++) {
                if (isset($this->parent->sections[$n]['id']) && $this->parent->sections[$n]['id'] == 'redux_importer_section') {
                    return;
                }
            }

            $redux_importer_label = trim(esc_html(apply_filters('wp_importer_label', esc_html__('Demo Importer', 'provide'))));
            $redux_importer_label = (!empty($wbc_importer_label)) ? $redux_importer_label : esc_html__('Demo Importer', 'provide');
            $section = array(
                'id' => 'redux_importer_section',
                'title' => $redux_importer_label,
                'desc' => esc_html__('one click demo importer', 'provide'),
                'icon' => 'el-icon-website',
                'fields' => array(
                    array(
                        'id' => 'redux_importer',
                        'type' => 'importer',
                        'full_width' => true,
                    )
                )
            );
            $this->parent->sections[] = $section;
        }

        public function provide_demoImporter()
        {
            if (isset($_POST) && $_POST['action'] == 'provide_demoImporter') {
                $ext = get_loaded_extensions();
                $demoUrl = provide_set($_POST, 'uri');
                $filePath = ABSPATH . 'wp-content/provide/';

                // create empty directory
                if (!is_dir($filePath)) {
                    mkdir($filePath);
                }

                // check revolution slide is active or not
                if (!function_exists('rev_slider_shortcode')) {
                    wp_send_json(array('status' => false, 'msg' => esc_html__('Please Active Revolution Slider Plugin From Plugin Menu')));
                }

                // check visual composer is active or not
                if (!function_exists('vc_map')) {
                    wp_send_json(array('status' => false, 'msg' => esc_html__('Please Active Visual Composer Plugin From Plugin Menu')));
                }

                // delete upload directory
//                if (is_dir(ABSPATH . 'wp-content/uploads')) {
//                    $this->provide_delete(ABSPATH . 'wp-content/uploads');
//                }

                // download demo zip file
                if (in_array('curl', $ext)) {
                    if ($this->urlExists($filePath) === true) {
                        if (!file_exists($filePath . 'demo.zip')) {
                            $this->downloadFile($demoUrl, $filePath . 'demo.zip');
                        }
                        if (in_array('zip', $ext)) {

                            // extract main demo file
                            $zip = new ZipArchive;
                            if ($zip->open(ABSPATH . 'wp-content/provide/demo.zip') === TRUE) {
                                $zip->extractTo(ABSPATH . 'wp-content/provide/');
                                $zip->close();
                                unlink(ABSPATH . 'wp-content/provide/demo.zip');

                                // extract upload file
                                if ($zip->open(ABSPATH . 'wp-content/provide/uploads.zip') === TRUE) {
                                    $zip->extractTo(ABSPATH . 'wp-content/uploads/');
                                    $zip->close();
                                    unlink(ABSPATH . 'wp-content/provide/uploads.zip');
                                } else {
                                    wp_send_json(array('status' => false, 'msg' => esc_html__('There is some error to extract Upload File', 'provide')));
                                }

                                // run xml demo importer
                                if (file_exists(ABSPATH . 'wp-content/provide/demo.xml')) {
                                    define('WP_LOAD_IMPORTERS', true);
                                    if (!class_exists('WP_Import')) {
                                        require_once Plugin_ROOT . 'wordpress-importer/wordpress-importer.php';
                                    }
                                    $content_xml = ABSPATH . 'wp-content/provide/demo.xml';
                                    if (!is_file($content_xml)) {
                                        wp_send_json(array('status' => false, 'msg' => esc_html__('XML file not present.', 'provide')));
                                    } else {

                                        $importer = new WP_Import();
                                        $importer->fetch_attachments = true;
                                        ob_start();
                                        $importer->import($content_xml);
                                        $result = ob_get_contents();
                                        ob_end_clean();

                                        // set theme options and other settings
                                        include_once Plugin_ROOT . 'import_export.php';
                                        $themeSettings = new provide_import_export();
                                        $themeSettings->provide_import();

                                        // delete provide folder and files
                                        if (is_dir(ABSPATH . 'wp-content/provide')) {
                                            $this->provide_delete(ABSPATH . 'wp-content/provide');
                                        }
                                        wp_send_json(array('status' => true, 'msg' => $result));
                                    }
                                }
                            } else {
                                wp_send_json(array('status' => false, 'msg' => esc_html__('There is some error to extract Demo File', 'provide')));
                            }
                        } else {
                            wp_send_json(array('status' => false, 'msg' => esc_html('Zip Library is not enable, Please contact your Hosting provide to enable zip library.', 'provide')));
                        }
                    } else {
                        wp_send_json(array('status' => false, 'msg' => esc_html('Demo File not present, Please contact Theme Author', 'provide')));
                    }
                } else {
                    wp_send_json(array('status' => false, 'msg' => esc_html('CURL Library is not enable, Please contact your Hosting provide to enable CURL library.', 'provide')));
                }
            }
        }

        public function provide_delete($path)
        {
            if (is_dir($path) === true) {
                $files = array_diff(scandir($path), array('.', '..'));
                foreach ($files as $file) {
                    $this->provide_delete(realpath($path) . '/' . $file);
                }
                return rmdir($path);
            } else if (is_file($path) === true) {
                return unlink($path);
            }
            return false;
        }

        public function downloadFile($url, $path)
        {
            $newfname = $path;
            $file = fopen($url, 'rb');
            if ($file) {
                $newf = fopen($newfname, 'wb');
                if ($newf) {
                    while (!feof($file)) {
                        fwrite($newf, fread($file, 1024 * 8), 1024 * 8);
                    }
                }
            }
            if ($file) {
                fclose($file);
            }
            if ($newf) {
                fclose($newf);
            }
        }

        public function urlExists($url)
        {
            if (!$url) {
                return FALSE;
            }
            $curl_resource = curl_init($url);
            curl_setopt($curl_resource, CURLOPT_RETURNTRANSFER, true);
            curl_exec($curl_resource);
            if (curl_getinfo($curl_resource, CURLINFO_HTTP_CODE) == 404) {
                curl_close($curl_resource);
                return FALSE;
            } else {
                curl_close($curl_resource);
                return TRUE;
            }
            return FALSE;
        }
    }

    /* class */
}

/* if */
	