<?php
/**
 * @package   Revolution Slider
 * @author    ThemePunch <info@themepunch.com>
 * @link      http://revolution.themepunch.com/
 * @copyright 2015 ThemePunch
 */
 
if( !defined( 'ABSPATH') ) exit();

class RevSliderNavigation {
	
	public function __construct(){
		
	}
	
	
	public function init_by_id($nav_id){
		if(intval($nav_id) == 0) return false;
		
		global $wpdb;
		
		$row = $wpdb->get_row($wpdb->prepare("SELECT `id`, `handle`, `type`, `css`, `settings` FROM ".$wpdb->prefix.RevSliderGlobals::TABLE_NAVIGATION_NAME." WHERE `id` = %d", $nav_id), ARRAY_A);
		
		return $row;
		
	}
	
	
	/**
	 * Get all Navigations Short
	 * @since: 5.0
	 **/
	public static function get_all_navigations_short(){
		global $wpdb;
		
		$navigations = $wpdb->get_results("SELECT `id`, `handle`, `name` FROM ".$wpdb->prefix.RevSliderGlobals::TABLE_NAVIGATION_NAME, ARRAY_A);
		
		return $navigations;
	}
	
	
	/**
	 * Get all Navigations
	 * @since: 5.0
	 **/
	public static function get_all_navigations($defaults = true, $raw = false){
		global $wpdb;
		
		$navigations = $wpdb->get_results("SELECT * FROM ".$wpdb->prefix.RevSliderGlobals::TABLE_NAVIGATION_NAME, ARRAY_A);
		
		if($raw == false){
			foreach($navigations as $key => $nav){
				$navigations[$key]['css'] = RevSliderBase::stripslashes_deep(json_decode($navigations[$key]['css'], true));
				$navigations[$key]['markup'] = RevSliderBase::stripslashes_deep(json_decode($navigations[$key]['markup'], true));
				if(isset($navigations[$key]['settings'])){
					$navigations[$key]['settings'] = RevSliderBase::stripslashes_deep(json_decode($navigations[$key]['settings'], true));
					if(!is_array($navigations[$key]['settings'])){
						$navigations[$key]['settings'] = json_decode($navigations[$key]['settings'], true);
					}
				}
			}
		}
		
		if($defaults){
			$def = self::get_default_navigations();
			
			$default_presets = get_option('revslider-nav-preset-default', array());
			
			if(!empty($def)){
				if($raw == false){
					foreach($def as $key => $nav){
						$def[$key]['css'] = RevSliderBase::stripslashes_deep(json_decode($def[$key]['css'], true));
						$def[$key]['markup'] = RevSliderBase::stripslashes_deep(json_decode($def[$key]['markup'], true));
						
						if(isset($def[$key]['settings'])){
							$def[$key]['settings'] = RevSliderBase::stripslashes_deep(json_decode($def[$key]['settings'], true));
							if(!is_array($def[$key]['settings'])){
								$def[$key]['settings'] = json_decode($def[$key]['settings'], true);
							}
						}
						//add custom settings (placeholders) to the default navigation
						if(!empty($default_presets)){
							if(!isset($def[$key]['settings'])) $def[$key]['settings'] = array();
							if(!isset($def[$key]['settings']['presets'])) $def[$key]['settings']['presets'] = array();
							foreach($default_presets as $id => $v){
								if($id !== $def[$key]['id']) continue;
								
								foreach($v as $values){
									$def[$key]['settings']['presets'][] = $values;
								}
							}
						}
					}
				}
				$navigations = array_merge($navigations, $def);
			}
		}
		
		return $navigations;
	}
	
	
	/**
	 * Creates / Updates Navigation skins
	 * @since: 5.0
	 **/
	public function create_update_full_navigation($data){
		global $wpdb;
		
		if(!empty($data) && is_array($data)){
			
			$navigations = self::get_all_navigations();
			
			foreach($data as $vals){
				$found = false;
				
				if(!isset($vals['markup']) || !isset($vals['css'])) continue;
				if(isset($vals['default']) && $vals['default'] == true) continue; //defaults can't be deleted
				
				if(isset($vals['id'])){ //new will be added temporary to navs to tell here that they are new
					
					if(intval($vals['id']) === 0) continue; //0
					
					foreach($navigations as $nav){
						if($vals['id'] == $nav['id']){
							$found = true;
							break;
						}
					}
				}
				
				if($found == true){ //update
					self::create_update_navigation($vals, $vals['id']);
				}else{ //create
					self::create_update_navigation($vals);
				}
			}
		}
		
		return true;
	}
	
	/**
	 * Creates / Updates Navigation skins
	 * @since: 5.0
	 **/
	public static function create_update_navigation($data, $nav_id = 0){
		global $wpdb;
		
		if(isset($data['default']) && $data['default'] == true) return false;
		
		if(!isset($data['settings'])) $data['settings'] = '';
		
		if($nav_id > 0){
			$response = $wpdb->update($wpdb->prefix.RevSliderGlobals::TABLE_NAVIGATION_NAME,
				array(
					'name' => $data['name'],
					'handle' => sanitize_title($data['name']),
					'markup' => json_encode($data['markup']),
					'css' => json_encode($data['css']),
					'settings' => json_encode($data['settings'])
				),
				array('id' => $nav_id)
			);
		}else{
			if(!isset($data['settings'])) $data['settings'] = '';
			$response = $wpdb->insert($wpdb->prefix.RevSliderGlobals::TABLE_NAVIGATION_NAME, array('name' => $data['name'], 'handle' => sanitize_title($data['name']), 'css' => json_encode($data['css']), 'markup' => json_encode($data['markup']), 'settings' => json_encode($data['settings'])));
		}
		
		return $response;
	}
	
	
	/**
	 * Delete Navigation
	 * @since: 5.0
	 **/
	public function delete_navigation($nav_id = 0){
		global $wpdb;
		
		if(!isset($nav_id) || intval($nav_id) == 0) return __('Invalid ID', 'revslider');
		
		
		$response = $wpdb->delete($wpdb->prefix.RevSliderGlobals::TABLE_NAVIGATION_NAME, array('id' => $nav_id));
		if($response === false) return __('Navigation could not be deleted', 'revslider');
		
		return true;

	}
	
	
	/**
	 * Get Default Navigation
	 * @since: 5.0
	 **/
	public static function get_default_navigations(){
		$navigations = array();
		
		
		$navigations[] = array(
			'id' => 5000,
			'default' => true,
			'name' => 'Hesperiden',
			'handle' => 'round',
			'markup' => '{"arrows":"","bullets":"","thumbs":"<span class=\\\\\\"tp-thumb-image\\\\\\"><\\/span>\\n<span class=\\\\\\"tp-thumb-title\\\\\\">{{title}}<\\/span>","tabs":"<div class=\\\\\\"tp-tab-content\\\\\\">\\n  <span class=\\\\\\"tp-tab-date\\\\\\">{{param1}}<\\/span>\\n  <span class=\\\\\\"tp-tab-title\\\\\\">{{title}}<\\/span>\\n<\\/div>\\n<div class=\\\\\\"tp-tab-image\\\\\\"><\\/div>"}',
			'css' => '{"arrows":".hesperiden.tparrows {\\n\\tcursor:pointer;\\n\\tbackground:rgba(##bg-color##);\\n\\twidth:##bg-size##px;\\n\\theight:##bg-size##px;\\n\\tposition:absolute;\\n\\tdisplay:block;\\n\\tz-index:100;\\n    border-radius: 50%;\\n}\\n.hesperiden.tparrows:hover {\\n\\tbackground:rgba(##hover-bg-color##);\\n}\\n.hesperiden.tparrows:before {\\n\\tfont-family: \\\\\\"revicons\\\\\\";\\n\\tfont-size:##arrow-size##px;\\n\\tcolor:rgb(##arrow-color##);\\n\\tdisplay:block;\\n\\tline-height: ##bg-size##px;\\n\\ttext-align: center;\\n}\\n.hesperiden.tparrows.tp-leftarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\e82c\\\\\\";\\n    margin-left:-3px;\\n}\\n.hesperiden.tparrows.tp-rightarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\e82d\\\\\\";\\n    margin-right:-3px;\\n}","bullets":".hesperiden.tp-bullets {\\n}\\n.hesperiden.tp-bullets:before {\\n\\tcontent:\\\\\\" \\\\\\";\\n\\tposition:absolute;\\n\\twidth:100%;\\n\\theight:100%;\\n\\tbackground:transparent;\\n\\tpadding:10px;\\n\\tmargin-left:-10px;margin-top:-10px;\\n\\tbox-sizing:content-box;\\n   border-radius:8px;\\n  \\n}\\n.hesperiden .tp-bullet {\\n\\twidth:##bullet-size##px;\\n\\theight:##bullet-size##px;\\n\\tposition:absolute;\\n\\tbackground: rgb(##bullet-bg-top##); \\/* old browsers *\\/\\n    background: -moz-linear-gradient(top,  rgb(##bullet-bg-top##) 0%, rgb(##bullet-bg-bottom##) 100%); \\/* ff3.6+ *\\/\\n    background: -webkit-linear-gradient(top,  rgb(##bullet-bg-top##) 0%,rgb(##bullet-bg-bottom##) 100%); \\/* chrome10+,safari5.1+ *\\/\\n    background: -o-linear-gradient(top,  rgb(##bullet-bg-top##) 0%,rgb(##bullet-bg-bottom##) 100%); \\/* opera 11.10+ *\\/\\n    background: -ms-linear-gradient(top,  rgb(##bullet-bg-top##) 0%,rgb(##bullet-bg-bottom##) 100%); \\/* ie10+ *\\/\\n    background: linear-gradient(to bottom,  rgb(##bullet-bg-top##) 0%,rgb(##bullet-bg-bottom##) 100%); \\/* w3c *\\/\\n    filter: progid:dximagetransform.microsoft.gradient( \\n    startcolorstr=\\\\\\"rgb(##bullet-bg-top##)\\\\\\", endcolorstr=\\\\\\"rgb(##bullet-bg-bottom##)\\\\\\",gradienttype=0 ); \\/* ie6-9 *\\/\\n\\tborder:##border-size##px solid rgb(##border-color##);\\n\\tborder-radius:50%;\\n\\tcursor: pointer;\\n\\tbox-sizing:content-box;\\n}\\n.hesperiden .tp-bullet:hover,\\n.hesperiden .tp-bullet.selected {\\n\\tbackground:rgb(##hover-bullet-bg##);\\n}\\n.hesperiden .tp-bullet-image {\\n}\\n.hesperiden .tp-bullet-title {\\n}\\n","thumbs":".hesperiden .tp-thumb {\\n  opacity:1;\\n  -webkit-perspective: 600px;\\n  perspective: 600px;\\n}\\n.hesperiden .tp-thumb .tp-thumb-title {\\n    font-size:##title-font-size##px;\\n    position:absolute;\\n    margin-top:-10px;\\n    color:rgba(##title-color##);\\n    display:block;\\n    z-index:1000;\\n    background-color:rgba(##title-bg##);\\n    padding:5px 10px; \\n    bottom:0px;\\n    left:0px;\\n    width:100%;\\n  box-sizing:border-box;\\n    text-align:center;\\n    overflow:hidden;\\n    white-space:nowrap;\\n    transition:all 0.3s;\\n    -webkit-transition:all 0.3s;\\n    transform:rotatex(90deg) translatez(0.001px);\\n    transform-origin:50% 100%;\\n    -webkit-transform:rotatex(90deg) translatez(0.001px);\\n    -webkit-transform-origin:50% 100%;\\n    opacity:0;\\n }\\n.hesperiden .tp-thumb:hover .tp-thumb-title {\\n  \\t transform:rotatex(0deg);\\n    -webkit-transform:rotatex(0deg);\\n    opacity:1;\\n}","tabs":".hesperiden .tp-tab { \\n  opacity:1;      \\n  padding:10px;\\n  box-sizing:border-box;\\n  font-family: \\\\\\"##font-family##\\\\\\", sans-serif;\\n  border-bottom: ##border-size##px solid rgba(##border-color##);\\n }\\n.hesperiden .tp-tab-image \\n{ \\n  width:##image-size##px;\\n  height:##image-size##px; max-height:100%; max-width:100%;\\n  position:relative;\\n  display:inline-block;\\n  float:left;\\n\\n}\\n.hesperiden .tp-tab-content \\n{\\n    background:rgba(##bgcolor##); \\n    position:relative;\\n    padding:15px 15px 15px 85px;\\n left:0px;\\n overflow:hidden;\\n margin-top:-15px;\\n    box-sizing:border-box;\\n    color:rgba(##contentcolor##);\\n    display: inline-block;\\n    width:100%;\\n    height:100%;\\n position:absolute; }\\n.hesperiden .tp-tab-date\\n  {\\n  display:block;\\n  color: rgba(##param1-color##);\\n  font-weight:500;\\n  font-size:##param1-size##px;\\n  margin-bottom:0px;\\n  }\\n.hesperiden .tp-tab-title \\n{\\n    display:block;\\t\\n    text-align:left\\t;\\n    color:rgba(##param2-color##);\\n    font-size:##param2-size##px;\\n    font-weight:500;\\n    text-transform:none;\\n    line-height:17px;\\n}\\n.hesperiden .tp-tab:hover,\\n.hesperiden .tp-tab.selected {\\n\\tbackground:rgba(##hover-bg-color##); \\n}\\n\\n.hesperiden .tp-tab-mask {\\n}\\n\\n\\/* media queries *\\/\\n@media only screen and (max-width: 960px) {\\n\\n}\\n@media only screen and (max-width: 768px) {\\n\\n}"}',
			'settings' => '{"width":{"thumbs":"160","arrows":"160","bullets":"160","tabs":"250"},"height":{"thumbs":"160","arrows":"160","bullets":"160","tabs":"80"},"original":{"css":{"arrows":".hesperiden.tparrows {\\n\\tcursor:pointer;\\n\\tbackground:#000;\\n\\tbackground:rgba(0,0,0,0.5);\\n\\twidth:40px;\\n\\theight:40px;\\n\\tposition:absolute;\\n\\tdisplay:block;\\n\\tz-index:100;\\n    border-radius: 50%;\\n}\\n.hesperiden.tparrows:hover {\\n\\tbackground:#000;\\n}\\n.hesperiden.tparrows:before {\\n\\tfont-family: \\\\\\"revicons\\\\\\";\\n\\tfont-size:20px;\\n\\tcolor:#fff;\\n\\tdisplay:block;\\n\\tline-height: 40px;\\n\\ttext-align: center;\\n}\\n.hesperiden.tparrows.tp-leftarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\\e82c\\\\\\";\\n    margin-left:-3px;\\n}\\n.hesperiden.tparrows.tp-rightarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\\e82d\\\\\\";\\n    margin-right:-3px;\\n}","bullets":".hesperiden.tp-bullets {\\n}\\n.hesperiden.tp-bullets:before {\\n\\tcontent:\\\\\\" \\\\\\";\\n\\tposition:absolute;\\n\\twidth:100%;\\n\\theight:100%;\\n\\tbackground:transparent;\\n\\tpadding:10px;\\n\\tmargin-left:-10px;margin-top:-10px;\\n\\tbox-sizing:content-box;\\n   border-radius:8px;\\n  \\n}\\n.hesperiden .tp-bullet {\\n\\twidth:12px;\\n\\theight:12px;\\n\\tposition:absolute;\\n\\tbackground: #999999; \\/* old browsers *\\/\\n    background: -moz-linear-gradient(top,  #999999 0%, #e1e1e1 100%); \\/* ff3.6+ *\\/\\n    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#999999), \\n    color-stop(100%,#e1e1e1)); \\/* chrome,safari4+ *\\/\\n    background: -webkit-linear-gradient(top,  #999999 0%,#e1e1e1 100%); \\/* chrome10+,safari5.1+ *\\/\\n    background: -o-linear-gradient(top,  #999999 0%,#e1e1e1 100%); \\/* opera 11.10+ *\\/\\n    background: -ms-linear-gradient(top,  #999999 0%,#e1e1e1 100%); \\/* ie10+ *\\/\\n    background: linear-gradient(to bottom,  #999999 0%,#e1e1e1 100%); \\/* w3c *\\/\\n    filter: progid:dximagetransform.microsoft.gradient( \\n    startcolorstr=\\\\\\"#999999\\\\\\", endcolorstr=\\\\\\"#e1e1e1\\\\\\",gradienttype=0 ); \\/* ie6-9 *\\/\\n\\tborder:3px solid #e5e5e5;\\n\\tborder-radius:50%;\\n\\tcursor: pointer;\\n\\tbox-sizing:content-box;\\n}\\n.hesperiden .tp-bullet:hover,\\n.hesperiden .tp-bullet.selected {\\n\\tbackground:#666;\\n}\\n.hesperiden .tp-bullet-image {\\n}\\n.hesperiden .tp-bullet-title {\\n}\\n","thumbs":".hesperiden .tp-thumb {\\n  opacity:1;\\n  -webkit-perspective: 600px;\\n  perspective: 600px;\\n}\\n.hesperiden .tp-thumb .tp-thumb-title {\\n    font-size:12px;\\n    position:absolute;\\n    margin-top:-10px;\\n    color:#fff;\\n    display:block;\\n    z-index:1000;\\n    background-color:#000;\\n    padding:5px 10px; \\n    bottom:0px;\\n    left:0px;\\n    width:100%;\\n  box-sizing:border-box;\\n    text-align:center;\\n    overflow:hidden;\\n    white-space:nowrap;\\n    transition:all 0.3s;\\n    -webkit-transition:all 0.3s;\\n    transform:rotatex(90deg) translatez(0.001px);\\n    transform-origin:50% 100%;\\n    -webkit-transform:rotatex(90deg) translatez(0.001px);\\n    -webkit-transform-origin:50% 100%;\\n    opacity:0;\\n }\\n.hesperiden .tp-thumb:hover .tp-thumb-title {\\n  \\t transform:rotatex(0deg);\\n    -webkit-transform:rotatex(0deg);\\n    opacity:1;\\n}","tabs":".hesperiden .tp-tab { \\n  opacity:1;      \\n  padding:10px;\\n  box-sizing:border-box;\\n  font-family: \\\\\\"Roboto\\\\\\", sans-serif;\\n  border-bottom: 1px solid #e5e5e5;\\n }\\n.hesperiden .tp-tab-image \\n{ \\n  width:60px;\\n  height:60px; max-height:100%; max-width:100%;\\n  position:relative;\\n  display:inline-block;\\n  float:left;\\n\\n}\\n.hesperiden .tp-tab-content \\n{\\n    background:rgba(0,0,0,0); \\n    position:relative;\\n    padding:15px 15px 15px 85px;\\n left:0px;\\n overflow:hidden;\\n margin-top:-15px;\\n    box-sizing:border-box;\\n    color:#333;\\n    display: inline-block;\\n    width:100%;\\n    height:100%;\\n position:absolute; }\\n.hesperiden .tp-tab-date\\n  {\\n  display:block;\\n  color: #aaa;\\n  font-weight:500;\\n  font-size:12px;\\n  margin-bottom:0px;\\n  }\\n.hesperiden .tp-tab-title \\n{\\n    display:block;\\t\\n    text-align:left;\\n    color:#333;\\n    font-size:14px;\\n    font-weight:500;\\n    text-transform:none;\\n    line-height:17px;\\n}\\n.hesperiden .tp-tab:hover,\\n.hesperiden .tp-tab.selected {\\n\\tbackground:#eee; \\n}\\n\\n.hesperiden .tp-tab-mask {\\n}\\n\\n\\/* MEDIA QUERIES *\\/\\n@media only screen and (max-width: 960px) {\\n\\n}\\n@media only screen and (max-width: 768px) {\\n\\n}"},"markup":{"arrows":"","bullets":"","thumbs":"<span class=\\\\\\"tp-thumb-image\\\\\\"><\\/span>\\n<span class=\\\\\\"tp-thumb-title\\\\\\">{{title}}<\\/span>","tabs":"<div class=\\\\\\"tp-tab-content\\\\\\">\\n  <span class=\\\\\\"tp-tab-date\\\\\\">{{param1}}<\\/span>\\n  <span class=\\\\\\"tp-tab-title\\\\\\">{{title}}<\\/span>\\n<\\/div>\\n<div class=\\\\\\"tp-tab-image\\\\\\"><\\/div>"}},"placeholders":[{"title":"BG-Color","handle":"bg-color","type":"custom","nav-type":"arrows","data":{"custom":"0,0,0,0.5"}},{"title":"BG-Size","handle":"bg-size","type":"custom","nav-type":"arrows","data":{"custom":"40"}},{"title":"Arrow-Color","handle":"arrow-color","type":"color","nav-type":"arrows","data":{"color":"#ffffff"}},{"title":"Arrow-Size","handle":"arrow-size","type":"custom","nav-type":"arrows","data":{"custom":"20"}},{"title":"Hover-BG-Color","handle":"hover-bg-color","type":"color-rgba","nav-type":"arrows","data":{"color-rgba":"#000000"}},{"title":"Bullet-Size","handle":"bullet-size","type":"custom","nav-type":"bullets","data":{"custom":"12"}},{"title":"Bullet-BG-Top","handle":"bullet-bg-top","type":"color","nav-type":"bullets","data":{"color":"#999999"}},{"title":"Bullet-BG-Bottom","handle":"bullet-bg-bottom","type":"color","nav-type":"bullets","data":{"color":"#e1e1e1"}},{"title":"Border-Color","handle":"border-color","type":"color","nav-type":"bullets","data":{"color":"#e5e5e5"}},{"title":"Border-Size","handle":"border-size","type":"custom","nav-type":"bullets","data":{"custom":"3"}},{"title":"Hover-Bullet-BG","handle":"hover-bullet-bg","type":"color","nav-type":"bullets","data":{"color":"#666666"}},{"title":"Title-BG-Color","handle":"title-bg","type":"color-rgba","nav-type":"thumbs","data":{"color-rgba":"rgba(0,0,0,0.85)"}},{"title":"Title-Font-Color","handle":"title-color","type":"color-rgba","nav-type":"thumbs","data":{"color-rgba":"#ffffff"}},{"title":"Title-Font-Size","handle":"title-font-size","type":"custom","nav-type":"thumbs","data":{"custom":"12"}},{"title":"Font-Family","handle":"font-family","type":"font-family","nav-type":"tabs","data":{"font_family":"Roboto"}},{"title":"Border-Bottom-Color","handle":"border-color","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"#e5e5e5"}},{"title":"Border-Bottom-Size","handle":"border-size","type":"custom","nav-type":"tabs","data":{"custom":"1"}},{"title":"Image-Size","handle":"image-size","type":"custom","nav-type":"tabs","data":{"custom":"60"}},{"title":"Date-Color","handle":"param1-color","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"rgba(51,51,51,0.5)"}},{"title":"Date-Size","handle":"param1-size","type":"custom","nav-type":"tabs","data":{"custom":"12"}},"","",{"title":"Hover-BG-Color","handle":"hover-bg-color","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"#eeeeee"}},{"title":"Background","handle":"bgcolor","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"rgba(0,0,0,0)"}},{"title":"Content","handle":"contentcolor","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"#333333"}},{"title":"Title-Color","handle":"param2-color","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"0,0,0,0"}},{"title":"Title-Size","handle":"param2-size","type":"custom","nav-type":"tabs","data":{"custom":"14"}}]}');
			
		$navigations[] = array(
			'id' => 5001,
			'default' => true,
			'name' => 'Gyges',
			'handle' => 'navbar',
			'markup' => '{"arrows":"","bullets":"","tabs":"<div class=\\\\\\"tp-tab-content\\\\\\">\\n  <span class=\\\\\\"tp-tab-date\\\\\\">{{param1}}<\\/span>\\n  <span class=\\\\\\"tp-tab-title\\\\\\">{{title}}<\\/span>\\n<\\/div>\\n<div class=\\\\\\"tp-tab-image\\\\\\"><\\/div>","thumbs":"<span class=\\\\\\"tp-thumb-img-wrap\\\\\\">\\n  <span class=\\\\\\"tp-thumb-image\\\\\\"><\\/span>\\n<\\/span>\\n"}',
			'css' => '{"arrows":"","bullets":".gyges.tp-bullets {\\n}\\n.gyges.tp-bullets:before {\\n\\tcontent:\\\\\\" \\\\\\";\\n\\tposition:absolute;\\n\\twidth:100%;\\n\\theight:100%;\\n    background: -moz-linear-gradient(top,  rgba(##bgtop##) 0%, rgba(##bgbottom##) 100%); \\n    background: -webkit-linear-gradient(top,  rgba(##bgtop##) 0%,rgba(##bgbottom##) 100%); \\n    background: -o-linear-gradient(top,  rgba(##bgtop##) 0%,rgba(##bgbottom##) 100%); \\n    background: -ms-linear-gradient(top,  rgba(##bgtop##) 0%,rgba(##bgbottom##) 100%); \\n    background: linear-gradient(to bottom,  rgba(##bgtop##) 0%, rgba(##bgbottom##) 100%); \\n    filter: progid:dximagetransform.microsoft.gradient( startcolorstr=\\\\\\"rgba(##bgtop##)\\\\\\", \\n    endcolorstr=\\\\\\"rgba(##bgbottom##)\\\\\\",gradienttype=0 ); \\n\\tpadding:10px;\\n\\tmargin-left:-10px;margin-top:-10px;\\n\\tbox-sizing:content-box;\\n  border-radius:10px;\\n}\\n.gyges .tp-bullet {\\n\\twidth:12px;\\n\\theight:12px;\\n\\tposition:absolute;\\n\\tbackground:rgba(##bulletbg##);\\n\\tborder:3px solid rgba(##bordercolor##);\\n\\tborder-radius:50%;\\n\\tcursor: pointer;\\n\\tbox-sizing:content-box;\\n}\\n.gyges .tp-bullet:hover,\\n.gyges .tp-bullet.selected {\\n\\n    background: -moz-linear-gradient(top,  rgba(##hbgtop##) 0%, rgba(##hbgbottom##) 100%); \\/* ff3.6+ *\\/\\n    background: -webkit-linear-gradient(top,  rgba(##hbgtop##) 0%,rgba(##hbgbottom##) 100%); \\/* chrome10+,safari5.1+ *\\/\\n    background: -o-linear-gradient(top,  rgba(##hbgtop##) 0%,rgba(##hbgbottom##) 100%); \\/* opera 11.10+ *\\/\\n    background: -ms-linear-gradient(top,  rgba(##hbgtop##) 0%,rgba(##hbgbottom##) 100%); \\/* ie10+ *\\/\\n    background: linear-gradient(to bottom,  rgba(##hbgtop##) 0%,rgba(##hbgbottom##) 100%); \\/* w3c *\\/\\n    filter: progid:dximagetransform.microsoft.gradient( startcolorstr=\\\\\\"rgba(##hbgtop##)\\\\\\", \\n    endcolorstr=\\\\\\"rgba(##hbgbottom##)\\\\\\",gradienttype=0 ); \\/* ie6-9 *\\/\\n\\n}\\n.gyges .tp-bullet-image {\\n}\\n.gyges .tp-bullet-title {\\n}\\n\\t","tabs":".gyges .tp-tab { \\n  opacity:1;      \\n  padding:10px;\\n  box-sizing:border-box;\\n  font-family: \\\\\\"roboto\\\\\\", sans-serif;\\n  border-bottom: 1px solid rgba(##borderc##);\\n }\\n.gyges .tp-tab-image \\n{ \\n  width:##size##px;\\n  height:##size##px; \\n  max-height:100%; \\n  max-width:100%;\\n  position:relative;\\n  display:inline-block;\\n  float:left;\\n\\n}\\n.gyges .tp-tab-content \\n{\\n    background:rgba(##bg##); \\n    position:relative;\\n    padding:15px 15px 15px 85px;\\n    left:0px;\\n    overflow:hidden;\\n    margin-top:-15px;\\n    box-sizing:border-box;\\n    color:rgba(##color##);\\n    display: inline-block;\\n    width:100%;\\n    height:100%;\\n position:absolute; }\\n.gyges .tp-tab-date\\n  {\\n  display:block;\\n  color: rgba(##datecolor##);\\n  font-weight:500;\\n  font-size:##datesize##px;\\n  margin-bottom:0px;\\n  }\\n.gyges .tp-tab-title \\n{\\n    display:block;  \\n    text-align:left;\\n    color:rgba(##titlecolor##);\\n    font-size:##titlesize##px;\\n    font-weight:500;\\n    text-transform:none;\\n    line-height:17px;\\n}\\n.gyges .tp-tab:hover,\\n.gyges .tp-tab.selected {\\n  background:rgba(##hbg##); \\n}\\n\\n.gyges .tp-tab-mask {\\n}\\n\\n\\/* media queries *\\/\\n@media only screen and (max-width: 960px) {\\n\\n}\\n@media only screen and (max-width: 768px) {\\n\\n}","thumbs":".gyges .tp-thumb { \\n      opacity:1\\n  }\\n.gyges .tp-thumb-img-wrap {\\n  padding:3px;\\n  background-color:rgba(##bg##);\\n  display:inline-block;\\n\\n  width:100%;\\n  height:100%;\\n  position:relative;\\n  margin:0px;\\n  box-sizing:border-box;\\n    transition:all 0.3s;\\n    -webkit-transition:all 0.3s;\\n}\\n.gyges .tp-thumb-image {\\n   padding:3px; \\n   display:block;\\n   box-sizing:border-box;\\n   position:relative;\\n    -webkit-box-shadow: inset 5px 5px 10px 0px rgba(##bg##);\\n  -moz-box-shadow: inset 5px 5px 10px 0px rgba(##bg##);\\n  box-shadow: inset 5px 5px 10px 0px rgba(##bg##);\\n }  \\n\\n.gyges .tp-thumb:hover .tp-thumb-img-wrap,\\n .gyges .tp-thumb.selected .tp-thumb-img-wrap {\\n    background: -moz-linear-gradient(top,  rgba(##hovercolor##) 0%, rgba(##hbgb##) 100%);\\nbackground: -webkit-gradient(left top, left bottom, color-stop(0%, rgba(##hovercolor##)), color-stop(100%, rgba(##hbgb##)));\\nbackground: -webkit-linear-gradient(top, rgba(##hovercolor##) 0%, rgba(##hbgb##) 100%);\\nbackground: -o-linear-gradient(top, rgba(##hovercolor##) 0%, rgba(##hbgb##) 100%);\\nbackground: -ms-linear-gradient(top, rgba(##hovercolor##) 0%, rgba(##hbgb##) 100%);\\nbackground: linear-gradient(to bottom, rgba(##hovercolor##) 0%, rgba(##hbgb##) 100%);\\n\\n}\\n\\n"}',
			'settings' => '{"width":{"thumbs":"70","arrows":"160","bullets":"160","tabs":"300"},"height":{"thumbs":"70","arrows":"160","bullets":"160","tabs":"80"},"original":{"css":{"arrows":"","bullets":".gyges.tp-bullets {\\n}\\n.gyges.tp-bullets:before {\\n\\tcontent:\\\\\\" \\\\\\";\\n\\tposition:absolute;\\n\\twidth:100%;\\n\\theight:100%;\\n\\tbackground: #777777; \\/* Old browsers *\\/\\n    background: -moz-linear-gradient(top,  #777777 0%, #666666 100%); \\n    background: -webkit-gradient(linear, left top, left bottom, \\n    color-stop(0%,#777777), color-stop(100%,#666666)); \\n    background: -webkit-linear-gradient(top,  #777777 0%,#666666 100%); \\n    background: -o-linear-gradient(top,  #777777 0%,#666666 100%); \\n    background: -ms-linear-gradient(top,  #777777 0%,#666666 100%); \\n    background: linear-gradient(to bottom,  #777777 0%,#666666 100%); \\n    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr=\\\\\\"#777777\\\\\\", \\n    endColorstr=\\\\\\"#666666\\\\\\",GradientType=0 ); \\n\\tpadding:10px;\\n\\tmargin-left:-10px;margin-top:-10px;\\n\\tbox-sizing:content-box;\\n  border-radius:10px;\\n}\\n.gyges .tp-bullet {\\n\\twidth:12px;\\n\\theight:12px;\\n\\tposition:absolute;\\n\\tbackground:#333;\\n\\tborder:3px solid #444;\\n\\tborder-radius:50%;\\n\\tcursor: pointer;\\n\\tbox-sizing:content-box;\\n}\\n.gyges .tp-bullet:hover,\\n.gyges .tp-bullet.selected {\\n\\tbackground: #ffffff; \\/* Old browsers *\\/\\n    background: -moz-linear-gradient(top,  #ffffff 0%, #e1e1e1 100%); \\/* FF3.6+ *\\/\\n    background: -webkit-gradient(linear, left top, left bottom, \\n    color-stop(0%,#ffffff), color-stop(100%,#e1e1e1)); \\/* Chrome,Safari4+ *\\/\\n    background: -webkit-linear-gradient(top,  #ffffff 0%,#e1e1e1 100%); \\/* Chrome10+,Safari5.1+ *\\/\\n    background: -o-linear-gradient(top,  #ffffff 0%,#e1e1e1 100%); \\/* Opera 11.10+ *\\/\\n    background: -ms-linear-gradient(top,  #ffffff 0%,#e1e1e1 100%); \\/* IE10+ *\\/\\n    background: linear-gradient(to bottom,  #ffffff 0%,#e1e1e1 100%); \\/* W3C *\\/\\n    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr=\\\\\\"#ffffff\\\\\\", \\n    endColorstr=\\\\\\"#e1e1e1\\\\\\",GradientType=0 ); \\/* IE6-9 *\\/\\n\\n}\\n.gyges .tp-bullet-image {\\n}\\n.gyges .tp-bullet-title {\\n}\\n\\t","tabs":".gyges .tp-tab { \\n  opacity:1;      \\n  padding:10px;\\n  box-sizing:border-box;\\n  font-family: \\\\\\"Roboto\\\\\\", sans-serif;\\n  border-bottom: 1px solid rgba(255,255,255,0.15);\\n }\\n.gyges .tp-tab-image \\n{ \\n  width:60px;\\n  height:60px; max-height:100%; max-width:100%;\\n  position:relative;\\n  display:inline-block;\\n  float:left;\\n\\n}\\n.gyges .tp-tab-content \\n{\\n    background:rgba(0,0,0,0); \\n    position:relative;\\n    padding:15px 15px 15px 85px;\\n left:0px;\\n  overflow:hidden;\\n margin-top:-15px;\\n    box-sizing:border-box;\\n    color:#333;\\n    display: inline-block;\\n    width:100%;\\n    height:100%;\\n position:absolute; }\\n.gyges .tp-tab-date\\n  {\\n  display:block;\\n  color: rgba(255,255,255,0.25);\\n  font-weight:500;\\n  font-size:12px;\\n  margin-bottom:0px;\\n  }\\n.gyges .tp-tab-title \\n{\\n    display:block;  \\n    text-align:left;\\n    color:#fff;\\n    font-size:14px;\\n    font-weight:500;\\n    text-transform:none;\\n    line-height:17px;\\n}\\n.gyges .tp-tab:hover,\\n.gyges .tp-tab.selected {\\n  background:rgba(0,0,0,0.5); \\n}\\n\\n.gyges .tp-tab-mask {\\n}\\n\\n\\/* MEDIA QUERIES *\\/\\n@media only screen and (max-width: 960px) {\\n\\n}\\n@media only screen and (max-width: 768px) {\\n\\n}","thumbs":".gyges .tp-thumb { \\n      opacity:1\\n  }\\n.gyges .tp-thumb-img-wrap {\\n  padding:3px;\\n    background:#000;\\n  background-color:rgba(0,0,0,0.25);\\n  display:inline-block;\\n\\n  width:100%;\\n  height:100%;\\n  position:relative;\\n  margin:0px;\\n  box-sizing:border-box;\\n    transition:all 0.3s;\\n    -webkit-transition:all 0.3s;\\n}\\n.gyges .tp-thumb-image {\\n   padding:3px; \\n   display:block;\\n   box-sizing:border-box;\\n   position:relative;\\n    -webkit-box-shadow: inset 5px 5px 10px 0px rgba(0,0,0,0.25);\\n  -moz-box-shadow: inset 5px 5px 10px 0px rgba(0,0,0,0.25);\\n  box-shadow: inset 5px 5px 10px 0px rgba(0,0,0,0.25);\\n }  \\n.gyges .tp-thumb-title { \\n     position:absolute; \\n     bottom:100%; \\n     display:inline-block;\\n     left:50%;\\n     background:rgba(255,255,255,0.8);\\n     padding:10px 30px;\\n     border-radius:4px;\\n\\t -webkit-border-radius:4px;\\n     margin-bottom:20px;\\n     opacity:0;\\n      transition:all 0.3s;\\n    -webkit-transition:all 0.3s;\\n    transform: translateZ(0.001px) translateX(-50%) translateY(14px);\\n    transform-origin:50% 100%;\\n    -webkit-transform: translateZ(0.001px) translateX(-50%) translateY(14px);\\n    -webkit-transform-origin:50% 100%;\\n    white-space:nowrap;\\n }\\n.gyges .tp-thumb:hover .tp-thumb-title {\\n  \\t transform:rotateX(0deg) translateX(-50%);\\n    -webkit-transform:rotateX(0deg) translateX(-50%);\\n    opacity:1;\\n}\\n\\n.gyges .tp-thumb:hover .tp-thumb-img-wrap,\\n .gyges .tp-thumb.selected .tp-thumb-img-wrap {\\n\\n  background: rgba(255,255,255,1);\\n  background: -moz-linear-gradient(top, rgba(255,255,255,1) 0%, rgba(119,119,119,1) 100%);\\n  background: -webkit-gradient(left top, left bottom, color-stop(0%, rgba(255,255,255,1)), color-stop(100%, rgba(119,119,119,1)));\\n  background: -webkit-linear-gradient(top, rgba(255,255,255,1) 0%, rgba(119,119,119,1) 100%);\\n  background: -o-linear-gradient(top, rgba(255,255,255,1) 0%, rgba(119,119,119,1) 100%);\\n  background: -ms-linear-gradient(top, rgba(255,255,255,1) 0%, rgba(119,119,119,1) 100%);\\n  background: linear-gradient(to bottom, rgba(255,255,255,1) 0%, rgba(119,119,119,1) 100%);\\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr=\\\\\\"#ffffff\\\\\\", endColorstr=\\\\\\"#777777\\\\\\", GradientType=0 );\\n }\\n.gyges .tp-thumb-title:after {\\n        content:\\\\\\" \\\\\\";\\n        position:absolute;\\n        left:50%;\\n        margin-left:-8px;\\n        width: 0;\\n\\t\\theight: 0;\\n\\t\\tborder-style: solid;\\n\\t\\tborder-width: 8px 8px 0 8px;\\n\\t\\tborder-color: rgba(255,255,255,0.8) transparent transparent transparent;\\n        bottom:-8px;\\n   }\\n"},"markup":{"arrows":"","bullets":"","tabs":"<div class=\\\\\\"tp-tab-content\\\\\\">\\n  <span class=\\\\\\"tp-tab-date\\\\\\">{{param1}}<\\/span>\\n  <span class=\\\\\\"tp-tab-title\\\\\\">{{title}}<\\/span>\\n<\\/div>\\n<div class=\\\\\\"tp-tab-image\\\\\\"><\\/div>","thumbs":"<span class=\\\\\\"tp-thumb-img-wrap\\\\\\">\\n  <span class=\\\\\\"tp-thumb-image\\\\\\"><\\/span>\\n<\\/span>\\n"}},"placeholders":[{"title":"BG-Top","handle":"bgtop","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#777777"}},{"title":"BG-Bottom","handle":"bgbottom","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#666666"}},{"title":"Border","handle":"bordercolor","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#444444"}},{"title":"Bullet-BG","handle":"bulletbg","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#333333"}},{"title":"Hover-BG-Top","handle":"hbgtop","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#ffffff"}},{"title":"Hover-BG-Bottom","handle":"hbgbottom","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#e0e0e0"}},{"title":"Background","handle":"bg","type":"color-rgba","nav-type":"thumbs","data":{"color-rgba":"rgba(0,0,0,0.25)"}},{"title":"Title-Background","handle":"titlebg","type":"color-rgba","nav-type":"thumbs","data":{"color-rgba":"rgba(255,255,255,0.81)"}},{"title":"Hover-Top","handle":"hovercolor","type":"color-rgba","nav-type":"thumbs","data":{"color-rgba":"#ffffff"}},{"title":"Border-Color","handle":"borderc","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"rgba(255,255,255,0.15)"}},{"title":"Size","handle":"size","type":"custom","nav-type":"tabs","data":{"custom":"60"}},{"title":"Background","handle":"bg","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"rgba(0,0,0,0)"}},{"title":"Content-Color","handle":"color","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"rgba(51,51,51,0)"}},{"title":"Date-Color","handle":"datecolor","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"rgba(255,255,255,0.5)"}},{"title":"Date-Size","handle":"datesize","type":"custom","nav-type":"tabs","data":{"custom":"12"}},{"title":"Title-Color","handle":"titlecolor","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"#ffffff"}},{"title":"Title-Size","handle":"titlesize","type":"custom","nav-type":"tabs","data":{"custom":"14"}},{"title":"Hover-Background","handle":"hbg","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"rgba(0,0,0,0.51)"}},{"title":"Hover-Bottom","handle":"hbgb","type":"color-rgba","nav-type":"thumbs","data":{"color-rgba":"#777777"}}]}');
			
		$navigations[] = array(
			'id' => 5002,
			'default' => true,
			'name' => 'Hades',
			'handle' => 'preview1',
			'markup' => '{"arrows":"<div class=\\\\\\"tp-arr-allwrapper\\\\\\">\\n\\t<div class=\\\\\\"tp-arr-imgholder\\\\\\"><\\/div>\\n<\\/div>","bullets":"<span class=\\\\\\"tp-bullet-image\\\\\\"><\\/span>","tabs":"<div class=\\\\\\"tp-tab-inner\\\\\\">\\n  <span class=\\\\\\"tp-tab-title\\\\\\">{{param1}}<\\/span>\\n  <span class=\\\\\\"tp-tab-price\\\\\\">{{param2}}<\\/span>\\n  <span class=\\\\\\"tp-tab-button\\\\\\">{{param3}}<\\/span>\\n<\\/div>","thumbs":"<span class=\\\\\\"tp-thumb-img-wrap\\\\\\">\\n  <span class=\\\\\\"tp-thumb-image\\\\\\"><\\/span>\\n<\\/span>\\n"}',
			'css' => '{"arrows":".hades.tparrows {\\n\\tcursor:pointer;\\n\\tbackground:rgba(##bg##);\\n\\twidth:100px;\\n\\theight:100px;\\n\\tposition:absolute;\\n\\tdisplay:block;\\n\\tz-index:100;\\n}\\n\\n.hades.tparrows:before {\\n\\tfont-family: \\\\\\"revicons\\\\\\";\\n\\tfont-size:30px;\\n\\tcolor:rgba(##acolor##);\\n\\tdisplay:block;\\n\\tline-height: 100px;\\n\\ttext-align: center;\\n  transition: background 0.3s, color 0.3s;\\n}\\n.hades.tparrows.tp-leftarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\e824\\\\\\";\\n}\\n.hades.tparrows.tp-rightarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\e825\\\\\\";\\n}\\n\\n.hades.tparrows:hover:before {\\n   color:rgba(##harrow##);\\n   background:rgba(##hbg##);\\n }\\n.hades .tp-arr-allwrapper {\\n  position:absolute;\\n  left:100%;\\n  top:0px;\\n  background:#888; \\n  width:100px;height:100px;\\n  -webkit-transition: all 0.3s;\\n  transition: all 0.3s;\\n  -ms-filter: \\\\\\"progid:dximagetransform.microsoft.alpha(opacity=0)\\\\\\";\\n  filter: alpha(opacity=0);\\n  -moz-opacity: 0.0;\\n  -khtml-opacity: 0.0;\\n  opacity: 0.0;\\n  -webkit-transform: rotatey(-90deg);\\n  transform: rotatey(-90deg);\\n  -webkit-transform-origin: 0% 50%;\\n  transform-origin: 0% 50%;\\n}\\n.hades.tp-rightarrow .tp-arr-allwrapper {\\n   left:auto;\\n   right:100%;\\n   -webkit-transform-origin: 100% 50%;\\n  transform-origin: 100% 50%;\\n   -webkit-transform: rotatey(90deg);\\n  transform: rotatey(90deg);\\n}\\n\\n.hades:hover .tp-arr-allwrapper {\\n   -ms-filter: \\\\\\"progid:dximagetransform.microsoft.alpha(opacity=100)\\\\\\";\\n  filter: alpha(opacity=100);\\n  -moz-opacity: 1;\\n  -khtml-opacity: 1;\\n  opacity: 1;  \\n    -webkit-transform: rotatey(0deg);\\n  transform: rotatey(0deg);\\n\\n }\\n    \\n.hades .tp-arr-iwrapper {\\n}\\n.hades .tp-arr-imgholder {\\n  background-size:cover;\\n  position:absolute;\\n  top:0px;left:0px;\\n  width:100%;height:100%;\\n}\\n.hades .tp-arr-titleholder {\\n}\\n.hades .tp-arr-subtitleholder {\\n}\\n","bullets":".hades.tp-bullets {\\n}\\n.hades.tp-bullets:before {\\n\\tcontent:\\\\\\" \\\\\\";\\n\\tposition:absolute;\\n\\twidth:100%;\\n\\theight:100%;\\n\\tbackground:transparent;\\n\\tpadding:10px;\\n\\tmargin-left:-10px;margin-top:-10px;\\n\\tbox-sizing:content-box;\\n}\\n.hades .tp-bullet {\\n\\twidth:##innersize##px;\\n\\theight:##innersize##px;\\n\\tposition:absolute;\\n\\tbackground:rgba(##colorinner##);\\n\\tcursor: pointer;\\n    border:##outersize##px solid rgba(##outercolor##);\\n\\tbox-sizing:content-box;\\n    box-shadow:0px 0px 3px 1px rgba(0,0,0,0.2);\\n    -webkit-perspective:400;\\n    perspective:400;\\n    -webkit-transform:translatez(0.01px);\\n    transform:translatez(0.01px);\\n}\\n.hades .tp-bullet:hover,\\n.hades .tp-bullet.selected {\\n\\tbackground:rgba(##innerhover##);\\n    border-color:rgba(##outerhover##);\\n}\\n\\n.hades .tp-bullet-image {\\n  position:absolute;\\n  top:##voffset##px; \\n  left:##hoffset##;\\n  width:##width##px;\\n  height:##height##px;\\n  background-position:center center;\\n  background-size:cover;\\n  visibility:hidden;\\n  opacity:0;\\n  transition:all 0.3s;\\n  -webkit-transform-style:flat;\\n  transform-style:flat;\\n  perspective:600;\\n  -webkit-perspective:600;\\n  transform: rotatex(-90deg) translatex(-50%);\\n  -webkit-transform: rotatex(-90deg) translate(-50%);\\n  box-shadow:0px 0px 3px 1px rgba(0,0,0,0.2);\\n  transform-origin:50% 100%;\\n  -webkit-transform-origin:50% 100%;\\n  \\n  \\n}\\n.hades .tp-bullet:hover .tp-bullet-image {\\n  display:block;\\n  opacity:1;\\n  transform: rotatex(0deg) translatex(-50%);\\n  -webkit-transform: rotatex(0deg) translatex(-50%);\\n  visibility:visible;\\n    }\\n.hades .tp-bullet-title {\\n}\\n","tabs":".hades .tp-tab {\\n  opacity:1;\\n }\\n    \\n.hades .tp-tab-title\\n {\\n      display:block;\\n      color:rgba(##param1##);\\n      font-weight:600;\\n      font-size:##param1size##px;\\n      text-align:center;\\n      line-height:25px;      \\n    } \\n.hades .tp-tab-price\\n {\\n\\tdisplay:block;\\n    text-align:center;\\n    color:rgba(##param2##);\\n    font-size:##p2size##px;\\n    margin-top:10px;\\n   line-height:20px\\n}\\n\\n.hades .tp-tab-button {\\n    display:inline-block;\\n    margin-top:15px;\\n    text-align:center;\\n\\tpadding:5px 15px;\\n  \\tcolor:rgba(##p3##);\\n  \\tfont-size:##p3size##px;\\n  \\tbackground:rgba(##p3bg##);\\n   \\tborder-radius:4px;\\n   font-weight:400;\\n}\\n.hades .tp-tab-inner {\\n\\ttext-align:center;\\n}\\n\\n              ","thumbs":".hades .tp-thumb { \\n      opacity:1\\n  }\\n.hades .tp-thumb-img-wrap {\\n  border-radius:##radius##;\\n  padding:##border##px;\\n  display:inline-block;\\n  background-color:rgba(##bg##);\\n  width:100%;\\n  height:100%;\\n  position:relative;\\n  margin:0px;\\n  box-sizing:border-box;\\n    transition:all 0.3s;\\n    -webkit-transition:all 0.3s;\\n}\\n.hades .tp-thumb-image {\\n   padding:##border##px; \\n   border-radius:##radius##;\\n   display:block;\\n   box-sizing:border-box;\\n   position:relative;\\n    -webkit-box-shadow: inset 5px 5px 10px 0px rgba(0,0,0,0.25);\\n  -moz-box-shadow: inset 5px 5px 10px 0px rgba(0,0,0,0.25);\\n  box-shadow: inset 5px 5px 10px 0px rgba(0,0,0,0.25);\\n }  \\n\\n\\n.hades .tp-thumb:hover .tp-thumb-img-wrap,\\n.hades .tp-thumb.selected .tp-thumb-img-wrap {\\n  \\n\\n  background: -moz-linear-gradient(top, rgba(##ht##) 0%, rgba(##hb##) 100%);\\n  background: -webkit-gradient(left top, left bottom, color-stop(0%, rgba(##ht##)), color-stop(100%, rgba(##hb##)));\\n  background: -webkit-linear-gradient(top, rgba(##ht##) 0%, rgba(##hb##) 100%);\\n  background: -o-linear-gradient(top, rgba(##ht##) 0%, rgba(##hb##) 100%);\\n  background: -ms-linear-gradient(top, rgba(##ht##) 0%, rgba(##hb##) 100%);\\n  background: linear-gradient(to bottom, rgba(##ht##) 0%, rgba(##hb##) 100%);\\n }\\n\\n"}',
			'settings' => '{"width":{"thumbs":"70","arrows":"160","bullets":"160","tabs":"160"},"height":{"thumbs":"70","arrows":"160","bullets":"160","tabs":"160"},"original":{"css":{"arrows":".hades.tparrows {\\n\\tcursor:pointer;\\n\\tbackground:#000;\\n\\tbackground:rgba(0,0,0,0.15);\\n\\twidth:100px;\\n\\theight:100px;\\n\\tposition:absolute;\\n\\tdisplay:block;\\n\\tz-index:100;\\n}\\n\\n.hades.tparrows:before {\\n\\tfont-family: \\\\\\"revicons\\\\\\";\\n\\tfont-size:30px;\\n\\tcolor:#fff;\\n\\tdisplay:block;\\n\\tline-height: 100px;\\n\\ttext-align: center;\\n  transition: background 0.3s, color 0.3s;\\n}\\n.hades.tparrows.tp-leftarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\\e824\\\\\\";\\n}\\n.hades.tparrows.tp-rightarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\\e825\\\\\\";\\n}\\n\\n.hades.tparrows:hover:before {\\n   color:#aaa;\\n   background:#fff;\\n   background:rgba(255,255,255,1);\\n }\\n.hades .tp-arr-allwrapper {\\n  position:absolute;\\n  left:100%;\\n  top:0px;\\n  background:#888; \\n  width:100px;height:100px;\\n  -webkit-transition: all 0.3s;\\n  transition: all 0.3s;\\n  -ms-filter: \\\\\\"progid:dximagetransform.microsoft.alpha(opacity=0)\\\\\\";\\n  filter: alpha(opacity=0);\\n  -moz-opacity: 0.0;\\n  -khtml-opacity: 0.0;\\n  opacity: 0.0;\\n  -webkit-transform: rotatey(-90deg);\\n  transform: rotatey(-90deg);\\n  -webkit-transform-origin: 0% 50%;\\n  transform-origin: 0% 50%;\\n}\\n.hades.tp-rightarrow .tp-arr-allwrapper {\\n   left:auto;\\n   right:100%;\\n   -webkit-transform-origin: 100% 50%;\\n  transform-origin: 100% 50%;\\n   -webkit-transform: rotatey(90deg);\\n  transform: rotatey(90deg);\\n}\\n\\n.hades:hover .tp-arr-allwrapper {\\n   -ms-filter: \\\\\\"progid:dximagetransform.microsoft.alpha(opacity=100)\\\\\\";\\n  filter: alpha(opacity=100);\\n  -moz-opacity: 1;\\n  -khtml-opacity: 1;\\n  opacity: 1;  \\n    -webkit-transform: rotatey(0deg);\\n  transform: rotatey(0deg);\\n\\n }\\n    \\n.hades .tp-arr-iwrapper {\\n}\\n.hades .tp-arr-imgholder {\\n  background-size:cover;\\n  position:absolute;\\n  top:0px;left:0px;\\n  width:100%;height:100%;\\n}\\n.hades .tp-arr-titleholder {\\n}\\n.hades .tp-arr-subtitleholder {\\n}\\n","bullets":".hades.tp-bullets {\\n}\\n.hades.tp-bullets:before {\\n\\tcontent:\\\\\\" \\\\\\";\\n\\tposition:absolute;\\n\\twidth:100%;\\n\\theight:100%;\\n\\tbackground:transparent;\\n\\tpadding:10px;\\n\\tmargin-left:-10px;margin-top:-10px;\\n\\tbox-sizing:content-box;\\n}\\n.hades .tp-bullet {\\n\\twidth:3px;\\n\\theight:3px;\\n\\tposition:absolute;\\n\\tbackground:#888;\\t\\n\\tcursor: pointer;\\n    border:5px solid #fff;\\n\\tbox-sizing:content-box;\\n    box-shadow:0px 0px 3px 1px rgba(0,0,0,0.2);\\n    -webkit-perspective:400;\\n    perspective:400;\\n    -webkit-transform:translatez(0.01px);\\n    transform:translatez(0.01px);\\n}\\n.hades .tp-bullet:hover,\\n.hades .tp-bullet.selected {\\n\\tbackground:#555;\\n  \\n}\\n\\n.hades .tp-bullet-image {\\n  position:absolute;top:-80px; left:-60px;width:120px;height:60px;\\n  background-position:center center;\\n  background-size:cover;\\n  visibility:hidden;\\n  opacity:0;\\n  transition:all 0.3s;\\n  -webkit-transform-style:flat;\\n  transform-style:flat;\\n  perspective:600;\\n  -webkit-perspective:600;\\n  transform: rotatex(-90deg);\\n  -webkit-transform: rotatex(-90deg);\\n  box-shadow:0px 0px 3px 1px rgba(0,0,0,0.2);\\n  transform-origin:50% 100%;\\n  -webkit-transform-origin:50% 100%;\\n  \\n  \\n}\\n.hades .tp-bullet:hover .tp-bullet-image {\\n  display:block;\\n  opacity:1;\\n  transform: rotatex(0deg);\\n  -webkit-transform: rotatex(0deg);\\n  visibility:visible;\\n    }\\n.hades .tp-bullet-title {\\n}\\n","tabs":".hades .tp-tab {\\n  opacity:1;\\n }\\n    \\n.hades .tp-tab-title\\n {\\n      display:block;\\n      color:#333;\\n      font-weight:600;\\n      font-size:18px;\\n      text-align:center;\\n      line-height:25px;      \\n    } \\n.hades .tp-tab-price\\n {\\n\\tdisplay:block;\\n    text-align:center;\\n    color:#999;\\n    font-size:16px;\\n    margin-top:10px;\\n   line-height:20px\\n}\\n\\n.hades .tp-tab-button {\\n    display:inline-block;\\n    margin-top:15px;\\n    text-align:center;\\n\\tpadding:5px 15px;\\n  \\tcolor:#fff;\\n  \\tfont-size:14px;\\n  \\tbackground:#219bd7;\\n   \\tborder-radius:4px;\\n   font-weight:400;\\n}\\n.hades .tp-tab-inner {\\n\\ttext-align:center;\\n}\\n\\n              ","thumbs":".hades .tp-thumb { \\n      opacity:1\\n  }\\n.hades .tp-thumb-img-wrap {\\n  border-radius:50%;\\n  padding:3px;\\n  display:inline-block;\\nbackground:#000;\\n  background-color:rgba(0,0,0,0.25);\\n  width:100%;\\n  height:100%;\\n  position:relative;\\n  margin:0px;\\n  box-sizing:border-box;\\n    transition:all 0.3s;\\n    -webkit-transition:all 0.3s;\\n}\\n.hades .tp-thumb-image {\\n   padding:3px; \\n   border-radius:50%;\\n   display:block;\\n   box-sizing:border-box;\\n   position:relative;\\n    -webkit-box-shadow: inset 5px 5px 10px 0px rgba(0,0,0,0.25);\\n  -moz-box-shadow: inset 5px 5px 10px 0px rgba(0,0,0,0.25);\\n  box-shadow: inset 5px 5px 10px 0px rgba(0,0,0,0.25);\\n }  \\n\\n\\n.hades .tp-thumb:hover .tp-thumb-img-wrap,\\n.hades .tp-thumb.selected .tp-thumb-img-wrap {\\n  \\n   background: rgba(255,255,255,1);\\n  background: -moz-linear-gradient(top, rgba(255,255,255,1) 0%, rgba(119,119,119,1) 100%);\\n  background: -webkit-gradient(left top, left bottom, color-stop(0%, rgba(255,255,255,1)), color-stop(100%, rgba(119,119,119,1)));\\n  background: -webkit-linear-gradient(top, rgba(255,255,255,1) 0%, rgba(119,119,119,1) 100%);\\n  background: -o-linear-gradient(top, rgba(255,255,255,1) 0%, rgba(119,119,119,1) 100%);\\n  background: -ms-linear-gradient(top, rgba(255,255,255,1) 0%, rgba(119,119,119,1) 100%);\\n  background: linear-gradient(to bottom, rgba(255,255,255,1) 0%, rgba(119,119,119,1) 100%);\\n  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr=\\\\\\"#ffffff\\\\\\", endColorstr=\\\\\\"#777777\\\\\\", GradientType=0 );\\n \\n      }\\n.hades .tp-thumb-title:after {\\n        content:\\\\\\" \\\\\\";\\n        position:absolute;\\n        left:50%;\\n        margin-left:-8px;\\n        width: 0;\\n\\t\\theight: 0;\\n\\t\\tborder-style: solid;\\n\\t\\tborder-width: 8px 8px 0 8px;\\n\\t\\tborder-color: rgba(0,0,0,0.75) transparent transparent transparent;\\n        bottom:-8px;\\n   }\\n"},"markup":{"arrows":"<div class=\\\\\\"tp-arr-allwrapper\\\\\\">\\n\\t<div class=\\\\\\"tp-arr-imgholder\\\\\\"><\\/div>\\n<\\/div>","bullets":"<span class=\\\\\\"tp-bullet-image\\\\\\"><\\/span>","tabs":"<div class=\\\\\\"tp-tab-inner\\\\\\">\\n  <span class=\\\\\\"tp-tab-title\\\\\\">{{param1}}<\\/span>\\n  <span class=\\\\\\"tp-tab-price\\\\\\">{{param2}}<\\/span>\\n  <span class=\\\\\\"tp-tab-button\\\\\\">{{param3}}<\\/span>\\n<\\/div>","thumbs":"<span class=\\\\\\"tp-thumb-img-wrap\\\\\\">\\n  <span class=\\\\\\"tp-thumb-image\\\\\\"><\\/span>\\n<\\/span>\\n"}},"placeholders":[{"title":"Background","handle":"bg","type":"color-rgba","nav-type":"arrows","data":{"color-rgba":"rgba(0,0,0,0.25)"}},{"title":"Arrow","handle":"acolor","type":"color-rgba","nav-type":"arrows","data":{"color-rgba":"#ffffff"}},{"title":"Hover-Arrow","handle":"harrow","type":"color-rgba","nav-type":"arrows","data":{"color-rgba":"rgba(0,0,0,0.5)"}},{"title":"Hover-Background","handle":"hbg","type":"color-rgba","nav-type":"arrows","data":{"color-rgba":"#ffffff"}},{"title":"Size-Inner","handle":"innersize","type":"custom","nav-type":"bullets","data":{"custom":"3"}},{"title":"Color-Inner","handle":"colorinner","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#7f7f7f"}},{"title":"Size-Outer","handle":"outersize","type":"custom","nav-type":"bullets","data":{"custom":"5"}},{"title":"Color-Outer","handle":"outercolor","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#ffffff"}},{"title":"Hover-Outer","handle":"outerhover","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#ffffff"}},{"title":"Hover-Inner","handle":"innerhover","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#565656"}},{"title":"Image-Width","handle":"width","type":"custom","nav-type":"bullets","data":{"custom":"120"}},{"title":"Image-Height","handle":"height","type":"custom","nav-type":"bullets","data":{"custom":"60"}},{"title":"Horizontal-Offset","handle":"hoffset","type":"custom","nav-type":"bullets","data":{"custom":"0"}},{"title":"Vertical-Offset","handle":"voffset","type":"custom","nav-type":"bullets","data":{"custom":"-80"}},{"title":"Radius","handle":"radius","type":"custom","nav-type":"thumbs","data":{"custom":"50%"}},{"title":"Border","handle":"border","type":"custom","nav-type":"thumbs","data":{"custom":"3"}},{"title":"Background","handle":"bg","type":"color-rgba","nav-type":"thumbs","data":{"color-rgba":"rgba(0,0,0,0.25)"}},{"title":"Hover-Top","handle":"ht","type":"color-rgba","nav-type":"thumbs","data":{"color-rgba":"#ffffff"}},{"title":"Hover-Bottom","handle":"hb","type":"color-rgba","nav-type":"thumbs","data":{"color-rgba":"#878787"}},{"title":"Param1","handle":"param1","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"#333333"}},{"title":"Param1-Size","handle":"param1size","type":"custom","nav-type":"tabs","data":{"custom":"18"}},{"title":"Param2","handle":"param2","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"#999999"}},{"title":"Param2-Size","handle":"p2size","type":"custom","nav-type":"tabs","data":{"custom":"16"}},{"title":"Param3","handle":"p3","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"#ffffff"}},{"title":"Param3-Size","handle":"p3size","type":"custom","nav-type":"tabs","data":{"custom":"14"}},{"title":"Param3-BG","handle":"p3bg","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"#219bd7"}}]}');
			
		$navigations[] = array(
			'id' => 5003,
			'default' => true,
			'name' => 'Ares',
			'handle' => 'preview2',
			'markup' => '{"arrows":"<div class=\\\\\\"tp-title-wrap\\\\\\">\\n\\t<span class=\\\\\\"tp-arr-titleholder\\\\\\">{{title}}<\\/span>\\n <\\/div>\\n","bullets":"<span class=\\\\\\"tp-bullet-title\\\\\\">{{title}}<\\/span>","tabs":"<div class=\\\\\\"tp-tab-content\\\\\\">\\n  <span class=\\\\\\"tp-tab-date\\\\\\">{{param1}}<\\/span>\\n  <span class=\\\\\\"tp-tab-title\\\\\\">{{param2}}<\\/span>\\n<\\/div>\\n<div class=\\\\\\"tp-tab-image\\\\\\"><\\/div>"}',
			'css' => '{"arrows":".ares.tparrows {\\n\\tcursor:pointer;\\n\\tbackground:rgba(##bg-color##);\\n\\tmin-width:##bg-size##px;\\n    min-height:##bg-size##px;\\n\\tposition:absolute;\\n\\tdisplay:block;\\n\\tz-index:100;\\n    border-radius:50%;\\n}\\n.ares.tparrows:hover {\\n}\\n.ares.tparrows:before {\\n\\tfont-family: \\\\\\"revicons\\\\\\";\\n\\tfont-size:##arrow-size##px;\\n\\tcolor:rgba(##arrowcolor##);\\n\\tdisplay:block;\\n\\tline-height: ##bg-size##px;\\n\\ttext-align: center;\\n    -webkit-transition: color 0.3s;\\n    -moz-transition: color 0.3s;\\n    transition: color 0.3s;\\n    z-index:2;\\n    position:relative;\\n}\\n.ares.tparrows.tp-leftarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\e81f\\\\\\";\\n}\\n.ares.tparrows.tp-rightarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\e81e\\\\\\";\\n}\\n.ares.tparrows:hover:before {\\n color:rgb(##hover-arrow-color##);\\n      }\\n.tp-title-wrap { \\n  position:absolute;\\n  z-index:1;\\n  display:inline-block;\\n  background:rgba(##bg-color##);\\n  min-height:##bg-size##px;\\n  line-height:##bg-size##px;\\n  top:0px;\\n  margin-left:30px;\\n  border-radius:0px 30px 30px 0px;\\n  overflow:hidden;\\n  -webkit-transition: -webkit-transform 0.3s;\\n  transition: transform 0.3s;\\n  transform:scalex(0);  \\n  -webkit-transform:scalex(0);  \\n  transform-origin:0% 50%; \\n   -webkit-transform-origin:0% 50%;\\n}\\n .ares.tp-rightarrow .tp-title-wrap { \\n   right:0px;\\n   margin-right:30px;margin-left:0px;\\n   -webkit-transform-origin:100% 50%;\\nborder-radius:30px 0px 0px 30px;\\n }\\n.ares.tparrows:hover .tp-title-wrap {\\n\\ttransform:scalex(1) scaley(1);\\n  \\t-webkit-transform:scalex(1) scaley(1);\\n}\\n.ares .tp-arr-titleholder {\\n  position:relative;\\n  -webkit-transition: -webkit-transform 0.3s;\\n  transition: transform 0.3s;\\n  transform:translatex(200px);  \\n  text-transform:uppercase;\\n  color:rgb(##hover-title-color##);\\n  font-weight:400;\\n  font-size:14px;\\n  line-height:60px;\\n  white-space:nowrap;\\n  padding:0px 20px;\\n  margin-left:10px;\\n  opacity:0;\\n}\\n\\n.ares.tp-rightarrow .tp-arr-titleholder {\\n   transform:translatex(-200px); \\n   margin-left:0px; margin-right:10px;\\n      }\\n\\n.ares.tparrows:hover .tp-arr-titleholder {\\n   transform:translatex(0px);\\n   -webkit-transform:translatex(0px);\\n  transition-delay: 0.1s;\\n  opacity:1;\\n}","bullets":".ares.tp-bullets {\\n}\\n.ares.tp-bullets:before {\\n\\tcontent:\\\\\\" \\\\\\";\\n\\tposition:absolute;\\n\\twidth:100%;\\n\\theight:100%;\\n\\tbackground:transparent;\\n\\tpadding:10px;\\n\\tmargin-left:-10px;margin-top:-10px;\\n\\tbox-sizing:content-box;\\n}\\n.ares .tp-bullet {\\n\\twidth:##bullet-size##px;\\n\\theight:##bullet-size##px;\\n\\tposition:absolute;\\n\\tbackground:rgba(##bullet-bg-color##);\\n\\tborder-radius:50%;\\n\\tcursor: pointer;\\n\\tbox-sizing:content-box;\\n}\\n.ares .tp-bullet:hover,\\n.ares .tp-bullet.selected {\\n\\tbackground:rgba(##hover-bullet-bg-color##);\\n}\\n.ares .tp-bullet-title {\\n  position:absolute;\\n  color:##title-color##;\\n  font-size:##title-font-size##px;\\n  padding:0px 10px;\\n  font-weight:600;\\n  right:27px;\\n  top:-4px;  \\n  background:rgba(##title-bg-color##);\\n  visibility:hidden;\\n  transform:translatex(-20px);\\n  -webkit-transform:translatex(-20px);\\n  transition:transform 0.3s;\\n  -webkit-transition:transform 0.3s;\\n  line-height:20px;\\n  white-space:nowrap;\\n}     \\n\\n.ares .tp-bullet-title:after {\\n    width: 0px;\\n\\theight: 0px;\\n\\tborder-style: solid;\\n\\tborder-width: 10px 0 10px 10px;\\n\\tborder-color: transparent transparent transparent rgba(##title-bg-color##);\\n\\tcontent:\\\\\\" \\\\\\";\\n    position:absolute;\\n    right:-10px;\\n\\ttop:0px;\\n}\\n    \\n.ares .tp-bullet:hover .tp-bullet-title{\\n  visibility:visible;\\n   transform:translatex(0px);\\n  -webkit-transform:translatex(0px);\\n}\\n\\n.ares .tp-bullet.selected:hover .tp-bullet-title {\\n    background:rgba(##hover-bullet-bg-color##);}\\n.ares .tp-bullet.selected:hover .tp-bullet-title:after {\\n  border-color:transparent transparent transparent rgba(##hover-bullet-bg-color##);\\n}\\n.ares.tp-bullets:hover .tp-bullet-title {\\n  visibility:hidden;\\n  \\n}\\n.ares.tp-bullets:hover .tp-bullet:hover .tp-bullet-title {\\n    visibility:visible;\\n    transform:translateX(0px) translatey(0px);\\n  -webkit-transform:translateX(0px) translatey(0px);\\n}\\n\\n\\n\\/* VERTICAL *\\/\\n.ares.nav-dir-vertical.nav-pos-hor-left .tp-bullet-title { right:auto; left:27px;  transform:translatex(20px); -webkit-transform:translatex(20px);}  \\n.ares.nav-dir-vertical.nav-pos-hor-left .tp-bullet-title:after { \\n  border-width: 10px 10px 10px 0 !important;\\n  border-color: transparent rgba(##title-bg-color##) transparent transparent;\\n  right:auto !important;\\n  left:-10px !important;   \\n}\\n.ares.nav-dir-vertical.nav-pos-hor-left .tp-bullet.selected:hover .tp-bullet-title:after {\\n  border-color:  transparent rgba(##hover-bullet-bg-color##) transparent transparent !important;\\n}\\n\\n\\n\\n\\/* HORIZONTAL BOTTOM && CENTER *\\/\\n.ares.nav-dir-horizontal.nav-pos-ver-center .tp-bullet-title,\\n.ares.nav-dir-horizontal.nav-pos-ver-bottom .tp-bullet-title { top:-35px; left:50%; right:auto; transform: translateX(-50%) translateY(-10px);-webkit-transform: translateX(-50%) translateY(-10px); }  \\n\\n.ares.nav-dir-horizontal.nav-pos-ver-center .tp-bullet-title:after,\\n.ares.nav-dir-horizontal.nav-pos-ver-bottom .tp-bullet-title:after { \\n  border-width: 10px 10px 0px 10px;\\n  border-color: rgba(##title-bg-color##) transparent transparent transparent;\\n  right:auto;\\n  left:50%;\\n  margin-left:-10px;\\n  top:auto;\\n  bottom:-10px;\\n    \\n}\\n.ares.nav-dir-horizontal.nav-pos-ver-center .tp-bullet.selected:hover .tp-bullet-title:after,\\n.ares.nav-dir-horizontal.nav-pos-ver-bottom .tp-bullet.selected:hover .tp-bullet-title:after {\\n  border-color:  rgba(##hover-bullet-bg-color##) transparent transparent transparent;\\n}\\n\\n.ares.nav-dir-horizontal.nav-pos-ver-center .tp-bullet:hover .tp-bullet-title,\\n.ares.nav-dir-horizontal.nav-pos-ver-bottom .tp-bullet:hover .tp-bullet-title{\\n   transform:translateX(-50%) translatey(0px);\\n  -webkit-transform:translateX(-50%) translatey(0px);\\n}\\n\\n\\n\\/* HORIZONTAL TOP *\\/\\n.ares.nav-dir-horizontal.nav-pos-ver-top .tp-bullet-title { top:25px; left:50%; right:auto; transform: translateX(-50%) translateY(10px);-webkit-transform: translateX(-50%) translateY(10px); }  \\n.ares.nav-dir-horizontal.nav-pos-ver-top .tp-bullet-title:after { \\n  border-width: 0 10px 10px 10px;\\n  border-color:  transparent transparent rgba(##title-bg-color##) transparent;\\n  right:auto;\\n  left:50%;\\n  margin-left:-10px;\\n  bottom:auto;\\n  top:-10px;\\n    \\n}\\n.ares.nav-dir-horizontal.nav-pos-ver-top .tp-bullet.selected:hover .tp-bullet-title:after {\\n  border-color:  transparent transparent  rgba(##hover-bullet-bg-color##) transparent;\\n}\\n\\n.ares.nav-dir-horizontal.nav-pos-ver-top .tp-bullet:hover .tp-bullet-title{\\n   transform:translateX(-50%) translatey(0px);\\n  -webkit-transform:translateX(-50%) translatey(0px);\\n}\\n\\n","tabs":".ares .tp-tab { \\n  opacity:1;      \\n  padding:10px;\\n  box-sizing:border-box;\\n  font-family: \\\\\\"##font-family##\\\\\\", sans-serif;\\n  border-bottom: ##bottom-border-size##px solid rgb(##bottom-border-color##);\\n  background:rgb(##idle-bg-color);\\n }\\n.ares .tp-tab-image \\n{ \\n  width:##image-size##px;\\n  height:##image-size##px; max-height:100%; max-width:100%;\\n  position:relative;\\n  display:inline-block;\\n  float:left;\\n\\n}\\n.ares .tp-tab-content \\n{\\n    background:rgba(0,0,0,0); \\n    position:relative;\\n    padding:15px 15px 15px 85px;\\n left:0px;\\n overflow:hidden;\\n margin-top:-15px;\\n    box-sizing:border-box;\\n    color:#333;\\n    display: inline-block;\\n    width:100%;\\n    height:100%;\\n position:absolute; }\\n.ares .tp-tab-date\\n  {\\n  display:block;\\n  color: rgb(##param1-color##);\\n  font-weight:500;\\n  font-size:##param1-size##px;\\n  margin-bottom:0px;\\n  }\\n.ares .tp-tab-title \\n{\\n    display:block;\\t\\n    text-align:left;\\n    color:rgb(##param2-color##);\\n    font-size:##param2-size##px;\\n    font-weight:500;\\n    text-transform:none;\\n    line-height:17px;\\n}\\n.ares .tp-tab:hover,\\n.ares .tp-tab.selected {\\n\\tbackground:rgb(##hover-bg-color##); \\n}\\n\\n.ares .tp-tab-mask {\\n}\\n\\n\\/* media queries *\\/\\n@media only screen and (max-width: 960px) {\\n\\n}\\n@media only screen and (max-width: 768px) {\\n\\n}"}',
			'settings' => '{"width":{"tabs":"250"},"height":{"tabs":"80"},"original":{"css":{"arrows":".ares.tparrows {\\n\\tcursor:pointer;\\n\\tbackground:#fff;\\n\\tmin-width:60px;\\n    min-height:60px;\\n\\tposition:absolute;\\n\\tdisplay:block;\\n\\tz-index:100;\\n    border-radius:50%;\\n}\\n.ares.tparrows:hover {\\n}\\n.ares.tparrows:before {\\n\\tfont-family: \\\\\\"revicons\\\\\\";\\n\\tfont-size:25px;\\n\\tcolor:#aaa;\\n\\tdisplay:block;\\n\\tline-height: 60px;\\n\\ttext-align: center;\\n    -webkit-transition: color 0.3s;\\n    -moz-transition: color 0.3s;\\n    transition: color 0.3s;\\n    z-index:2;\\n    position:relative;\\n}\\n.ares.tparrows.tp-leftarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\\e81f\\\\\\";\\n}\\n.ares.tparrows.tp-rightarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\\e81e\\\\\\";\\n}\\n.ares.tparrows:hover:before {\\n color:#000;\\n      }\\n.tp-title-wrap { \\n  position:absolute;\\n  z-index:1;\\n  display:inline-block;\\n  background:#fff;\\n  min-height:60px;\\n  line-height:60px;\\n  top:0px;\\n  margin-left:30px;\\n  border-radius:0px 30px 30px 0px;\\n  overflow:hidden;\\n  -webkit-transition: -webkit-transform 0.3s;\\n  transition: transform 0.3s;\\n  transform:scaleX(0);  \\n  -webkit-transform:scaleX(0);  \\n  transform-origin:0% 50%; \\n   -webkit-transform-origin:0% 50%;\\n}\\n .ares.tp-rightarrow .tp-title-wrap { \\n   right:0px;\\n   margin-right:30px;margin-left:0px;\\n   -webkit-transform-origin:100% 50%;\\nborder-radius:30px 0px 0px 30px;\\n }\\n.ares.tparrows:hover .tp-title-wrap {\\n\\ttransform:scaleX(1) scaleY(1);\\n  \\t-webkit-transform:scaleX(1) scaleY(1);\\n}\\n.ares .tp-arr-titleholder {\\n  position:relative;\\n  -webkit-transition: -webkit-transform 0.3s;\\n  transition: transform 0.3s;\\n  transform:translateX(200px);  \\n  text-transform:uppercase;\\n  color:#000;\\n  font-weight:400;\\n  font-size:14px;\\n  line-height:60px;\\n  white-space:nowrap;\\n  padding:0px 20px;\\n  margin-left:10px;\\n  opacity:0;\\n}\\n\\n.ares.tp-rightarrow .tp-arr-titleholder {\\n   transform:translateX(-200px); \\n   margin-left:0px; margin-right:10px;\\n      }\\n\\n.ares.tparrows:hover .tp-arr-titleholder {\\n   transform:translateX(0px);\\n   -webkit-transform:translateX(0px);\\n  transition-delay: 0.1s;\\n  opacity:1;\\n}","bullets":".ares.tp-bullets {\\n}\\n.ares.tp-bullets:before {\\n\\tcontent:\\\\\\" \\\\\\";\\n\\tposition:absolute;\\n\\twidth:100%;\\n\\theight:100%;\\n\\tbackground:transparent;\\n\\tpadding:10px;\\n\\tmargin-left:-10px;margin-top:-10px;\\n\\tbox-sizing:content-box;\\n}\\n.ares .tp-bullet {\\n\\twidth:13px;\\n\\theight:13px;\\n\\tposition:absolute;\\n\\tbackground:#e5e5e5;\\n\\tborder-radius:50%;\\n\\tcursor: pointer;\\n\\tbox-sizing:content-box;\\n}\\n.ares .tp-bullet:hover,\\n.ares .tp-bullet.selected {\\n\\tbackground:#fff;\\n}\\n.ares .tp-bullet-title {\\n  position:absolute;\\n  color:#888;\\n  font-size:12px;\\n  padding:0px 10px;\\n  font-weight:600;\\n  right:27px;\\n  top:-4px;\\n  background:#fff;\\n  background:rgba(255,255,255,0.75);\\n  visibility:hidden;\\n  transform:translateX(-20px);\\n  -webkit-transform:translateX(-20px);\\n  transition:transform 0.3s;\\n  -webkit-transition:transform 0.3s;\\n  line-height:20px;\\n  white-space:nowrap;\\n}     \\n\\n.ares .tp-bullet-title:after {\\n    width: 0px;\\n\\theight: 0px;\\n\\tborder-style: solid;\\n\\tborder-width: 10px 0 10px 10px;\\n\\tborder-color: transparent transparent transparent rgba(255,255,255,0.75);\\n\\tcontent:\\\\\\" \\\\\\";\\n    position:absolute;\\n    right:-10px;\\n\\ttop:0px;\\n}\\n    \\n.ares .tp-bullet:hover .tp-bullet-title{\\n  visibility:visible;\\n   transform:translateX(0px);\\n  -webkit-transform:translateX(0px);\\n}\\n\\n.ares .tp-bullet.selected:hover .tp-bullet-title {\\n    background:#fff;\\n        }\\n.ares .tp-bullet.selected:hover .tp-bullet-title:after {\\n  border-color:transparent transparent transparent #fff;\\n}\\n.ares.tp-bullets:hover .tp-bullet-title {\\n        visibility:hidden;\\n}\\n.ares.tp-bullets:hover .tp-bullet:hover .tp-bullet-title {\\n    visibility:visible;\\n      }","tabs":".ares .tp-tab { \\n  opacity:1;      \\n  padding:10px;\\n  box-sizing:border-box;\\n  font-family: \\\\\\"Roboto\\\\\\", sans-serif;\\n  border-bottom: 1px solid #e5e5e5;\\n }\\n.ares .tp-tab-image \\n{ \\n  width:60px;\\n  height:60px; max-height:100%; max-width:100%;\\n  position:relative;\\n  display:inline-block;\\n  float:left;\\n\\n}\\n.ares .tp-tab-content \\n{\\n    background:rgba(0,0,0,0); \\n    position:relative;\\n    padding:15px 15px 15px 85px;\\n left:0px;\\n overflow:hidden;\\n margin-top:-15px;\\n    box-sizing:border-box;\\n    color:#333;\\n    display: inline-block;\\n    width:100%;\\n    height:100%;\\n position:absolute; }\\n.ares .tp-tab-date\\n  {\\n  display:block;\\n  color: #aaa;\\n  font-weight:500;\\n  font-size:12px;\\n  margin-bottom:0px;\\n  }\\n.ares .tp-tab-title \\n{\\n    display:block;\\t\\n    text-align:left;\\n    color:#333;\\n    font-size:14px;\\n    font-weight:500;\\n    text-transform:none;\\n    line-height:17px;\\n}\\n.ares .tp-tab:hover,\\n.ares .tp-tab.selected {\\n\\tbackground:#eee; \\n}\\n\\n.ares .tp-tab-mask {\\n}\\n\\n\\/* MEDIA QUERIES *\\/\\n@media only screen and (max-width: 960px) {\\n\\n}\\n@media only screen and (max-width: 768px) {\\n\\n}"},"markup":{"arrows":"<div class=\\\\\\"tp-title-wrap\\\\\\">\\n\\t<span class=\\\\\\"tp-arr-titleholder\\\\\\">{{title}}<\\/span>\\n <\\/div>\\n","bullets":"<span class=\\\\\\"tp-bullet-title\\\\\\">{{title}}<\\/span>","tabs":"<div class=\\\\\\"tp-tab-content\\\\\\">\\n  <span class=\\\\\\"tp-tab-date\\\\\\">{{param1}}<\\/span>\\n  <span class=\\\\\\"tp-tab-title\\\\\\">{{param2}}<\\/span>\\n<\\/div>\\n<div class=\\\\\\"tp-tab-image\\\\\\"><\\/div>"}},"placeholders":[{"title":"BG-Color","handle":"bg-color","type":"color-rgba","nav-type":"arrows","data":{"color-rgba":"#ffffff"}},{"title":"Size","handle":"bg-size","type":"custom","nav-type":"arrows","data":{"custom":"60"}},{"title":"Arrow-Size","handle":"arrow-size","type":"custom","nav-type":"arrows","data":{"custom":"25"}},{"title":"Hover-Arrow","handle":"hover-arrow-color","type":"color","nav-type":"arrows","data":{"color":"#000000"}},{"title":"Hover-Title","handle":"hover-title-color","type":"color","nav-type":"arrows","data":{"color":"#000000"}},{"title":"Bullet-Size","handle":"bullet-size","type":"custom","nav-type":"bullets","data":{"custom":"13"}},{"title":"Bullet-Background","handle":"bullet-bg-color","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#e5e5e5"}},{"title":"Hover-Bullet-BG","handle":"hover-bullet-bg-color","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#ffffff"}},{"title":"Title-Color","handle":"title-color","type":"color","nav-type":"bullets","data":{"color":"#888888"}},{"title":"Title-Font-Size","handle":"title-font-size","type":"custom","nav-type":"bullets","data":{"custom":"12"}},{"title":"Title-BG-Color","handle":"title-bg-color","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"rgba(255,255,255,0.75)"}},{"title":"Font-Family","handle":"font-family","type":"font-family","nav-type":"tabs","data":{"font_family":"Roboto"}},{"title":"Bottom-Border","handle":"bottom-border-color","type":"color","nav-type":"tabs","data":{"color":"#e5e5e5"}},{"title":"Bottom-Border-Size","handle":"bottom-border-size","type":"custom","nav-type":"tabs","data":{"custom":"1"}},{"title":"Image-Size","handle":"image-size","type":"custom","nav-type":"tabs","data":{"custom":"60"}},{"title":"Param-1-Color","handle":"param1-color","type":"color","nav-type":"tabs","data":{"color":"#aaaaaa"}},{"title":"Param-1-Size","handle":"param1-size","type":"custom","nav-type":"tabs","data":{"custom":"12"}},{"title":"Param-2-Color","handle":"param2-color","type":"color","nav-type":"tabs","data":{"color":"#333333"}},{"title":"Param-2-Size","handle":"param2-size","type":"custom","nav-type":"tabs","data":{"custom":"14"}},{"title":"Hover-Background","handle":"hover-bg-color","type":"color","nav-type":"tabs","data":{"color":"#eeeeee"}},{"title":"Idle-Background","handle":"idle-bg-color","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"rgba(0,0,0,0)"}},{"title":"Arrow-Color","handle":"arrowcolor","type":"color-rgba","nav-type":"arrows","data":{"color-rgba":"#aaaaaa"}}]}');
			
		$navigations[] = array(
			'id' => 5004,
			'default' => true,
			'name' => 'Hebe',
			'handle' => 'preview3',
			'markup' => '{"arrows":"<div class=\\\\\\"tp-title-wrap\\\\\\">\\n\\t<span class=\\\\\\"tp-arr-titleholder\\\\\\">{{title}}<\\/span>\\n    <span class=\\\\\\"tp-arr-imgholder\\\\\\"><\\/span>\\n <\\/div>\\n","bullets":"<span class=\\\\\\"tp-bullet-image\\\\\\"><\\/span>","tabs":"<div class=\\\\\\"tp-tab-title\\\\\\">{{param1}}<\\/div>\\n<div class=\\\\\\"tp-tab-desc\\\\\\">{{title}}<\\/div>"}',
			'css' => '{"arrows":".hebe.tparrows {\\n  cursor:pointer;\\n  background:rgba(##back-color##);\\n  min-width:##back-size##px;\\n  min-height:##back-size##px;\\n  position:absolute;\\n  display:block;\\n  z-index:100;\\n}\\n.hebe.tparrows:hover {\\n}\\n.hebe.tparrows:before {\\n  font-family: \\\\\\"revicons\\\\\\";\\n  font-size:##arrow-size##px;\\n  color:rgba(##arrow-color##);\\n  display:block;\\n  line-height: ##back-size##px;\\n  text-align: center;\\n  -webkit-transition: color 0.3s;\\n  -moz-transition: color 0.3s;\\n  transition: color 0.3s;\\n  z-index:2;\\n  position:relative;\\n   background:rgba(##back-color##);\\n  min-width:##back-size##px;\\n    min-height:##back-size##px;\\n}\\n.hebe.tparrows.tp-leftarrow:before {\\n  content: \\\\\\"\\\\\\\e824\\\\\\";\\n}\\n.hebe.tparrows.tp-rightarrow:before {\\n  content: \\\\\\"\\\\\\\e825\\\\\\";\\n}\\n.hebe.tparrows:hover:before {\\n color:#000;\\n      }\\n.tp-title-wrap { \\n  position:absolute;\\n  z-index:0;\\n  display:inline-block;\\n  background:#000;\\n  background:rgba(##title-wrap-color##);\\n  min-height:60px;\\n  line-height:60px;\\n  top:-10px;\\n  margin-left:0px;\\n  -webkit-transition: -webkit-transform 0.3s;\\n  transition: transform 0.3s;\\n  transform:scalex(0);  \\n  -webkit-transform:scalex(0);  \\n  transform-origin:0% 50%; \\n   -webkit-transform-origin:0% 50%;\\n}\\n .hebe.tp-rightarrow .tp-title-wrap { \\n   right:0px;\\n   -webkit-transform-origin:100% 50%;\\n }\\n.hebe.tparrows:hover .tp-title-wrap {\\n  transform:scalex(1);\\n  -webkit-transform:scalex(1);\\n}\\n.hebe .tp-arr-titleholder {\\n  position:relative;\\n  text-transform:uppercase;\\n  color:rgb(##title-color##);\\n  font-weight:600;\\n  font-size:##title-size##px;\\n  line-height:##image-size##px;\\n  white-space:nowrap;\\n  padding:0px 20px 0px ##image-size##px;\\n}\\n\\n.hebe.tp-rightarrow .tp-arr-titleholder {\\n   margin-left:0px; \\n   padding:0px ##image-size##px 0px 20px;\\n }\\n\\n.hebe.tparrows:hover .tp-arr-titleholder {\\n   transform:translatex(0px);\\n   -webkit-transform:translatex(0px);\\n  transition-delay: 0.1s;\\n  opacity:1;\\n}\\n\\n.hebe .tp-arr-imgholder{\\n      width:##image-size##px;\\n      height:##image-size##px;\\n      position:absolute;\\n      left:100%;\\n      display:block;\\n      background-size:cover;\\n      background-position:center center;\\n  \\t top:0px; right:-##image-size##px;\\n    }\\n.hebe.tp-rightarrow .tp-arr-imgholder{\\n        right:auto;left:-##image-size##px;\\n      }","bullets":"\\n.hebe.tp-bullets:before {\\n  content:\\\\\\" \\\\\\";\\n  position:absolute;\\n  width:100%;\\n  height:100%;\\n  background:transparent;\\n  padding:10px;\\n  margin-left:-10px;margin-top:-10px;\\n  box-sizing:content-box;\\n}\\n\\n.hebe .tp-bullet {\\n  width:##bullet-back-size##px;\\n  height:##bullet-back-size##px;\\n  position:absolute;\\n  background:rgba(##bullet-back-color##);  \\n  cursor: pointer;\\n  border:##bullet-border-size##px solid rgba(##bullet-border-color##);\\n  border-radius:##bradius##;\\n  box-sizing:content-box;\\n  -webkit-perspective:400;\\n  perspective:400;\\n  -webkit-transform:translatez(0.01px);\\n  transform:translatez(0.01px);\\n   transition:all ##aspeed##s;\\n}\\n.hebe .tp-bullet:hover,\\n.hebe .tp-bullet.selected {\\n  background:rgba(##bullet-border-color##);\\n  border-color:rgba(##bullet-back-color##);\\n}\\n\\n.hebe .tp-bullet-image {\\n  position:absolute;\\n  width:##width##px;\\n  height:##height##px;\\n  background-position:center center;\\n  background-size:cover;\\n  visibility:hidden;\\n  opacity:0;\\n  bottom:##bullet-back-size##px;\\n  transition:all ##aspeed##s;\\n  -webkit-transform-style:flat;\\n  transform-style:flat;\\n  perspective:600;\\n  -webkit-perspective:600;\\n  transform: scale(0) translateX(-50%) translateY(0%);\\n  -webkit-transform: scale(0) translateX(-50%) translateY(0%);\\n  transform-origin:0% 100%;\\n  -webkit-transform-origin:0% 100%;\\n  margin-bottom:15px;\\n border-radius:##iradius##px;\\n}\\n.hebe .tp-bullet:hover .tp-bullet-image {\\n  display:block;\\n  opacity:1;\\n  transform: scale(1) translateX(-50%) translateY(0%);\\n  -webkit-transform: scale(1) translateX(-50%) translateY(0%);\\n  visibility:visible;\\n}\\n\\n\\n\\/* VERTICAL *\\/\\n\\n.hebe.nav-dir-vertical .tp-bullet-image {\\n  bottom:auto;\\n  margin-right:15px;\\n  margin-bottom:0px;\\n  right:##bullet-back-size##px;\\n  transform: scale(0) translateX(0px) translateY(-50%);\\n  -webkit-transform: scale(0) translateX(0px) translateY(-50%);\\n  transform-origin:100% 0%;\\n  -webkit-transform-origin:100% 0%;\\n}\\n\\n.hebe.nav-dir-vertical .tp-bullet:hover .tp-bullet-image {\\n  transform: scale(1) translateX(0px) translateY(-50%);\\n  -webkit-transform: scale(1) translateX(0px) translateY(-50%);\\n}\\n\\n\\/* VERTICAL LEFT *\\/\\n\\n.hebe.nav-dir-vertical.nav-pos-hor-left .tp-bullet-image {\\n  bottom:auto;\\n  margin-left:15px;\\n  margin-bottom:0px;\\n  left:##bullet-back-size##px;\\n  transform: scale(0) translateX(0px) translateY(-50%);\\n  -webkit-transform: scale(0) translateX(0px) translateY(-50%);\\n  transform-origin:0% 0%;\\n  -webkit-transform-origin:0% 0%;\\n}\\n\\n.hebe.nav-dir-vertical.nav-pos-hor-left .tp-bullet:hover .tp-bullet-image {\\n  transform: scale(1) translateX(0px) translateY(-50%);\\n  -webkit-transform: scale(1) translateX(0px) translateY(-50%);\\n}\\n\\n\\/* HORIZONTAL TOP *\\/\\n.hebe.nav-pos-ver-top.nav-dir-horizontal .tp-bullet-image {\\n  bottom:auto;\\n  top:##bullet-back-size##px;\\n  transform: scale(0) translateX(-50%) translateY(0%);\\n  -webkit-transform: scale(0) translateX(-50%) translateY(0%);\\n  transform-origin:0% 0%;\\n  -webkit-transform-origin:0% 0%;\\n  margin-top:15px;\\n  margin-bottom:0px;  \\n}\\n.hebe.nav-pos-ver-top.nav-dir-horizontal .tp-bullet:hover .tp-bullet-image {\\n  transform: scale(1) translateX(-50%) translateY(0%);\\n  -webkit-transform: scale(1) translateX(-50%) translateY(0%);\\n}","tabs":".hebe .tp-tab-title {\\n    color:rgb(##title-color##);\\n    font-size:##title-size##px;\\n    font-weight:700;\\n    text-transform:uppercase;\\n    font-family:\\\\\\"##title-font##\\\\\\"\\n    margin-bottom:5px;\\n}\\n\\n.hebe .tp-tab-desc {\\n\\tfont-size:##param1-size##px;\\n    font-weight:400;\\n    color:rgb(##param1-color##);\\n    line-height:25px;\\n\\tfont-family:\\\\\\"##param1-font##\\\\\\";\\n}\\n"}',
			'settings' => '{"original":{"css":{"arrows":".hebe.tparrows {\\n  cursor:pointer;\\n  background:#fff;\\n  min-width:70px;\\n    min-height:70px;\\n  position:absolute;\\n  display:block;\\n  z-index:100;\\n}\\n.hebe.tparrows:hover {\\n}\\n.hebe.tparrows:before {\\n  font-family: \\\\\\"revicons\\\\\\";\\n  font-size:30px;\\n  color:#aaa;\\n  display:block;\\n  line-height: 70px;\\n  text-align: center;\\n  -webkit-transition: color 0.3s;\\n  -moz-transition: color 0.3s;\\n  transition: color 0.3s;\\n  z-index:2;\\n  position:relative;\\n   background:#fff;\\n  min-width:70px;\\n    min-height:70px;\\n}\\n.hebe.tparrows.tp-leftarrow:before {\\n  content: \\\\\\"\\\\\\\\e824\\\\\\";\\n}\\n.hebe.tparrows.tp-rightarrow:before {\\n  content: \\\\\\"\\\\\\\\e825\\\\\\";\\n}\\n.hebe.tparrows:hover:before {\\n color:#000;\\n      }\\n.tp-title-wrap { \\n  position:absolute;\\n  z-index:0;\\n  display:inline-block;\\n  background:#000;\\n  background:rgba(0,0,0,0.75);\\n  min-height:60px;\\n  line-height:60px;\\n  top:-10px;\\n  margin-left:0px;\\n  -webkit-transition: -webkit-transform 0.3s;\\n  transition: transform 0.3s;\\n  transform:scaleX(0);  \\n  -webkit-transform:scaleX(0);  \\n  transform-origin:0% 50%; \\n   -webkit-transform-origin:0% 50%;\\n}\\n .hebe.tp-rightarrow .tp-title-wrap { \\n   right:0px;\\n   -webkit-transform-origin:100% 50%;\\n }\\n.hebe.tparrows:hover .tp-title-wrap {\\n  transform:scaleX(1);\\n  -webkit-transform:scaleX(1);\\n}\\n.hebe .tp-arr-titleholder {\\n  position:relative;\\n  text-transform:uppercase;\\n  color:#fff;\\n  font-weight:600;\\n  font-size:12px;\\n  line-height:90px;\\n  white-space:nowrap;\\n  padding:0px 20px 0px 90px;\\n}\\n\\n.hebe.tp-rightarrow .tp-arr-titleholder {\\n   margin-left:0px; \\n   padding:0px 90px 0px 20px;\\n }\\n\\n.hebe.tparrows:hover .tp-arr-titleholder {\\n   transform:translateX(0px);\\n   -webkit-transform:translateX(0px);\\n  transition-delay: 0.1s;\\n  opacity:1;\\n}\\n\\n.hebe .tp-arr-imgholder{\\n      width:90px;\\n      height:90px;\\n      position:absolute;\\n      left:100%;\\n      display:block;\\n      background-size:cover;\\n      background-position:center center;\\n  \\t top:0px; right:-90px;\\n    }\\n.hebe.tp-rightarrow .tp-arr-imgholder{\\n        right:auto;left:-90px;\\n      }","bullets":".hebe.tp-bullets {\\n}\\n.hebe.tp-bullets:before {\\n  content:\\\\\\" \\\\\\";\\n  position:absolute;\\n  width:100%;\\n  height:100%;\\n  background:transparent;\\n  padding:10px;\\n  margin-left:-10px;margin-top:-10px;\\n  box-sizing:content-box;\\n}\\n\\n.hebe .tp-bullet {\\n  width:3px;\\n  height:3px;\\n  position:absolute;\\n  background:#fff;  \\n  cursor: pointer;\\n  border:5px solid #222;\\n  border-radius:50%;\\n  box-sizing:content-box;\\n  -webkit-perspective:400;\\n  perspective:400;\\n  -webkit-transform:translateZ(0.01px);\\n  transform:translateZ(0.01px);\\n   transition:all 0.3s;\\n}\\n.hebe .tp-bullet:hover,\\n.hebe .tp-bullet.selected {\\n  background:#222;\\n  border-color:#fff;\\n}\\n\\n.hebe .tp-bullet-image {\\n  position:absolute;\\n  top:-90px; left:-40px;\\n  width:70px;\\n  height:70px;\\n  background-position:center center;\\n  background-size:cover;\\n  visibility:hidden;\\n  opacity:0;\\n  transition:all 0.3s;\\n  -webkit-transform-style:flat;\\n  transform-style:flat;\\n  perspective:600;\\n  -webkit-perspective:600;\\n  transform: scale(0);\\n  -webkit-transform: scale(0);\\n  transform-origin:50% 100%;\\n  -webkit-transform-origin:50% 100%;\\nborder-radius:6px;\\n  \\n  \\n}\\n.hebe .tp-bullet:hover .tp-bullet-image {\\n  display:block;\\n  opacity:1;\\n  transform: scale(1);\\n  -webkit-transform: scale(1);\\n  visibility:visible;\\n    }\\n.hebe .tp-bullet-title {\\n}\\n","tabs":".hebe .tp-tab-title {\\n    color:#a8d8ee;\\n    font-size:13px;\\n    font-weight:700;\\n    text-transform:uppercase;\\n    font-family:\\\\\\"Roboto Slab\\\\\\"\\n    margin-bottom:5px;\\n}\\n\\n.hebe .tp-tab-desc {\\n\\tfont-size:18px;\\n    font-weight:400;\\n    color:#fff;\\n    line-height:25px;\\n\\tfont-family:\\\\\\"Roboto Slab\\\\\\";\\n}\\n"},"markup":{"arrows":"<div class=\\\\\\"tp-title-wrap\\\\\\">\\n\\t<span class=\\\\\\"tp-arr-titleholder\\\\\\">{{title}}<\\/span>\\n    <span class=\\\\\\"tp-arr-imgholder\\\\\\"><\\/span>\\n <\\/div>\\n","bullets":"<span class=\\\\\\"tp-bullet-image\\\\\\"><\\/span>","tabs":"<div class=\\\\\\"tp-tab-title\\\\\\">{{param1}}<\\/div>\\n<div class=\\\\\\"tp-tab-desc\\\\\\">{{title}}<\\/div>"}},"placeholders":[{"title":"BG-Size","handle":"back-size","type":"custom","nav-type":"arrows","data":{"custom":"70"}},{"title":"Background","handle":"back-color","type":"color-rgba","nav-type":"arrows","data":{"color-rgba":"#ffffff"}},{"title":"Arrow-Color","handle":"arrow-color","type":"color-rgba","nav-type":"arrows","data":{"color-rgba":"rgba(0,0,0,0.5)"}},{"title":"Arrow-Size","handle":"arrow-size","type":"custom","nav-type":"arrows","data":{"custom":"30"}},{"title":"Image-Size","handle":"image-size","type":"custom","nav-type":"arrows","data":{"custom":"90"}},{"title":"Title-Wrap-BG-Color","handle":"title-wrap-color","type":"custom","nav-type":"arrows","data":{"custom":"0,0,0,0.75"}},{"title":"Title-Color","handle":"title-color","type":"color","nav-type":"arrows","data":{"color":"#ffffff"}},{"title":"Title-Size","handle":"title-size","type":"custom","nav-type":"arrows","data":{"custom":"12"}},{"title":"Bullet-Background","handle":"bullet-back-color","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#ffffff"}},{"title":"Bullet-Border-Color","handle":"bullet-border-color","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"#000000"}},{"title":"Bullet-Border-Size","handle":"bullet-border-size","type":"custom","nav-type":"bullets","data":{"custom":"5"}},{"title":"Bullet-BG-Size","handle":"bullet-back-size","type":"custom","nav-type":"bullets","data":{"custom":"3"}},"","","",{"title":"Title-Color","handle":"title-color","type":"color","nav-type":"tabs","data":{"color":"#a8d8ee"}},{"title":"Title-Size","handle":"title-size","type":"custom","nav-type":"tabs","data":{"custom":"13"}},{"title":"Title-Font","handle":"title-font","type":"font-family","nav-type":"tabs","data":{"font_family":"Roboto Slab"}},{"title":"Param-1-Color","handle":"param1-color","type":"color","nav-type":"tabs","data":{"color":"#ffffff"}},{"title":"Param-1-Size","handle":"param1-size","type":"custom","nav-type":"tabs","data":{"custom":"18"}},{"title":"Param-1-Font","handle":"param1-font","type":"font-family","nav-type":"tabs","data":{"font_family":"Roboto Slab"}},{"title":"Image-Width","handle":"width","type":"custom","nav-type":"bullets","data":{"custom":"70"}},{"title":"Image-Height","handle":"height","type":"custom","nav-type":"bullets","data":{"custom":"70"}},{"title":"Image-Radius","handle":"iradius","type":"custom","nav-type":"bullets","data":{"custom":"6"}},{"title":"Bullet-Radius","handle":"bradius","type":"custom","nav-type":"bullets","data":{"custom":"50%"}},{"title":"Animation-Speed","handle":"aspeed","type":"custom","nav-type":"bullets","data":{"custom":"0.3"}}]}');
			
		$navigations[] = array(
			'id' => 5005,
			'default' => true,
			'name' => 'Hermes',
			'handle' => 'preview4',
			'markup' => '{"arrows":"<div class=\\\\\\"tp-arr-allwrapper\\\\\\">\\n\\t<div class=\\\\\\"tp-arr-imgholder\\\\\\"><\\/div>\\n\\t<div class=\\\\\\"tp-arr-titleholder\\\\\\">{{title}}<\\/div>\\t\\n<\\/div>","bullets":"","tabs":"<span class=\\\\\\"tp-tab-image\\\\\\"><\\/span>\\n<span class=\\\\\\"tp-tab-content-wrapper\\\\\\">\\n<span class=\\\\\\"tp-tab-bg\\\\\\"><\\/span>\\n<span class=\\\\\\"tp-tab-content\\\\\\">\\n\\t<span class=\\\\\\"tp-tab-date\\\\\\">{{param1}}<\\/span>\\n\\t<span class=\\\\\\"tp-tab-title\\\\\\">{{param2}}<\\/span>\\n<\\/span>\\n<\\/span>"}',
			'css' => '{"arrows":".hermes.tparrows {\\n\\tcursor:pointer;\\n\\tbackground:rgba(##back-color##);\\n\\twidth:##width##px;\\n\\theight:##height##px;\\n\\tposition:absolute;\\n\\tdisplay:block;\\n\\tz-index:100;\\n}\\n\\n.hermes.tparrows:before {\\n\\tfont-family: \\\\\\"revicons\\\\\\";\\n\\tfont-size:##arrow-size##px;\\n\\tcolor:rgb(##arrow-color##);\\n\\tdisplay:block;\\n\\tline-height: ##height##px;\\n\\ttext-align: center;\\n    transform:translatex(0px);\\n    -webkit-transform:translatex(0px);\\n    transition:all 0.3s;\\n    -webkit-transition:all 0.3s;\\n}\\n.hermes.tparrows.tp-leftarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\e824\\\\\\";\\n}\\n.hermes.tparrows.tp-rightarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\e825\\\\\\";\\n}\\n.hermes.tparrows.tp-leftarrow:hover:before {\\n    transform:translatex(-20px);\\n    -webkit-transform:translatex(-20px);\\n     opacity:0;\\n}\\n.hermes.tparrows.tp-rightarrow:hover:before {\\n    transform:translatex(20px);\\n    -webkit-transform:translatex(20px);\\n     opacity:0;\\n}\\n\\n.hermes .tp-arr-allwrapper {\\n    overflow:hidden;\\n    position:absolute;\\n\\twidth:##wrapper-width##px;\\n    height:##wrapper-height##px;\\n    top:0px;\\n    left:0px;\\n    visibility:hidden;\\n      -webkit-transition: -webkit-transform 0.3s 0.3s;\\n  transition: transform 0.3s 0.3s;\\n  -webkit-perspective: 1000px;\\n  perspective: 1000px;\\n    }\\n.hermes.tp-rightarrow .tp-arr-allwrapper {\\n   right:0px;left:auto;\\n      }\\n.hermes.tparrows:hover .tp-arr-allwrapper {\\n   visibility:visible;\\n          }\\n.hermes .tp-arr-imgholder {\\n  width:##wrapper-width##px;position:absolute;\\n  left:0px;top:0px;height:##height##px;\\n  transform:translatex(-##wrapper-width##px);\\n  -webkit-transform:translatex(-##wrapper-width##px);\\n  transition:all 0.3s;\\n  transition-delay:0.3s;\\n}\\n.hermes.tp-rightarrow .tp-arr-imgholder{\\n    transform:translatex(##wrapper-width##px);\\n  -webkit-transform:translatex(##wrapper-width##px);\\n      }\\n  \\n.hermes.tparrows:hover .tp-arr-imgholder {\\n   transform:translatex(0px);\\n   -webkit-transform:translatex(0px);            \\n}\\n.hermes .tp-arr-titleholder {\\n  top:##height##px;\\n  width:##wrapper-width##px;\\n  text-align:left; \\n  display:block;\\n  padding:0px 10px;\\n  line-height:30px; background:#000;\\n  background:rgba(##title-back-color##);\\n  color:rgb(##title-font-color##);\\n  font-weight:600; position:absolute;\\n  font-size:##title-size##px;\\n  white-space:nowrap;\\n  letter-spacing:1px;\\n  -webkit-transition: all 0.3s;\\n  transition: all 0.3s;\\n  -webkit-transform: rotatex(-90deg);\\n  transform: rotatex(-90deg);\\n  -webkit-transform-origin: 50% 0;\\n  transform-origin: 50% 0;\\n  box-sizing:border-box;\\n\\n}\\n.hermes.tparrows:hover .tp-arr-titleholder {\\n    -webkit-transition-delay: 0.6s;\\n  transition-delay: 0.6s;\\n  -webkit-transform: rotatex(0deg);\\n  transform: rotatex(0deg);\\n}\\n","bullets":".hermes.tp-bullets {\\n}\\n\\n.hermes .tp-bullet {\\n    overflow:hidden;\\n    border-radius:50%;\\n    width:##bullet-size##px;\\n    height:##bullet-size##px;\\n    background-color: rgba(0, 0, 0, 0);\\n    box-shadow: inset 0 0 0 ##border##px rgb(##bullet-color##);\\n    -webkit-transition: background 0.3s ease;\\n    transition: background 0.3s ease;\\n    position:absolute;\\n}\\n\\n.hermes .tp-bullet:hover {\\n\\t  background-color: rgba(##bullet-hover##);\\n}\\n.hermes .tp-bullet:after {\\n  content: \\\\\' \\\\\';\\n  position: absolute;\\n  bottom: 0;\\n  height: 0;\\n  left: 0;\\n  width: 100%;\\n  background-color: rgb(##bullet-color##);\\n  box-shadow: 0 0 1px rgb(##bullet-color##);\\n  -webkit-transition: height 0.3s ease;\\n  transition: height 0.3s ease;\\n}\\n.hermes .tp-bullet.selected:after {\\n  height:100%;\\n}\\n","tabs":".hermes .tp-tab { \\n  opacity:1;  \\n  box-sizing:border-box;\\n  padding-right:10px;\\n }\\n \\n.hermes .tp-tab-content-wrapper {\\n  position:absolute;\\n  width:100%;\\n  min-height:40%;\\n  bottom:0px;\\n  box-sizing:border-box;\\n  padding-right:10px;\\n  overflow:hidden;\\n}\\n.hermes .tp-tab-bg {\\n  position:absolute; \\n  top:0px;\\n  left:-10px; \\n  width:100%;height:100%;\\n  background:rgba(##back-color##); \\n}\\n.hermes .tp-tab-image \\n{ \\n  width:100%;\\n  height:60%;\\n  position:relative;\\n}\\n.hermes .tp-tab-content \\n{\\n  position:relative;\\n  padding:##padding##;\\n  box-sizing:border-box;\\n  display:block;\\n  width:100%;\\n }\\n.hermes .tp-tab-date\\n  {\\n  display:block;\\n  color:rgb(##param1-color##);\\n  font-weight:600;\\n  font-size:##param1-size##px;\\n  margin-bottom:10px;\\n  }\\n.hermes .tp-tab-title \\n{\\n    display:block;\\t\\n    color:rgb(##param2-color##);\\n    font-size:##param2-size##px;\\n    font-weight:800;\\n    text-transform:uppercase;\\n   line-height:##param2-size##px;\\n}\\n\\n.hermes .tp-tab.selected .tp-tab-content-wrapper:after {\\n  width: 0px;\\n\\theight: 0px;\\n\\tborder-style: solid;\\n\\tborder-width: 25px 0 25px 10px;\\n\\tborder-color: transparent transparent transparent ##back-color##;\\n\\tcontent:\\\\\\" \\\\\\";\\n    position:absolute;\\n    right:0px;\\n    bottom:50%;\\n    margin-bottom:-25px;\\n}\\n\\n\\n\\/* media queries *\\/\\n@media only screen and (max-width: 960px) {\\n  .hermes .tp-tab .tp-tab-title {font-size:14px;line-height:16px;}\\n  .hermes .tp-tab-date { font-size:11px; line-height:13px;margin-bottom:10px;}\\n  .hermes .tp-tab-content { padding:15px 15px 15px 25px;}\\n}\\n@media only screen and (max-width: 768px) {\\n  .hermes .tp-tab .tp-tab-title {font-size:12px;line-height:14px;}\\n  .hermes .tp-tab-date {font-size:10px; line-height:12px;margin-bottom:5px;}\\n  .hermes .tp-tab-content {padding:10px 10px 10px 20px;}\\n}\\n\\n\\/* BOTTOM HORIZONTAL *\\/\\n.hermes .nav-pos-ver-bottom.nav-dir-horizontal .tp-tab-image             { margin-top:40%; }\\n.hermes .nav-pos-ver-bottom.nav-dir-horizontal .tp-tab-content-wrapper   { position:absolute; bottom:auto;top:0px; padding-top:10px;}\\n.hermes .nav-pos-ver-bottom.nav-dir-horizontal                           { padding-right:0px; }\\n.hermes .nav-pos-ver-bottom.nav-dir-horizontal .tp-tab-bg                { left:0px; top:10px;}\\n.hermes .nav-pos-ver-bottom.nav-dir-horizontal.tp-tab.selected .tp-tab-content-wrapper:after {  \\n  border-width: 0px 25px 10px 25px;\\n  border-color: transparent transparent rgba(##back-color##) transparent;\\n  top:0px;\\n  left:50%;\\n  margin-left:0px 0px 0px -25px;\\n}\\n\\n\\/* CENTER HORIZONTAL *\\/\\n.hermes .nav-pos-ver-center.nav-dir-horizontal .tp-tab-image             { margin-top:40%; }\\n.hermes .nav-pos-ver-center.nav-dir-horizontal .tp-tab-content-wrapper   { position:absolute; bottom:auto;top:0px; padding-top:10px;}\\n.hermes .nav-pos-ver-center.nav-dir-horizontal                           { padding-right:0px; }\\n.hermes .nav-pos-ver-center.nav-dir-horizontal .tp-tab-bg                { left:0px; top:10px;}\\n.hermes .nav-pos-ver-center.nav-dir-horizontal.tp-tab.selected .tp-tab-content-wrapper:after {  \\n  border-width: 0px 25px 10px 25px;\\n  border-color: transparent transparent rgba(##back-color##) transparent;\\n  top:0px;\\n  left:50%;\\n  margin:0px 0px 0px -25px;\\n}\\n\\n\\/* BOTTOM HORIZONTAL *\\/\\n.hermes .nav-pos-ver-top.nav-dir-horizontal .tp-tab-content-wrapper   { padding-bottom:10px;}\\n.hermes .nav-pos-ver-top.nav-dir-horizontal                           { padding-right:0px; }\\n.hermes .nav-pos-ver-top.nav-dir-horizontal .tp-tab-bg                { left:0px; top:-10px;}\\n.hermes .nav-pos-ver-top.nav-dir-horizontal.tp-tab.selected .tp-tab-content-wrapper:after {  \\n  border-width: 10px 25px 0px 25px;\\n  border-color: rgba(##back-color##) transparent transparent transparent;\\n  bottom:0px;\\n  left:50%;\\n  margin:0px 0px 0px -25px;\\n}\\n\\n\\/* RIGHT VEERTICAL *\\/\\n.hermes .nav-pos-hor-right.nav-dir-vertical .tp-tab-content-wrapper { padding-left:10px; padding-right:0px; left:0px;} \\n.hermes .nav-pos-hor-right.nav-dir-vertical { padding-left:10px; padding-right:0px;}\\n.hermes .nav-pos-hor-right.nav-dir-vertical .tp-tab-bg  { left:10px;}\\n.hermes .nav-pos-hor-right.nav-dir-vertical.tp-tab.selected .tp-tab-content-wrapper:after {  \\n  border-width: 25px 10px 25px 0px;\\n  border-color:transparent  rgba(##back-color##) transparent transparent;\\n  right:auto;\\n  left:0px;    \\n}\\n\\n"}',
			'settings' => '{"width":{"thumbs":"160","arrows":"160","bullets":"160","tabs":"240"},"height":{"thumbs":"160","arrows":"160","bullets":"160","tabs":"260"},"original":{"css":{"arrows":".hermes.tparrows {\\n\\tcursor:pointer;\\n\\tbackground:#000;\\n\\tbackground:rgba(0,0,0,0.5);\\n\\twidth:30px;\\n\\theight:110px;\\n\\tposition:absolute;\\n\\tdisplay:block;\\n\\tz-index:100;\\n}\\n\\n.hermes.tparrows:before {\\n\\tfont-family: \\\\\\"revicons\\\\\\";\\n\\tfont-size:15px;\\n\\tcolor:#fff;\\n\\tdisplay:block;\\n\\tline-height: 110px;\\n\\ttext-align: center;\\n    transform:translateX(0px);\\n    -webkit-transform:translateX(0px);\\n    transition:all 0.3s;\\n    -webkit-transition:all 0.3s;\\n}\\n.hermes.tparrows.tp-leftarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\\e824\\\\\\";\\n}\\n.hermes.tparrows.tp-rightarrow:before {\\n\\tcontent: \\\\\\"\\\\\\\\e825\\\\\\";\\n}\\n.hermes.tparrows.tp-leftarrow:hover:before {\\n    transform:translateX(-20px);\\n    -webkit-transform:translateX(-20px);\\n     opacity:0;\\n}\\n.hermes.tparrows.tp-rightarrow:hover:before {\\n    transform:translateX(20px);\\n    -webkit-transform:translateX(20px);\\n     opacity:0;\\n}\\n\\n.hermes .tp-arr-allwrapper {\\n    overflow:hidden;\\n    position:absolute;\\n\\twidth:180px;\\n    height:140px;\\n    top:0px;\\n    left:0px;\\n    visibility:hidden;\\n      -webkit-transition: -webkit-transform 0.3s 0.3s;\\n  transition: transform 0.3s 0.3s;\\n  -webkit-perspective: 1000px;\\n  perspective: 1000px;\\n    }\\n.hermes.tp-rightarrow .tp-arr-allwrapper {\\n   right:0px;left:auto;\\n      }\\n.hermes.tparrows:hover .tp-arr-allwrapper {\\n   visibility:visible;\\n          }\\n.hermes .tp-arr-imgholder {\\n  width:180px;position:absolute;\\n  left:0px;top:0px;height:110px;\\n  transform:translateX(-180px);\\n  -webkit-transform:translateX(-180px);\\n  transition:all 0.3s;\\n  transition-delay:0.3s;\\n}\\n.hermes.tp-rightarrow .tp-arr-imgholder{\\n    transform:translateX(180px);\\n  -webkit-transform:translateX(180px);\\n      }\\n  \\n.hermes.tparrows:hover .tp-arr-imgholder {\\n   transform:translateX(0px);\\n   -webkit-transform:translateX(0px);            \\n}\\n.hermes .tp-arr-titleholder {\\n  top:110px;\\n  width:180px;\\n  text-align:left; \\n  display:block;\\n  padding:0px 10px;\\n  line-height:30px; background:#000;\\n  background:rgba(0,0,0,0.75);color:#fff;\\n  font-weight:600; position:absolute;\\n  font-size:12px;\\n  white-space:nowrap;\\n  letter-spacing:1px;\\n  -webkit-transition: all 0.3s;\\n  transition: all 0.3s;\\n  -webkit-transform: rotateX(-90deg);\\n  transform: rotateX(-90deg);\\n  -webkit-transform-origin: 50% 0;\\n  transform-origin: 50% 0;\\n  box-sizing:border-box;\\n\\n}\\n.hermes.tparrows:hover .tp-arr-titleholder {\\n    -webkit-transition-delay: 0.6s;\\n  transition-delay: 0.6s;\\n  -webkit-transform: rotateX(0deg);\\n  transform: rotateX(0deg);\\n}\\n","bullets":".hermes.tp-bullets {\\n}\\n\\n.hermes .tp-bullet {\\n    overflow:hidden;\\n    border-radius:50%;\\n    width:16px;\\n    height:16px;\\n    background-color: rgba(0, 0, 0, 0);\\n    box-shadow: inset 0 0 0 2px #FFF;\\n    -webkit-transition: background 0.3s ease;\\n    transition: background 0.3s ease;\\n    position:absolute;\\n}\\n\\n.hermes .tp-bullet:hover {\\n\\t  background-color: rgba(0, 0, 0, 0.2);\\n}\\n.hermes .tp-bullet:after {\\n  content: \\\\\' \\\\\';\\n  position: absolute;\\n  bottom: 0;\\n  height: 0;\\n  left: 0;\\n  width: 100%;\\n  background-color: #FFF;\\n  box-shadow: 0 0 1px #FFF;\\n  -webkit-transition: height 0.3s ease;\\n  transition: height 0.3s ease;\\n}\\n.hermes .tp-bullet.selected:after {\\n  height:100%;\\n}\\n","tabs":".hermes .tp-tab { \\n  opacity:1;  \\n  padding-right:10px;\\n  box-sizing:border-box;\\n }\\n.hermes .tp-tab-image \\n{ \\n  width:100%;\\n  height:60%;\\n  position:relative;\\n}\\n.hermes .tp-tab-content \\n{\\n    background:rgb(54,54,54); \\n    position:absolute;\\n    padding:20px 20px 20px 30px;\\n    box-sizing:border-box;\\n    color:#fff;\\n  display:block;\\n  width:100%;\\n  min-height:40%;\\n  bottom:0px;\\n  left:-10px;\\n  }\\n.hermes .tp-tab-date\\n  {\\n  display:block;\\n  color:#888;\\n  font-weight:600;\\n  font-size:12px;\\n  margin-bottom:10px;\\n  }\\n.hermes .tp-tab-title \\n{\\n    display:block;\\t\\n    color:#fff;\\n    font-size:16px;\\n    font-weight:800;\\n    text-transform:uppercase;\\n   line-height:19px;\\n}\\n\\n.hermes .tp-tab.selected .tp-tab-title:after {\\n    width: 0px;\\n\\theight: 0px;\\n\\tborder-style: solid;\\n\\tborder-width: 30px 0 30px 10px;\\n\\tborder-color: transparent transparent transparent rgb(54,54,54);\\n\\tcontent:\\\\\\" \\\\\\";\\n    position:absolute;\\n    right:-9px;\\n    bottom:50%;\\n    margin-bottom:-30px;\\n}\\n.hermes .tp-tab-mask {\\n     padding-right:10px !important;\\n          }\\n\\n\\/* MEDIA QUERIES *\\/\\n@media only screen and (max-width: 960px) {\\n  .hermes .tp-tab .tp-tab-title {font-size:14px;line-height:16px;}\\n  .hermes .tp-tab-date { font-size:11px; line-height:13px;margin-bottom:10px;}\\n  .hermes .tp-tab-content { padding:15px 15px 15px 25px;}\\n}\\n@media only screen and (max-width: 768px) {\\n  .hermes .tp-tab .tp-tab-title {font-size:12px;line-height:14px;}\\n  .hermes .tp-tab-date {font-size:10px; line-height:12px;margin-bottom:5px;}\\n  .hermes .tp-tab-content {padding:10px 10px 10px 20px;}\\n}"},"markup":{"arrows":"<div class=\\\\\\"tp-arr-allwrapper\\\\\\">\\n\\t<div class=\\\\\\"tp-arr-imgholder\\\\\\"><\\/div>\\n\\t<div class=\\\\\\"tp-arr-titleholder\\\\\\">{{title}}<\\/div>\\t\\n<\\/div>","bullets":"","tabs":"<span class=\\\\\\"tp-tab-image\\\\\\"><\\/span>\\n<span class=\\\\\\"tp-tab-content\\\\\\">\\n\\t<span class=\\\\\\"tp-tab-date\\\\\\">{{param1}}<\\/span>\\n\\t<span class=\\\\\\"tp-tab-title\\\\\\">{{param2}}<\\/span>\\n<\\/span>"}},"placeholders":[{"title":"Background","handle":"back-color","type":"color-rgba","nav-type":"arrows","data":{"color-rgba":"rgba(0,0,0,0.5)"}},{"title":"Width","handle":"width","type":"custom","nav-type":"arrows","data":{"custom":"30"}},{"title":"Height","handle":"height","type":"custom","nav-type":"arrows","data":{"custom":"110"}},{"title":"Arrow-Color","handle":"arrow-color","type":"color","nav-type":"arrows","data":{"color":"#ffffff"}},{"title":"Arrow-Size","handle":"arrow-size","type":"custom","nav-type":"arrows","data":{"custom":"15"}},{"title":"Wrapper-Height","handle":"wrapper-height","type":"custom","nav-type":"arrows","data":{"custom":"140"}},{"title":"Wrapper-Width","handle":"wrapper-width","type":"custom","nav-type":"arrows","data":{"custom":"180"}},{"title":"Title-Size","handle":"title-size","type":"custom","nav-type":"arrows","data":{"custom":"12"}},{"title":"Title-Background","handle":"title-back-color","type":"color-rgba","nav-type":"arrows","data":{"color-rgba":"rgba(0,0,0,0.75)"}},{"title":"Title-Font-Color","handle":"title-font-color","type":"color","nav-type":"arrows","data":{"color":"#ffffff"}},{"title":"Bullet-Size","handle":"bullet-size","type":"custom","nav-type":"bullets","data":{"custom":"16"}},{"title":"Bullet-Color","handle":"bullet-color","type":"color","nav-type":"bullets","data":{"color":"#ffffff"}},{"title":"Border-Thickness","handle":"border","type":"custom","nav-type":"bullets","data":{"custom":"2"}},{"title":"Hover-Bullet","handle":"bullet-hover","type":"color-rgba","nav-type":"bullets","data":{"color-rgba":"rgba(0,0,0,0.21)"}},{"title":"Background","handle":"back-color","type":"color-rgba","nav-type":"tabs","data":{"color-rgba":"#000000"}},{"title":"Param-1-Color","handle":"param1-color","type":"color","nav-type":"tabs","data":{"color":"#888888"}},{"title":"Param-2-Color","handle":"param2-color","type":"color","nav-type":"tabs","data":{"color":"#ffffff"}},{"title":"Param-1-Size","handle":"param1-size","type":"custom","nav-type":"tabs","data":{"custom":"12"}},{"title":"Param-2-Size","handle":"param2-size","type":"custom","nav-type":"tabs","data":{"custom":"16"}},{"title":"Padding","handle":"padding","type":"custom","nav-type":"tabs","data":{"custom":"20px"}}]}');
		
		$navigations[] = array('id' => 5006,'default' => true,'name' => 'Custom','handle' => 'custom','markup' => '{"thumbs":